<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class bauen_accordion extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-accordion';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen Accordion', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-accordion';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-addons' ];
 	}
	
	/**
	 * A list of scripts that the widgets is depended in
	**/ 
	public function get_script_depends() {
		return [ 
			'elementor-accordion-box',
		 ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
			]
		);				
		
		$repeater = new \Elementor\Repeater();
		
		$repeater->add_control(
			'style_type',
			[
				'label' => __( 'Tab Style', 'bauen-plugin' ),
				'description' => __( 'Select tab style type.', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'st1' => 'Inactive',
					'st2' => 'Active',
				],
				'default' => 'st1',
				'label_block' => true,
			]
		);	
		$repeater->add_control(
			'title2', [
				'label' => __( 'Number', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' =>'1.',
				'description' => __( 'Ex: 1.', 'bauen-plugin' ),
				'label_block' => true,
			]
		);		
		$repeater->add_control(
			'title', [
				'label' => __( 'Title', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Add Title' , 'bauen-plugin' ),
				'description' => __( 'Ex: Modern Architectural Structures', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);	
		$repeater->add_control(
			'block-content', [
				'label' => __( 'Content', 'bauen-plugin' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => __('Architecture viverra tristique justo duis vitae diam neque nivamus aestan ateuene artines aringianu atelit finibus viverra nec lacus. Nedana theme erodino setlie suscipe no tristique.', 'bauen-plugin'),
				'label_block' => true,
			]
		);			

		$this->add_control(
			'bauen_accordions',
			[
				'label' => __( 'Accordion', 'bauen-plugin' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'title' => __('Modern Architectural Structures', 'bauen-plugin'),
					],
					[
						'title' => __('Modern Building Structures', 'bauen-plugin'),
					],
					[
						'title' => __('Modern Design Structures', 'bauen-plugin'),
					],					
				],
			]
		);

		$this->end_controls_section();
		
		
		$this->start_controls_section(
			'section_style_title',
			[
				'label' => __( 'Title', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .accordion-box .block .acc-btn' => 'color: {{VALUE}};',		
				],
				'default' =>'',
			]
		);
		$this->add_control(
			'title_color_hv',
			[
				'label' => __( 'Color Active', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .accordion-box .block .acc-btn.active' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .accordion-box .block .acc-btn',
			]
		);
		$this->add_control(
			'title2_color',
			[
				'label' => __( 'Number & Icon Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .accordion-box .block .acc-btn .count' => 'color: {{VALUE}};',
					'{{WRAPPER}} .accordion-box .block .acc-btn:before' => 'color: {{VALUE}};',			
				],
				'default' =>'',
			]
		);	
		$this->add_control(
			'title2_color_hv',
			[
				'label' => __( 'Number & Icon Color Active', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .accordion-box .block .acc-btn.active:before' => 'color: {{VALUE}};',
					'{{WRAPPER}} .accordion-box .block .acc-btn.active .count' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);		
		$this->end_controls_section();				
		
		$this->start_controls_section(
			'section_style_content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'content_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .accordion-box .block .content .text p' => 'color: {{VALUE}};',
					'{{WRAPPER}} .accordion-box .block .content .text' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'text_typography',
				'selector' => '{{WRAPPER}} .accordion-box .block .content .text p, .accordion-box .block .content .text',
			]
		);				
		
		$this->end_controls_section();		
		
		$this->start_controls_section(
			'section_style_background',
			[
				'label' => __( 'Background Color', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,					
			]
		);	
		
		$this->add_control(
			'bg_color',
			[
				'label' => __( 'Background', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .accordion-box .block' => 'background-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);		
		$this->add_control(
			'bg_hover_color',
			[
				'label' => __( 'Background Active', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .accordion-box .block .acc-btn.active' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .accordion-box .block .content' => 'background-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);	
		
		$this->end_controls_section();		
		

	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>

		<div class="sec-accordion">
			<ul class="accordion-box clearfix">
				<?php foreach( $settings['bauen_accordions'] as $bauen_accordion ) { ?>
					<?php if( $bauen_accordion['style_type'] == 'st2' ) { ?>
					<li class="accordion block active-block">
						<?php if ( $bauen_accordion['title'] ) { ?>
							<div class="acc-btn active">
								<?php if ( $bauen_accordion['title2'] ) { ?>
									<span class="count">
									   <?php echo esc_html($bauen_accordion['title2']); ?>
									</span> 
								<?php } ;?>								
							   <?php echo esc_html($bauen_accordion['title']); ?>
							</div> 
						<?php } ;?>	
						<?php if ( $bauen_accordion['block-content'] ) { ?>
							<div class="acc-content current">
								<div class="content">
									<div class="text"><?php echo do_shortcode($bauen_accordion['block-content']); ?></div>
								</div>
							</div>							
						<?php } ;?>											
					</li>										
					<?php } 
					else { ?>					
					<li class="accordion block">
						<?php if ( $bauen_accordion['title'] ) { ?>
							<div class="acc-btn">
								<?php if ( $bauen_accordion['title2'] ) { ?>
									<span class="count">
									   <?php echo esc_html($bauen_accordion['title2']); ?>
									</span> 
								<?php } ;?>								
							   <?php echo esc_html($bauen_accordion['title']); ?>
							</div> 
						<?php } ;?>	
						<?php if ( $bauen_accordion['block-content'] ) { ?>
							<div class="acc-content">
								<div class="content">
									<div class="text"><?php echo do_shortcode($bauen_accordion['block-content']); ?></div>
								</div>
							</div>							
						<?php } ;?>											
					</li>
					<?php } ;?>	
				<?php } ;?>	
	    	</ul>		
		</div>		

        <?php		

	}

}