<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Bauen_Banner_Image extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-banner-image';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen Image & Video Banner', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-image';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-banner' ];
 	}	
	
	/**
	 * A list of scripts that the widgets is depended in
	 **/
	public function get_script_depends() {
		return [ 
			'elementor-banner-bg',
		];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Slider Content', 'bauen-plugin' ),
			]
		);
		
		$repeater = new \Elementor\Repeater();
		
		$this->add_control(
			'corner_line',
			[
				'label' => esc_html__( 'Right Corner Line', 'bauen-plugin' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_off' => esc_html__( 'Off', 'bauen-plugin' ),
				'label_on' => esc_html__( 'On', 'bauen-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		
		$this->add_control(
			'corner_line_color',
			[
				'label' => __( 'Line Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hero-corner, {{WRAPPER}} .hero-corner3' => 'border-color: {{VALUE}};',
				],
				'default' =>'',
				'conditions' => [
					'terms' => [
						[
							'name' => 'corner_line',
							'operator' => 'in',
							'value' => [
								'yes',
							],
						],
					],
				],				
			]
		);
		
		$this->add_responsive_control(
			'slider_height',
			[
				'label' => esc_html__( 'Banner Height', 'annie-plugin' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'vh', '%' ],
				'range' => [
					'vh' => [
						'min' => 0,
						'max' => 100,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'vh',
					'size' => '',
				],
				'selectors' => [
					'{{WRAPPER}} .header' => 'max-height: {{SIZE}}{{UNIT}}; min-height: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'image[url]!' => '',
				],
			]
		);
		
		$this->add_responsive_control(
			'conten_container',
			[
				'label' => esc_html__( 'Content Container Width', 'annie-plugin' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'vh', '%' ],
				'range' => [
					'vh' => [
						'min' => 0,
						'max' => 100,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'vh',
					'size' => '',
				],
				'selectors' => [
					'{{WRAPPER}} .container' => 'max-width: {{SIZE}}{{UNIT}}; width: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'image[url]!' => '',
				],
			]
		);
		
		$this->add_control(
			'image',
			[
				'label' => __( 'Upload Image', 'bauen-plugin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => '',
				],
				'label_block' => true,
			]
		);
		
		$this->add_control(
			'back_position',
			[
				'label' => __( 'Background Position', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'' => 'Default',
					'center center' => 'Center Center',
					'center left' => 'Center Left',
					'center right' => 'Center Right',
					'top center' => 'Top Center',
					'top left' => 'Top Left',
					'top right' => 'Top Right',
					'bottom center' => 'Bottom Center',
					'bottom left' => 'Bottom Left',
					'bottom right' => 'Bottom right',
				],
				'default' => '',
				'label_block' => true,
				'condition' => [
					'image[url]!' => '',
				],
			]
		);
		
		$this->add_control(
			'data_video_url',
			[
				'label' => __( 'MP4 Video URL', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'description' => __( 'Optional.', 'bauen-plugin' ),
				'label_block' => true,
				'condition' => [
					'image[url]!' => '',
				],
			]
		);
		
		$this->add_control(
			'image_overlay',
			[
				'label' => __( 'Overlay', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'0' => '0',
					'1' => '1',
					'2' => '2',
					'3' => '3',
					'4' => '4',
					'5' => '5',
					'6' => '6',
					'7' => '7',
					'8' => '8',
					'9' => '9',
				],
				'default' => '6',
				'label_block' => true,
				'condition' => [
					'image[url]!' => '',
				],
			]
		);
		
		$this->add_control(
			'col_size',
			[
				'label' => __( 'Text Column Size', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'1' => 'Column 1',
					'2' => 'Column 2',
					'3' => 'Column 3',
					'4' => 'Column 4',
					'5' => 'Column 5',
					'6' => 'Column 6',
					'7' => 'Column 7',
					'8' => 'Column 8',
					'9' => 'Column 9',
					'10' => 'Column 10',
					'11' => 'Column 11',
					'12' => 'Column 12',
				],
				'default' => '7',
				'label_block' => true,
				'condition' => [
					'image[url]!' => '',
				],
			]
		);		
		$this->add_control(
			'col_offset',
			[
				'label' => __( 'Text Column Offset', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'offset-0' => 'None',
					'offset-md-1' => 'Offset 1',
					'offset-md-2' => 'Offset 2',
					'offset-md-3' => 'Offset 3',
					'offset-md-4' => 'Offset 4',
					'offset-md-5' => 'Offset 5',
					'offset-md-6' => 'Offset 6',
				],
				'default' => 'offset-md-2',
				'label_block' => true,
				'condition' => [
					'image[url]!' => '',
				],
			]
		);	
		
		$this->add_control(
			'txt_align',
			[
				'label' => esc_html__( 'Text Alignment', 'bauen-plugin' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'text-left ' => [
						'title' => esc_html__( 'Left', 'bauen-plugin' ),
						'icon' => 'eicon-text-align-left',
					],
					'text-center' => [
						'title' => esc_html__( 'Center', 'bauen-plugin' ),
						'icon' => 'eicon-text-align-center',
					],
					'text-right' => [
						'title' => esc_html__( 'Right', 'bauen-plugin' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'text-left',
				'toggle' => true,
				'condition' => [
					'image[url]!' => '',
				],
			]
		);
		
		$this->add_control(
			'title_tag',
			[
				'label' => __( 'Title Tag', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'h1' => 'h1',
					'h2' => 'h2',
					'h3' => 'h3',
					'h4' => 'h4',
					'h5' => 'h5',
					'h6' => 'h6',
				],
				'default' => 'h1',
				'label_block' => true,
				'condition' => [
					'image[url]!' => '',
				],
			]
		);
		
		$this->add_control(
			'data_title_1',
			[
				'label' => __( 'Data Title 1', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Innovate Design in [br]Toronto',
				'description' => __( 'Innovate Design in [br]Toronto', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'image[url]!' => '',
				],
			]
		);
		
		$this->add_control(
			'data_title_2',
			[
				'label' => __( 'Data Title 2', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => 'Architecture viverra tellus nec massa dictum the euismoe.[br]Curabitur viverra the posuere aukue velit.',
				'description' => __( 'E.X: Architecture viverra tellus nec massa dictum the euismoe.[br]Curabitur viverra the posuere aukue velit.', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'image[url]!' => '',
				],
			]
		);
		
		$this->add_control(
			'button_text',
			[
				'label' => __( 'Button Text', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Read More',
				'description' => __( 'Ex: Read More', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'image[url]!' => '',
				],
			]
		);
		
		$this->add_control(
			'button_url',
			[
				'label' => __( 'Button URL', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '#',
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'image[url]!' => '',
				],
			]
		);		
		$this->add_control(
			'button_target',
			[
				'label' => __( 'Button Target', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'_self' => 'Self',
					'_blank' => 'Blank',
					'_parent' => 'Parent',
					'_top' => 'Top',
				],
				'default' => '_self',
				'label_block' => true,
				'condition' => [
					'image[url]!' => '',
				],
			]
		);
		
		$this->add_control(
			'banner_social_option',
			[
				'label' => esc_html__( 'Social Icons', 'bauen-plugin' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_off' => esc_html__( 'Off', 'bauen-plugin' ),
				'label_on' => esc_html__( 'On', 'bauen-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition' => [
					'image[url]!' => '',
				],
			]
		);
		
		$this->add_control(
			'social_opt_mob_main',
			[
				'label' => esc_html__( 'Disaplay on Mobile', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_off' => esc_html__( 'Off', 'bauen-plugin' ),
				'label_on' => esc_html__( 'On', 'bauen-plugin' ),
				'return_value' => 'yes',
				'default' => 'off',
				'conditions' => [
					'terms' => [
						[
							'name' => 'banner_social_option',
							'operator' => 'in',
							'value' => [
								'yes',
							],
						],
					],
				],
			]
		);
		
		$repeater->add_control(
			'icon_type', [
				'label' => __( 'Icon Type', 'candore-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
						'st1' => 'Fontawesome',
						'st2' => 'Themify',
					],
				'default' => 'st1',
				'label_block' => true,
			]
		);
		
		$repeater->add_control(
			'icon_class',
			[
				'label' => esc_html__( 'Icon', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'ti-facebook',
					'library' => 'solid',
				],
				
                'skin' =>'inline',
				'label_block' => false,
				'condition' => [
					'icon_type' => 'st1',
				],
			]
		);
		
		$repeater->add_control(
			'icon_class_list',
			[
				'label' => __( 'Icon Class', 'candore-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'ti-facebook',
				'description' => __( '<a href="https://themify.me/themify-icons" target="_blank" rel="noopener noreferrer">Themify Icon Class</a>', 'candore-plugin' ),
				'condition' => [
					'icon_type' => 'st2',
				],
			]
		);		
		
		$repeater->add_control(
			'social_url',
			[
				'label' => __( 'Social URL', 'candore-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'description' => __( '', 'candore-plugin' ),
				'label_block' => true,
			]
			
		);	
		
		$this->add_control(
			'bauen_social_icons',
			[
				'label' => __( 'Social Icon', 'bauen-plugin' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
				],
				'conditions' => [
					'terms' => [
						[
							'name' => 'banner_social_option',
							'operator' => 'in',
							'value' => [
								'yes',
							],
						],
					],
				],
			]
		);
		
		$this->end_controls_section();
		
		
		$this->start_controls_section(
			'opt_data_overlay',
			[
				'label' => __( 'Overlay', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'opt_data_overlay_color',
				'label' => esc_html__( 'Overlay Color', 'bauen-plugin' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} [data-overlay-dark]:before',
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'opt_data_title_1',
			[
				'label' => __( 'Data Title 1', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'opt_data_title_1_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bn-slider-title-class' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'opt_data_title_1_typo',
				'selector' => '{{WRAPPER}} .bn-slider-title-class',
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'opt_data_title_2',
			[
				'label' => __( 'Data Title 2', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'opt_data_title_2_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .header .caption p' => 'color: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'opt_data_title_2_typo',
				'selector' => '{{WRAPPER}} .header .caption p',
			]
		);
		
		$this->end_controls_section();
		
				
		$this->start_controls_section(
			'section_button',
			[
				'label' => __( 'Button', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'button_color',
			[
				'label' => __( 'Text Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .butn-light a span' => 'color: {{VALUE}};',
				],				
			]
		);
		
		$this->add_control(
			'button_border_color',
			[
				'label' => __( 'Border Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .butn-light a' => 'border-color: {{VALUE}};',
				],				
			]
		);
		$this->add_control(
			'button_bgcolor',
			[
				'label' => __( 'Background Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .butn-light a' => 'background: {{VALUE}}; border-color: {{VALUE}};',
				],				
			]
		);
		$this->add_control(
			'button_color_hv',
			[
				'label' => __( 'Text Color (Hover)', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .butn-light a:hover span' => 'color: {{VALUE}};',
				],				
			]
		);
		$this->add_control(
			'button_bgcolor_hv',
			[
				'label' => __( 'Background Color (Hover)', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .butn-light a:after' => 'background: {{VALUE}};',
					'{{WRAPPER}} .butn-light a:hover' => 'border-color: {{VALUE}};',
				],				
			]
		);		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_typography',
				'selector' => '{{WRAPPER}} .butn-light a',
			]
		);
		
		$this->end_controls_section();
		
				
		$this->start_controls_section(
			'social_area',
			[
				'label' => __( 'Social Icon', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'icon_color',
			[
				'label' => __( 'Icon Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .social-left li a' => 'color: {{VALUE}}; border-color: {{VALUE}};',
					'{{WRAPPER}} .social-left:before' => 'background: {{VALUE}}; ',
				],				
			]
		);
		$this->add_responsive_control(
			'icon_color_hover',
			[
				'label' => __( 'Icon Color(Hover)', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .social-left li a:hover' => 'color: {{VALUE}}; border-color: {{VALUE}};',
				],				
			]
		);
		
		
		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>
		
		
		<header class="header main-slider  bn-intro-type-slider " data-scroll-index="0">
        
            <!-- The opacity on the image is made with "data-overlay-dark="number". You can change it using the numbers 0-9. -->
            
			<?php if ( $settings['data_video_url'] ) { ?>
			<div class="video-fullscreen-wrap item">
				<div class="video-fullscreen-video" data-overlay-dark="<?php echo esc_attr($settings['image_overlay']); ?>">
					<video playsinline="" autoplay="" loop="" muted="" poster="<?php echo esc_url($settings['image']['url']); ?>">
						<source src="<?php echo esc_url($settings['data_video_url']); ?>" type="video/mp4" autoplay="" loop="" muted="">
					</video>
				</div>
			<?php } else { ?>
			<div class=" bg-img bg-img-d item" data-overlay-dark="<?php echo esc_attr($settings['image_overlay']); ?>" data-background="<?php echo esc_url($settings['image']['url']); ?>" data-position="<?php echo esc_attr($settings['back_position']); ?>">
			<?php } ;?>
                <div class="v-middle caption mt-30">
                    <div class="container">
                        <div class="row">
                            <div class="col-md-<?php echo esc_attr($settings['col_size']); ?> <?php echo esc_attr($settings['col_offset']); ?> <?php echo esc_attr($settings['txt_align']); ?>">
							<div class="o-hidden">
                                <<?php echo esc_attr($settings['title_tag']); ?> class="bn-slider-title-class">
									<?php if ( $settings['data_title_1'] ) { ?>
									<?php echo do_shortcode($settings['data_title_1']); ?>
									<?php } ;?>
								</<?php echo esc_attr($settings['title_tag']); ?>>
								<?php if ( $settings['data_title_2'] ) { ?>
                                <p><?php echo do_shortcode($settings['data_title_2']); ?></p> 
								<?php } ;?>
								<?php if ( $settings['button_url'] ) { ?>
                                <div class="butn-light mt-30 mb-30"><a href="<?php echo esc_url($settings['button_url']); ?>" target="<?php echo esc_attr($settings['button_target']); ?>"  rel="noopener noreferrer"><span><?php echo esc_html($settings['button_text']); ?></span></a></div>
								<?php } ;?>
                            </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
			
        
		<?php if ( 'yes' === $settings['corner_line'] ) {?>
		<div class="hero-corner"></div>
		<div class="hero-corner3"></div>
		<?php } ;?>
		<?php if ( 'yes' === $settings['banner_social_option'] ) { ?>
		<div class="left-panel el-left-panel <?php if ( 'yes' === $settings['social_opt_mob_main'] ) { ?>bn-if-social-on<?php } else { ?>bn-if-social-off<?php } ;?>"">
			 <?php if ( 'yes' === $settings['banner_social_option'] ) { ?>
			<ul class="social-left clearfix">
			<?php foreach( $settings['bauen_social_icons'] as $bauen_social_icon ) { ?>
			<?php if ( $bauen_social_icon['icon_class'] || $bauen_social_icon['icon_class_list'] ) { ?>
				<?php if( $bauen_social_icon['icon_type'] == 'st2' ) { ?>
					<li> <a href="<?php echo esc_url($bauen_social_icon['social_url']); ?>" target="_blank" rel="noopener noreferrer"><i class="<?php echo esc_attr($bauen_social_icon['icon_class_list']); ?>"></i></a></li>
				<?php } else { ?>
					<li> <a href="<?php echo esc_url($bauen_social_icon['social_url']); ?>" target="_blank" rel="noopener noreferrer"><?php \Elementor\Icons_Manager::render_icon( $bauen_social_icon['icon_class'], [ 'aria-hidden' => 'true' ] ); ?> </a></li>
				<?php } ;?>
			<?php } ;?>
			<?php } ;?>
			</ul>
			 <?php } ;?>
			
		</div>
		<?php };?>
		
    </header>		

        <?php		

	}

}