<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Bauen_Before_After extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-before-after';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen Before After Image', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-image-before-after';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-addons' ];
 	}
	
	/**
	 * A list of scripts that the widgets is depended in
	 **/
	public function get_script_depends() {
		return [ 
			'elementor-before-after-main',
		];
	}
	public function get_style_depends() {
		return [ 
			'bauen-before-after',
		];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_image',
			[
				'label' => __( 'Image', 'bauen-plugin' ),
			]
		);
				
		$this->add_control(
			'before_image',
			[
				'label' => __( 'Before Image', 'bauen-plugin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => '',
				],
				'label_block' => true,			
			]
		);
		
		$this->add_control(
			'after_image',
			[
				'label' => __( 'After Image', 'bauen-plugin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => '',
				],
				'label_block' => true,			
			]
		);
		
		$this->add_control(
			'text_1', [
				'label' => __( 'Before', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Before' , 'bauen-plugin' ),
				'description' => __( 'Translet Option.', 'bauen-plugin' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'text_2', [
				'label' => __( 'After', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'After' , 'bauen-plugin' ),
				'description' => __( 'Translet Option.', 'bauen-plugin' ),
				'label_block' => true,
			]
		);		

		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_caption',
			[
				'label' => __( 'Label', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'caption_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} div.jx-image div.jx-label' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'caption_typography',
				'selector' => '{{WRAPPER}} div.jx-image div.jx-label',
			]
		);		
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'controller_style_background',
			[
				'label' => __( 'Controller Color', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);	
		
		$this->add_control(
			'main_controller_color',
			[
				'label' => __( 'Background Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} div.jx-controller' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} div.jx-control' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} div.jx-arrow.jx-left' => 'border-color: transparent {{VALUE}} transparent transparent;',
					'{{WRAPPER}} div.jx-arrow.jx-right' => 'border-color: transparent transparent transparent {{VALUE}};',
				],
				'default' =>'',
			]
		);		
		
		
		$this->end_controls_section();
	
		
		
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>
		<?php if ( $settings['before_image']['url'] || $settings['after_image']['url'] ) { ?>
		<div class="clear">
            <div class="juxtapose"> <img src="<?php echo esc_url($settings['before_image']['url']); ?>" class="img-fluid" data-label="<?php echo esc_attr($settings['text_1']); ?>" alt="<?php echo esc_attr($settings['before_image']['alt']); ?>"> <img src="<?php echo esc_url($settings['after_image']['url']); ?>" class="img-fluid" data-label="<?php echo esc_attr($settings['text_2']); ?>" alt="<?php echo esc_attr($settings['after_image']['alt']); ?>"> </div>
        </div>	
		<?php } ;?>
		
		<?php
		

	}

}