<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Bauen_Careers extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-careers';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen Careers', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-table';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-addons' ];
 	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
			]
		);
		
		$repeater = new \Elementor\Repeater();
		
		$repeater->add_control(
			'title',
			[
				'label' => __( 'Job Title', 'tank-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Project Manager',
				'description' => __( 'Ex: Project Manager', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);
		
		$repeater->add_control(
			'job_type',
			[
				'label' => __( 'Job Type', 'tank-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Development',
				'description' => __( 'Ex: Development', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);
		
		$repeater->add_control(
			'location',
			[
				'label' => __( 'Location Data Title', 'tank-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Location',
				'description' => __( 'Ex: Development', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);
		$repeater->add_control(
			'location_data',
			[
				'label' => __( 'Location Data Content', 'tank-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => ' New York, NY',
				'description' => __( 'Ex:  New York, NY', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);
		
		$repeater->add_control(
			'employment_data_title',
			[
				'label' => __( 'Employment Data Title', 'tank-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => ' Employment Type',
				'description' => __( 'Ex:  Employment Type', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);
		
		$repeater->add_control(
			'employment_data_con',
			[
				'label' => __( 'Employment Data Content', 'tank-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => ' Full-time',
				'description' => __( 'Ex:  Full-time', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);
		
		$repeater->add_control(
			'custom_url',
			[
				'label' => __( 'Custom URL', 'tank-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '#',
				'description' => __( '', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);
		
		$repeater->add_control(
			'button_target',
			[
				'label' => __( 'Link Target', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'_self' => 'Self',
					'_blank' => 'Blank',
					'_parent' => 'Parent',
					'_top' => 'Top',
				],
				'default' => '_self',
				'label_block' => true,
			]
		);
		
		$this->add_control(
			'bauen_careers',
			[
				'label' => __( 'Careers Items', 'bauen-plugin' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
			]
		);	
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_hover',
			[
				'label' => __( 'Section Hover & Border', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);	

		$this->add_control(
			'section_hover_color',
			[
				'label' => __( 'Section Hover Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .position:hover' => 'background-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		
		$this->add_control(
			'section_border_color',
			[
				'label' => __( 'Section Border Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .position' => 'border-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_text',
			[
				'label' => __( 'Job Title & Job Type', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'job_title_color',
			[
				'label' => __( 'Job Title Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .position-title' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => __( 'Job Title Typography', 'bauen-plugin' ),
				'name' => 'job_title_typography',
				'selector' => '{{WRAPPER}} .position-title',
			]
		);
		
		$this->add_control(
			'job_type_color',
			[
				'label' => __( 'Job Type Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .position-title span' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_control(
			'job_type_hover_color',
			[
				'label' => __( 'Job Type Hover Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .position:hover .position-title span' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => __( 'Job Type Typography', 'bauen-plugin' ),
				'name' => 'job_type_typography',
				'selector' => '{{WRAPPER}} .position-title span',
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_location_text',
			[
				'label' => __( 'Job Location &  Employment', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'job_location_color',
			[
				'label' => __( 'Title Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .position-location span' => 'color: {{VALUE}};',
					'{{WRAPPER}} .position-time' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		
		
		$this->add_control(
			'job_location_hover_color',
			[
				'label' => __( 'Title Hover Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .position:hover .position-location span' => 'color: {{VALUE}};',
					'{{WRAPPER}} .position:hover .position-time' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => __( 'Title Typography', 'bauen-plugin' ),
				'name' => 'job_location_title_typography',
				'selector' => '{{WRAPPER}} .position-location span, {{WRAPPER}} .position-time ',
			]
		);
		
		$this->add_control(
			'job_location_con_color',
			[
				'label' => __( 'Content Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .position-location' => 'color: {{VALUE}};',
					'{{WRAPPER}} .position-time span' => 'color: {{VALUE}};',
					'{{WRAPPER}} .position-icon' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => __( 'Content Typography', 'bauen-plugin' ),
				'name' => 'job_location_con_typography',
				'selector' => '{{WRAPPER}} .position-location, {{WRAPPER}} .position-time span ',
			]
		);
		
		$this->end_controls_section();
	
		
		
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>
		<div class="positions">
		<?php foreach( $settings['bauen_careers'] as $bauen_career ) { ?>
        <div class="position">
            <a class="position-link" href="<?php echo esc_url($bauen_career['custom_url']); ?>" target="<?php echo esc_attr($bauen_career['button_target']); ?>"></a>
            <div class="position-title"><?php echo esc_html($bauen_career['title']); ?> <span><?php echo esc_html($bauen_career['job_type']); ?></span></div>
            <div class="position-location"><span><?php echo esc_html($bauen_career['location']); ?></span> <?php echo esc_html($bauen_career['location_data']); ?></div>
            <div class="position-time"><?php echo esc_html($bauen_career['employment_data_title']); ?> <span><?php echo esc_html($bauen_career['employment_data_con']); ?></span></div>
            <div class="position-icon"><i class="ti-arrow-top-right"></i></div>
        </div>
		<?php } ;?>	
		</div>
        <?php
		

	}

}