<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Bauen_Clients extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-clients';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen Clients Logo', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-slider-push';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-addons' ];
 	}
	
	/**
	 * A list of scripts that the widgets is depended in
	 **/
	public function get_script_depends() {
		return [ 
			'owl-carousel',
			'elementor-clients-carousel',
		 ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
			]
		);
		
		$repeater = new \Elementor\Repeater();			
		
		$repeater->add_control(
			'image',
			[
				'label' => __( 'Clients Logo', 'bauen-plugin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => '',
				],
				'label_block' => true,
			]
		);
		
		$repeater->add_control(
			'button_url',
			[
				'label' => __( 'Custom URL', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '#',
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'image[url]!' => '',
				],					
			]
		);		
		$repeater->add_control(
			'button_target',
			[
				'label' => __( 'Custom URL Target', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'_self' => 'Self',
					'_blank' => 'Blank',
					'_parent' => 'Parent',
					'_top' => 'Top',
				],
				'default' => '_self',
				'label_block' => true,
				'condition' => [
					'button_url!' => '',
				],					
			]
		);				
		$this->add_control(
			'bauen_clients',
			[
				'label' => __( 'Clients Logos', 'tank-plugin' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'image' => __('', 'bauen-plugin'),
					],
					
				],
				
			]
		);		

		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_settings',
			[
				'label' => __( 'Carousel Settings', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'carousel_column', [
				'label' => __( 'Columns(Desktop)', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
						'6' => '6 Columns',
						'5' => '5 Columns',
						'4' => '4 Columns',
						'3' => '3 Columns',
						'2' => '2 Columns',
					],
				'default' => '5',
				'label_block' => true,
			]
		);
		
		$this->add_control(
			'carousel_column_tablet', [
				'label' => __( 'Columns(Tablet)', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
						'6' => '6 Columns',
						'5' => '5 Columns',
						'4' => '4 Columns',
						'3' => '3 Columns',
						'2' => '2 Columns',
					],
				'default' => '3',
				'label_block' => true,
			]
		);
		
		$this->add_control(
			'column_margin',
			[
				'label' => __( 'Column Gap(Desktop)', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '30',
				'description' => __( 'Default: 30', 'bauen-plugin' ),
				'label_block' => true,
			]
		);
		
		$this->add_control(
			'column_margin_tablet',
			[
				'label' => __( 'Column Gap(Tablet)', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '10',
				'description' => __( 'Default: 10', 'bauen-plugin' ),
				'label_block' => true,
			]
		);
		
		$this->add_control(
			'column_margin_mob',
			[
				'label' => __( 'Column Gap(Mobile)', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '10',
				'description' => __( 'Default: 10', 'bauen-plugin' ),
				'label_block' => true,
			]
		);
		
		$this->add_control(
			'clients_autoplay',
			[
				'label' => __( 'Carousel Autoplay', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'true' => 'Enable',
					'false' => 'Disable',
				],
				'default' => 'true',
				'label_block' => true,
			]			
		);

		$this->add_control(
			'client_autoplay_speed',
			[
				'label' => __( 'Autoplay Timeout', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '5000',
				'description' => __( 'Default: 5000', 'bauen-plugin' ),
				'label_block' => true,
				'condition' => [
					'clients_autoplay' => 'true',
				],
			]
		);
		
		$this->add_control(
			'clients_speed',
			[
				'label' => __( 'Carousel Speed', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '500',
				'description' => __( 'Default: 500', 'bauen-plugin' ),
				'label_block' => true,
			]
		);
		
		$this->end_controls_section();
		

	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>

		<div class="clients">
			<div class="owl-carousel owl-theme" data-clients-autoplay="<?php echo esc_attr($settings['clients_autoplay']); ?>" data-clients-speed="<?php echo esc_attr($settings['clients_speed']); ?>" data-client-autoplay-timeout="<?php echo esc_attr($settings['client_autoplay_speed']); ?>" data-carousel-columns="<?php echo esc_html($settings['carousel_column']); ?>" data-carousel-gap="<?php echo esc_html($settings['column_margin']); ?>" data-carousel-mobile-gap="<?php echo esc_html($settings['column_margin_mob']); ?>" data-carousel-tablet-gap="<?php echo esc_html($settings['column_margin_tablet']); ?>" data-carousel-columns-tablet="<?php echo esc_html($settings['carousel_column_tablet']); ?>" <?php if ( is_rtl() ) { ?>data-rtl="true"<?php } else { ?>data-rtl="false"<?php } ;?>>
				<?php foreach( $settings['bauen_clients'] as $bauen_client ) { ?>
				<div class="clients-logo">
				    <?php if ( $bauen_client['button_url'] ) { ?>
					<a href="<?php echo esc_url($bauen_client['button_url']); ?>" target="<?php echo esc_attr($bauen_client['button_target']); ?>" rel="noopener noreferrer">
					<?php } ;?>						
					<img src="<?php echo esc_url($bauen_client['image']['url']); ?>" alt="<?php echo esc_attr($bauen_client['image']['alt']); ?>">				
					<?php if ( $bauen_client['button_url'] ) { ?>
					</a>
					<?php } ;?>			
				</div>	
				<?php } ;?>
			</div>		
		</div>		

        <?php		

	}

}