<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Bauen_Contact extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-contact';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen Contact', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-device-mobile';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-addons' ];
 	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
			]
		);				
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Add Title',
				'description' => __( 'Ex: Contact Details', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);			
		$this->add_control(
			'block-content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => '',
				'label_block' => true,
			]				
		);			
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'content_type', [
				'label' => __( 'Content Type', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
						'st1' => 'Email',
						'st2' => 'Phone',
						'st3' => 'Location',
						'st4' => 'Info',
					],
				'default' => 'st1',
				'label_block' => true,
			]
		);
		
		$repeater->add_control(
			'data_info_address',
			[
				'label' => __( 'Location Title', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Add Title',
				'description' => __( 'Ex: Address : ', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'content_type' => 'st3',
				],				
			]
		);		
		$repeater->add_control(
			'data_address',
			[
				'label' => __( 'Location Name', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Add Content',
				'description' => __( 'Ex: 24 King St, Charleston, 29401 USA', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'content_type' => 'st3',
				],				
			]
		);
		$repeater->add_control(
			'data_url',
			[
				'label' => __( 'Location URL', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'description' => __( 'Ex: yoursite.com', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'content_type' => 'st3',
				],
			]
		);
		$repeater->add_control(
			'button_target', [
				'label' => __( 'Location URL Target', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'description' => 'Works only for content type Custom URL.',
				'options' => [
						'_self' => 'Self',
						'_blank' => 'Blank',
						'_parent' => 'Parent',
						'_top' => 'Top',
					],
				'default' => '_self',
				'label_block' => true,
				'condition' => [
					'content_type' => 'st3',
					'data_url!' => '',
				],			
			]
		);		
		$repeater->add_control(
			'data_info_mail',
			[
				'label' => __( 'Mail Title', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Add Mail',
				'description' => __( 'Ex: Mail : ', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'content_type' => 'st1',
				],				
			]
		);		
		$repeater->add_control(
			'data_email',
			[
				'label' => __( 'Email Address', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'yourmail@domain.com',
				'description' => __( 'Ex: yourmail@domain.com', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'content_type' => 'st1',
				],
			]
		);
		$repeater->add_control(
			'data_info_phone',
			[
				'label' => __( 'Phone Title', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Add Title',
				'description' => __( 'Ex: Phone : ', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'content_type' => 'st2',
				],				
			]
		);		
		$repeater->add_control(
			'data_phone',
			[
				'label' => __( 'Phone Number', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '+12031230606',
				'description' => __( 'Ex: +1-203-123-0606', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'content_type' => 'st2',
				],
			]
		);		
		$repeater->add_control(
			'data_info_text',
			[
				'label' => __( 'Data Title', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Add Title',
				'description' => __( 'Ex: VAT : ', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'content_type' => 'st4',
				],				
			]
		);		
		$repeater->add_control(
			'data_text',
			[
				'label' => __( 'Data Text', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'USA002323065B06',
				'description' => __( 'Ex: USA002323065B06', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'content_type' => 'st4',
				],
			]
		);		
		$this->add_control(
			'contact_info_loop',
			[
				'label' => __( 'Contact Information', 'bauen-plugin' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
			]
		);
		
		$this->end_controls_section();		

		$this->start_controls_section(
			'section_style_title',
			[
				'label' => __( 'Title', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);	
		$this->add_control(
			'title_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} p b' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',			
				'selector' => '{{WRAPPER}} p b',
			]
		);
		$this->end_controls_section();		
		
		$this->start_controls_section(
			'section_style_content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,				
			]
		);
		
		$this->add_control(
			'content_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} p' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'text_typography',
				'selector' => '{{WRAPPER}} p',
			]
		);				
		
		$this->end_controls_section();		

	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>
        
		<div class="sec-contact-info mb-30">
			<?php if ( $settings['title'] ) { ?>
			<p><b><?php echo esc_html($settings['title']); ?></b></p> 
			<?php }; ?>	
			<?php if ( $settings['block-content'] ) { ?>
			<p><?php echo do_shortcode($settings['block-content']); ?></p>
			<?php }; ?>	
		    
			<?php if ( $settings['contact_info_loop'] ) { ?>			
				<?php foreach( $settings['contact_info_loop'] as $contact_info_loops ) { ?>
					<?php if( $contact_info_loops['content_type'] == 'st3' ) { ?>
					    <p><b><?php echo esc_html($contact_info_loops['data_info_address']); ?></b> <a href="<?php echo esc_url($contact_info_loops['data_url']); ?>" target="<?php echo esc_attr($contact_info_loops['button_target']); ?>"><?php echo esc_html($contact_info_loops['data_address']); ?></a></p>
					<?php } 
					else if( $contact_info_loops['content_type'] == 'st2' ) { ?>						
					    <p><b><?php echo esc_html($contact_info_loops['data_info_phone']); ?></b> <a href="tel:<?php echo esc_attr($contact_info_loops['data_phone']); ?>"><?php echo esc_html($contact_info_loops['data_phone']); ?></a></p> 
					<?php } 
					else if( $contact_info_loops['content_type'] == 'st4' ) { ?>						
					    <p><b><?php echo esc_html($contact_info_loops['data_info_text']); ?></b> <?php echo esc_html($contact_info_loops['data_text']); ?></p> 						
					<?php } 
					else { ?>						 
						<p><b><?php echo esc_html($contact_info_loops['data_info_mail']); ?></b> <a href="mailto:<?php echo esc_attr($contact_info_loops['data_email']); ?>"><?php echo esc_html($contact_info_loops['data_email']); ?></a></p> 
					<?php } ;?>	 

				<?php } ;?>
			<?php } ;?>	
        </div>
		
        <?php		

	}

}