<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Bauen_Flip_Box extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-flip-box';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen Flip Box', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-flip-box';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-addons' ];
 	}	
	
	/**
	 * A list of scripts that the widgets is depended in
	 **/
	public function get_script_depends() {
		return [ 
			'elementor-flip-bg',
		 ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
			]
		);		

		$this->add_control(
			'block_image',
			[
				'label' => __( 'Block Image', 'bauen-plugin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => '',
				],
				'label_block' => true,	
			]
		);
		
		$this->add_control(
			'style_type',
			[
				'label' => __( 'Logo Type', 'bauen-plugin' ),
				'description' => __( 'Select style type.', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'st1' => 'Icon',
					'st2' => 'Image',
				],
				'default' => 'st1',
				'label_block' => true,
				'condition' => [
					'block_image[url]!' => '',
				],
			]
		);	
        $this->add_control(
			'icon_class',
			[
				'label' => esc_html__( 'Icon', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => '',
					'library' => '',
				],
				
                'skin' =>'inline',
				'label_block' => false,
				'condition' => [
					'style_type' => 'st1',
				],				
			]
		);	
		$this->add_control(
			'image',
			[
				'label' => __( 'Image', 'bauen-plugin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => '',
				],
				'label_block' => true,	
				'condition' => [
					'style_type' => 'st2',
				],					
			]
		);	

				
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Add Title',
				'description' => __( 'Ex: Architecture', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'block_image[url]!' => '',
				],
			]
		);	
		

		$this->add_control(
			'button_text',
			[
				'label' => __( 'Button Text', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'block_image[url]!' => '',
				],
			]
		);		
		
		$this->add_control(
			'button_url',
			[
				'label' => __( 'Button URL', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'block_image[url]!' => '',
				],
			]
		);		
		$this->add_control(
			'button_target',
			[
				'label' => __( 'Button Target', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'_self' => 'Self',
					'_blank' => 'Blank',
					'_parent' => 'Parent',
					'_top' => 'Top',
				],
				'default' => '_self',
				'label_block' => true,
				'condition' => [
					'block_image[url]!' => '',
				],
			]
		);	

		$this->add_control(
			'block-content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => '',	
				'condition' => [
					'block_image[url]!' => '',
				],		
				'label_block' => true,				
			]				
		);		
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_overlay',
			[
				'label' => __( 'Overlay', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'style_df_opacity',
			[
				'label' => __( 'Default Opacity', 'bauen-plugin' ),
				'description' => __( 'Enable/ Disable default opacity.', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'st1' => 'Enable',
					'st2' => 'Disable',
				],
				'default' => 'st1',
				'label_block' => true,
			]
		);	
		
		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'back_flip_color',
				'label' => esc_html__( 'Overlay Color', 'bauen-plugin' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .flip-overlay',
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_icon',
			[
				'label' => __( 'Icon & Background Color', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'icon_color',
			[
				'label' => __( 'Icon Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .services4 .square2 .icon i' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		
		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'back_flip_color_back',
				'label' => esc_html__( 'Flip Background', 'bauen-plugin' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .services4 .square2',
			]
		);
		
		
		$this->end_controls_section();			
		
		$this->start_controls_section(
			'section_style_title_before',
			[
				'label' => __( 'Before Hover Title Options', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		
        	
		$this->add_control(
			'before_title_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .services4 .square h4' => 'color: {{VALUE}};',
				],				
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'before_title_typography',
				'selector' => '{{WRAPPER}} .services4 .square h4',
			]
		);
		
		$this->end_controls_section();			
		
		$this->start_controls_section(
			'section_style_title_after',
			[
				'label' => __( 'After Hover Title Options', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        	
		$this->add_control(
			'after_title_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .services4 .square2 h4' => 'color: {{VALUE}};',
				],				
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'after_title_typography',
				'selector' => '{{WRAPPER}} .services4 .square2 h4',
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,					
			]
		);
		
		$this->add_control(
			'content_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .services4 .square2 .services4-text, {{WRAPPER}} .services4 .square2 .services4-text p' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'text_typography',
				'selector' => '{{WRAPPER}} .services4 .square2 .services4-text, {{WRAPPER}} .services4 .square2 .services4-text p',
			]
		);			
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_button',
			[
				'label' => __( 'Button', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'button_color',
			[
				'label' => __( 'Text Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .services4 .btn-line a' => 'color: {{VALUE}};',
				],				
			]
		);
		
		$this->add_control(
			'button_color_hv',
			[
				'label' => __( 'Text Color (Hover)', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .services4 .btn-line a:hover' => 'color: {{VALUE}};',
				],				
			]
		);
		
		$this->add_control(
			'button_bgcolor',
			[
				'label' => __( 'Border Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .services4 .btn-line a' => 'border-color: {{VALUE}};',
				],				
			]
		);
		
		$this->add_control(
			'button_bgcolor_hv',
			[
				'label' => __( 'Border Color (Hover)', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .services4 .btn-line a:hover' => 'border-color: {{VALUE}};',
				],				
			]
		);		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_typography',
				'selector' => '{{WRAPPER}} .services4 .btn-line a',
			]
		);	
		
		$this->end_controls_section();		

	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>

		<?php if ( $settings['block_image']['url'] ) { ?>
		<div class="services4">
			<div class="square-flip">
                <div class="square bg-img bg-img-f-d" data-background="<?php echo esc_url($settings['block_image']['url']); ?>">
                    <div class="square-container d-flex align-items-end justify-content-end">
                        <div class="box-title text-vertical">
                            <?php if ( $settings['title'] ) { ?><h4><?php echo do_shortcode($settings['title']); ?></h4><?php } ;?>
                        </div>
                    </div>
                    <div class="flip-overlay"<?php if ( $settings['style_df_opacity'] == 'st2' ) { ?> style="opacity:1;"<?php } ;?>></div>
                </div>
                <div class="square2">
                    <div class="square-container2">
                        <div class="icon">
						<?php if ( $settings['style_type'] == 'st2' ) { ?>
							<img src="<?php echo esc_url($settings['image']['url']); ?>" alt="<?php echo esc_attr($settings['image']['alt']); ?>"> 
						<?php } 
						else { ?>	
							<?php \Elementor\Icons_Manager::render_icon( $settings['icon_class'], [ 'aria-hidden' => 'true' ] ); ?>
						<?php } ;?>
						</div>
                        <?php if ( $settings['title'] ) { ?><h4><?php echo do_shortcode($settings['title']); ?></h4><?php } ;?>
                        <?php if ( $settings['block-content'] ) { ?>
						<div class="services4-text"><?php echo do_shortcode($settings['block-content']); ?></div>
						<?php }; ?>
						<?php if ( $settings['button_url'] ) { ?>
							<div class="btn-line"> <a href="<?php echo esc_url($settings['button_url']); ?>" target="<?php echo esc_attr($settings['button_target']); ?>" rel="noopener noreferrer"><span><?php echo esc_html($settings['button_text']); ?></span></a> </div>
					   <?php } ;?>
                        
                    </div>
                </div>
            </div>
                    
		</div>
		<?php } ;?>
        		

        <?php		

	}

}