<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Bauen_Form extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-form';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen Form', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-form-horizontal';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-addons' ];
 	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
			]
		);				
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Add Title',
				'description' => __( 'Ex: Contact Form', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);		
		$this->add_control(
			'form_shortcode',
			[
				'label' => __( 'Form Shortcode', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXTAREA,
				'description' => 'Ex: [contact-form-7 id="5" title="Contact form 1"]',
				'default' => '',
				'label_block' => true,
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_title',
			[
				'label' => __( 'Title', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);	
		$this->add_control(
			'title_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} p b' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',			
				'selector' => '{{WRAPPER}} p b',
			]
		);
		$this->end_controls_section();			
		
		$this->start_controls_section(
			'section_form_label',
			[
				'label' => __( 'Lable', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'lable_color',
			[
				'label' => __( 'Lable Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} form label' => 'color: {{VALUE}};',
				],
				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'lable_typography',
				'selector' => '{{WRAPPER}} form label',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_form_input',
			[
				'label' => __( 'Input', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'input_color',
			[
				'label' => __( 'Text Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .vc_template textarea, {{WRAPPER}} .vc_template input[type="text"], {{WRAPPER}} .vc_template input[type=email],  {{WRAPPER}} .vc_template input[type=password], {{WRAPPER}} .vc_template input[type=url], {{WRAPPER}} .vc_template input[type=number], {{WRAPPER}} input[type="file"], {{WRAPPER}} input[type="date"], {{WRAPPER}} input[type="tel"], {{WRAPPER}} input[type="url"]' => 'color: {{VALUE}};',
				],
			]
		);		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'input_typo',
				'selector' => '{{WRAPPER}} .vc_template textarea, {{WRAPPER}} .vc_template input[type="text"], {{WRAPPER}} .vc_template input[type=email], {{WRAPPER}} .vc_template input[type=password], {{WRAPPER}} .vc_template input[type=number], {{WRAPPER}} .vc_template input[type=number], {{WRAPPER}} input[type="file"], {{WRAPPER}} input[type="date"], {{WRAPPER}} input[type="tel"], {{WRAPPER}} input[type="url"]',
			]
		);		
		$this->end_controls_section();
				
		$this->start_controls_section(
			'section_form_checkbox',
			[
				'label' => __( 'Checkbox', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);	
		$this->add_control(
			'input_checkbox_text_color',
			[
				'label' => __( 'Text Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .vc_template form .wpcf7-checkbox label' => 'color: {{VALUE}};',
				],
			]
		);		
		$this->add_control(
			'input_checkbox_back_color',
			[
				'label' => __( 'Active Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} input[type=checkbox]:after' => 'color: {{VALUE}};',
				],
			]
		);	
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'input_checkbox_typo',
				'selector' => '{{WRAPPER}} .vc_template form .wpcf7-checkbox label',
			]
		);			
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_form_radio',
			[
				'label' => __( 'Radio', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);		
		$this->add_control(
			'input_radio_text_color',
			[
				'label' => __( 'Text Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .vc_template form .wpcf7-radio label' => 'color: {{VALUE}};',
				],
			]
		);		
		$this->add_control(
			'input_radio_back_color',
					[
						'label' => __( 'Active Color', 'bauen-plugin' ),
						'type' => Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} input[type=radio]:before' => 'background-image:radial-gradient(circle, {{VALUE}} 50%, transparent 70%);',
						],
						'default' =>'',
					]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'input_radio_typo',
				'selector' => '{{WRAPPER}} .vc_template form .wpcf7-radio label',
			]
		);			
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_form_select',
			[
				'label' => __( 'Select', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);	
		$this->add_control(
			'input_select_color',
			[
				'label' => __( 'Text Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .form-select, .vc_template form select' => 'color: {{VALUE}};',
				],
			]
		);	
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'input_select_typo',
				'selector' => '{{WRAPPER}} .form-select, .vc_template form select',
			]
		);			
		$this->end_controls_section();	
		
		$this->start_controls_section(
			'section_form_date',
			[
				'label' => __( 'Calender', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);	
		$this->add_control(
			'input_date_color',
			[
				'label' => __( 'Text Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .vc_template input[type=date], .vc_template input[type="date"]:after' => 'color: {{VALUE}};',
				],
			]
		);	
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'input_date_typo',
				'selector' => '{{WRAPPER}} .vc_template input[type=date]',
			]
		);			
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_form_border',
			[
				'label' => __( 'Border', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);		
		$this->add_control(
			'input_border_color',
			[
				'label' => __( 'Border Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .vc_template textarea, {{WRAPPER}} .vc_template input[type="text"], {{WRAPPER}} .vc_template input[type=email], {{WRAPPER}} .dark-version input[type=email], {{WRAPPER}} .dark-version input[type=text], {{WRAPPER}} .dark-version textarea, {{WRAPPER}} .dark-version input[type=password], {{WRAPPER}} .dark-version input[type=url], {{WRAPPER}} .dark-version input[type=date], {{WRAPPER}} .dark-version input[type=number], {{WRAPPER}} .dark-version .form-control, {{WRAPPER}} .dark-version form select, {{WRAPPER}} .vc_template input[type="tel"], {{WRAPPER}} .vc_template input[type=password], {{WRAPPER}} .vc_template input[type=url], {{WRAPPER}} input[type=date], {{WRAPPER}} .vc_template input[type=number], {{WRAPPER}} .vc_template input[type=radio]:before, {{WRAPPER}} .dark-version input[type=radio]:before, {{WRAPPER}} .vc_template input[type=checkbox]:before, {{WRAPPER}} .dark-version input[type=checkbox]:before, {{WRAPPER}} .vc_template input[type="file"], {{WRAPPER}} .dark-version .vc_template input[type="file"]' => 'border-color: {{VALUE}};',
				],
			]
		);		
		$this->end_controls_section();		
		
		$this->start_controls_section(
			'section_form_placeholder',
			[
				'label' => __( 'Placeholder', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'placeholder_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .vc_template input::placeholder' => 'color: {{VALUE}};',
					'{{WRAPPER}} .vc_template input::-webkit-input-placeholder, {{WRAPPER}} .vc_template textarea::-webkit-input-placeholder, {{WRAPPER}} .vc_template input[type="email"]::-webkit-input-placeholder, {{WRAPPER}} .vc_template input[type="text"]::-webkit-input-placeholder' => 'color: {{VALUE}}!important;',
					'{{WRAPPER}} .vc_template input:-moz-placeholder, {{WRAPPER}} .vc_template textarea:-moz-placeholder, {{WRAPPER}} .vc_template input[type="text"]:-moz-placeholder, {{WRAPPER}} .vc_template input[type="email"]:-moz-placeholder, {{WRAPPER}} .vc_template  input[type=date]::-webkit-input-placeholder, {{WRAPPER}} .vc_template input[type=number]::-webkit-input-placeholder,  {{WRAPPER}} .vc_template input[type="tel"]::-webkit-input-placeholder' => 'color: {{VALUE}}!important;',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => __( 'Chrome Placeholder', 'bauen-plugin' ),
				'name' => 'placeholder_typography_webkit',
				'selector' => '{{WRAPPER}} .vc_template input::-webkit-input-placeholder, {{WRAPPER}} .vc_template textarea::-webkit-input-placeholder',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => __( 'Mozila Placeholder', 'bauen-plugin' ),
				'name' => 'placeholder_typography_moz',
				'selector' => '{{WRAPPER}} .vc_template input:-moz-placeholder, {{WRAPPER}} .vc_template textarea:-moz-placeholder',
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_form_button',
			[
				'label' => __( 'Button', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'button_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .vc_template .butn-dark a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'button_color_hover',
			[
				'label' => __( 'Color Hover', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .vc_template .butn-dark a:hover span' => 'color: {{VALUE}};',
				],
			]
		);		
		$this->add_control(
			'button_background',
			[
				'label' => __( 'Background Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .vc_template button,  {{WRAPPER}} .vc_template .butn-dark a' => 'background: {{VALUE}};',
				],
			]
		);		
		$this->add_control(
			'button_background_hover',
			[
				'label' => __( 'Background Color Hover', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .vc_template .butn-dark a:after, {{WRAPPER}} .vc_template button:hover' => 'background: {{VALUE}};',
				],
			]
		);		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_typo',
				'selector' => '{{WRAPPER}} .vc_template .butn-dark a',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_form_valid',
			[
				'label' => __( 'Valid & Response', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'required_color',
			[
				'label' => __( 'Required Field Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpcf7-not-valid-tip' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'response_color',
			[
				'label' => __( 'Response Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpcf7 form.invalid .wpcf7-response-output' => 'color: {{VALUE}};',
					'{{WRAPPER}} .wpcf7 form.unaccepted .wpcf7-response-output' => 'color: {{VALUE}};',
				],
			]
		);		
		$this->add_control(
			'response_border',
			[
				'label' => __( 'Response Border Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpcf7 form.invalid .wpcf7-response-output' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .wpcf7 form.unaccepted .wpcf7-response-output' => 'border-color: {{VALUE}};',
				],
			]
		);			
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'response_typo',
				'selector' => '{{WRAPPER}} .wpcf7-not-valid-tip, {{WRAPPER}} .wpcf7 form.invalid .wpcf7-response-output, {{WRAPPER}} .wpcf7 form.unaccepted .wpcf7-response-output',
			]
		);
		$this->end_controls_section();		

	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>
		<div  class="sec-contact-form">
        <?php if ( $settings['title'] ) { ?>
			<p><b><?php echo esc_html($settings['title']); ?></b></p> 
		<?php }; ?>	
			<div  class="vc_template">
			   <?php echo do_shortcode($settings['form_shortcode']); ?>
			</div>	
		</div>	
		
        <?php		

	}

}