<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Bauen_Gallery extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-gallery';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen Masonry Gallery', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-gallery-justified';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-addons' ];
 	}	
	
	/**
	 * A list of scripts that the widgets is depended in
	 **/
	public function get_script_depends() {
		return [ 
			'isotope',
			'imagesloaded',
			'elementor-gallery-load-more',
			'elementor-gallery-popup',
		 ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Gallery Images', 'bauen-plugin' ),
			]
		);
		
		$repeater = new \Elementor\Repeater();	

		$this->add_control(
			'post_pagination',
			[
				'label' => __( 'Load More Button', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'st1' => 'Disable',
					'st2' => 'Enable',
				],
				'default' => 'st1',
				'label_block' => true,
			]			
		);		
		$this->add_control(
			'post_show_before_loadmore',
			[
				'label' => __( 'Number of posts to show before load more button.', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '4',
				'description' => __( 'Ex: 4', 'bauen-plugin' ),
				'label_block' => true,
				'condition' => [
					'post_pagination' => 'st2',
				],
			]
		);
		$this->add_control(
			'load_btn_text_translate',
			[
				'label' => __( 'Load More Text', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Load More',
				'description' => __( 'Translate Option.', 'bauen-plugin' ),
				'label_block' => true,
				'condition' => [
					'post_pagination' => 'st2',
				],
			]
		);	
		
		$this->add_control(
			'grid_column',
			[
				'label' => __( 'Grid Column', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'col-md-6' => '1/2 Column',
					'col-md-4' => '1/3 Column',
					'col-md-3' => '1/4 Column',
					'col-md-12' => '1/1 Column',
				],
				'default' => 'col-md-4',
				'label_block' => true,
			]
		);

		$this->add_control(
			'post_theme_lightbox',
			[
				'label' => esc_html__( 'Default Lightbox', 'bauen-plugin' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'On', 'bauen-plugin' ),
				'label_off' => esc_html__( 'Off', 'bauen-plugin' ),
				'description' => __( 'Not affected for video popup.', 'bauen-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		
		$repeater->add_control(
			'image',
			[
				'label' => __( 'Image', 'bauen-plugin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => '',
				],
				'label_block' => true,
			]
		);	
		
		$repeater->add_control(
			'style_type',
			[
				'label' => __( 'Style Type', 'bauen-plugin' ),
				'description' => __( 'Select tab style type.', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'st1' => 'PopUp Image',
					'st2' => 'PopUp Video',
				],
				'default' => 'st1',
				'label_block' => true,
			]
		);				

		$repeater->add_control(
			'video', [
				'label' => __( 'Video URL', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'description' => __( 'Insert video URL in format: https://youtu.be/RziCmLzpFNY  <br> https://vimeo.com/449554367', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'style_type' => 'st2',
					'image[url]!' => '',
				],				
			]
		);		
		
		$this->add_control(
			'bauen_gallery_images',
			[
				'label' => __( 'Image Gallery', 'bauen-plugin' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'image' => __('', 'bauen-plugin'),
					],
				],
			]
		);	

		$this->end_controls_section();
		
		$this->start_controls_section(
			'port_overlay',
			[
				'label' => __( 'Hover Overlay', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'port_overlay',
				'label' => esc_html__( 'Overlay Color', 'bauen-plugin' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .gallery-box:hover .gallery-img:after',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_form_button',
			[
				'label' => __( 'Button', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'button_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .butn-dark a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'button_color_hover',
			[
				'label' => __( 'Color Hover', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .butn-dark a:hover span' => 'color: {{VALUE}};',
				],
			]
		);		
		$this->add_control(
			'button_background',
			[
				'label' => __( 'Background Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .butn-dark a, {{WRAPPER}} button' => 'background: {{VALUE}};',
				],
			]
		);		
		$this->add_control(
			'button_background_hover',
			[
				'label' => __( 'Background Color Hover', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .butn-dark a:after, {{WRAPPER}} button:hover' => 'background: {{VALUE}};',
				],
			]
		);		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_typo',
				'selector' => '{{WRAPPER}} .butn-dark a',
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_popup_button',
			[
				'label' => __( 'Popup Button', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'popup_button_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .video-gallery-polygon' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'popup_button_color_hover',
			[
				'label' => __( 'Color Hover', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .video-gallery-polygon:hover' => 'color: {{VALUE}};',
				],
			]
		);		
		$this->add_control(
			'popup_button_background',
			[
				'label' => __( 'Border Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .video-gallery-polygon' => 'border-color: {{VALUE}};',
				],
			]
		);		
		$this->add_control(
			'popup_button_background_hover',
			[
				'label' => __( 'Background Color Hover', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .video-gallery-polygon:hover' => 'background-color: {{VALUE}}; border-color: {{VALUE}};',
					
				],
			]
		);	

		$this->end_controls_section();
		

	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>
		
		<?php if ( $settings['post_pagination'] == 'st2' ) { 
			$load_main_count= $settings['post_show_before_loadmore'];
		}
		else {
			$load_main_count='10000000';
		}
		?>
		<div class="container-after-gallery">
		<div class="row isotope-items-wrap  no-hide-last loadmore-wrapper-gallery sec-gallery" data-load-item="<?php echo esc_attr($load_main_count); ?>" data-button-text="<?php echo esc_attr($settings['load_btn_text_translate']); ?>">	
			<?php foreach( $settings['bauen_gallery_images'] as $bauen_gallery_image ) { ?>
			<?php $caption = wp_get_attachment_caption( $bauen_gallery_image['image']['id'] );?>
			    <?php if( $bauen_gallery_image['style_type'] == 'st2' ) { ?>
					<div class="<?php echo esc_attr($settings['grid_column']); ?> vid-area pt-30 isotope-item">
						<div class="vid-icon">
							<img src="<?php echo esc_url($bauen_gallery_image['image']['url']); ?> " alt="<?php echo esc_attr($bauen_gallery_image['image']['alt']); ?>"/>								 
							<a href="<?php echo esc_url($bauen_gallery_image['video']); ?>" class="video-gallery-button vid"> <span class="video-gallery-polygon"> <i class="ti-control-play"></i> </span> </a>								 
						</div>																		
					</div>			
				<?php } 
				else { ?>				
					<div class="<?php echo esc_attr($settings['grid_column']); ?> gallery-item isotope-item ">
						
						<a href="<?php echo esc_url($bauen_gallery_image['image']['url']); ?>" title="<?php echo esc_attr($caption);?>" <?php if ( 'yes' === $settings['post_theme_lightbox'] ) { ?>class="img-zoom-gallery"<?php } ;?>>
							<div class="gallery-box">
								<div class="gallery-img"> 
								<img src="<?php echo esc_url($bauen_gallery_image['image']['url']); ?> " alt="<?php echo esc_attr($bauen_gallery_image['image']['alt']); ?>"/>
								</div>
							</div>									
						</a>
						
					</div>
			    <?php } ;?>	
			<?php } ;?>	
		</div>		
		</div>		

        <?php		

	}

}