<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Bauen_Image_Slider extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-image-slider';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen Image Slider', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-slider-album';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-addons' ];
 	}
	
	/**
	 * A list of scripts that the widgets is depended in
	 **/
	public function get_script_depends() {
		return [ 
			'owl-carousel',
			'elementor-image-slider',
		 ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
			]
		);
		$this->add_control(
			'gallery',
			[
				'label' => esc_html__( 'Add Images', 'bauen-plugin' ),
				'type' => \Elementor\Controls_Manager::GALLERY,
				'default' => [],
				'description' => __( 'Upload same size images.', 'bauen-plugin' ),
			]
		);		
		$repeater = new \Elementor\Repeater();
		
		$repeater->add_control(
			'data_title', [
				'label' => __( 'Data Title', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Project Year' , 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);	

		$repeater->add_control(
			'data_content', [
				'label' => __( 'Data Content', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '2020 - 2022' , 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);

		$repeater->add_control(
			'data_url', [
				'label' => __( 'Custom URL', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '' , 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);	

		$repeater->add_control(
			'data_target',
			[
				'label' => __( 'Link Target', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'_self' => 'Self',
					'_blank' => 'Blank',
					'_parent' => 'Parent',
					'_top' => 'Top',
				],
				'default' => '_self',
				'label_block' => true,
			]
		);

		$this->add_control(
			'bn_slider_info',
			[
				'label' => esc_html__( 'Slider Information', 'bauen-plugin' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_off' => esc_html__( 'Off', 'bauen-plugin' ),
				'label_on' => esc_html__( 'On', 'bauen-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'bauen_sliders',
			[
				'label' => __( 'Slider Info Item', 'bauen-plugin' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
									
				],
				'conditions' => [
					'terms' => [
						[
							'name' => 'bn_slider_info',
							'operator' => 'in',
							'value' => [
								'yes',
							],
						],
					],
				],
			]
		);

		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_settings',
			[
				'label' => __( 'Carousel Settings', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'slider_nav',
			[
				'label' => __( 'Carousel Navigation', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'true' => 'Enable',
					'false' => 'Disable',
				],
				'default' => 'true',
				'label_block' => true,
			]			
		);
		
		$this->add_control(
			'navination_color',
			[
				'label' => __( 'Navigation Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-page .owl-theme .owl-nav [class*=owl-]' => 'border-color: {{VALUE}};',
				],
				'default' =>'',
				'condition' => [
					'slider_nav' => 'true',
				],				
			]
		);	
		$this->add_control(
			'navination__icon_color',
			[
				'label' => __( 'Navigation Icon Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-page .owl-theme .owl-nav [class*=owl-]' => 'color: {{VALUE}};',
				],
				'default' =>'',
				'condition' => [
					'slider_nav' => 'true',
				],				
			]
		);	
		$this->end_controls_section();
		
		
		
		$this->start_controls_section(
			'section_style_main_content_bar',
			[
				'label' => __( 'Info Bar', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'data_bar_color',
			[
				'label' => __( 'Background Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-bar' => 'background-color: {{VALUE}};',
				],				
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_main_title',
			[
				'label' => __( 'Data Title', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'data_title_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-bar h5' => 'color: {{VALUE}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'data_title_typography',
				'selector' => '{{WRAPPER}} .project-bar h5',
			]
		);	
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_main_content',
			[
				'label' => __( 'Data Content', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'data_content_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-page h6' => 'color: {{VALUE}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'data_content_typography',
				'selector' => '{{WRAPPER}} .project-page h6',
			]
		);	
		
		$this->end_controls_section();
		
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>
		<div class="project-page">
			<div class="rows justify-content-center">
				<div class="owl-carousel owl-theme bn-image-car-class" data-projects-nav="<?php echo esc_attr($settings['slider_nav']); ?>" <?php if ( is_rtl() ) { ?>data-rtl="true"<?php } else { ?>data-rtl="false"<?php } ;?>>
					<?php foreach ( $settings['gallery'] as $bauen_image ) { ?>
					<div class="portfolio-item"> <img class="img-fluid" src="<?php echo esc_url($bauen_image['url']);?>" alt=""> </div>
					<?php } ;?>
				</div>
				<?php if ( 'yes' === $settings['bn_slider_info'] ) {?>
				<?php if ( $settings['bauen_sliders'] ) { ?>
				<div class="row">
					 <div class="col-md-8 offset-md-4">
						<div class="project-bar">
							<div class="row justify-content-between align-items-center text-left text-lg-start">
							<?php foreach( $settings['bauen_sliders'] as $bauen_testimonial ) { ?>
								<div class="col-md-3 mb-0">
								<?php if ( $bauen_testimonial['data_url'] ) { ?>
								<a href="<?php echo esc_html($bauen_testimonial['data_url']); ?>" target="<?php echo esc_attr($bauen_testimonial['data_target']); ?>">
								<?php } ;?>
								<?php if ( $bauen_testimonial['data_title'] ) { ?>
									<h5><?php echo esc_html($bauen_testimonial['data_title']); ?></h5>
								<?php } ;?>
								<?php if ( $bauen_testimonial['data_content'] ) { ?>
									<h6><?php echo esc_html($bauen_testimonial['data_content']); ?></h6>
								<?php } ;?>
								<?php if ( $bauen_testimonial['data_url'] ) { ?>
								</a>
								<?php } ;?>
								</div>
							<?php } ;?>
							</div>
						</div>
					</div>
				</div>
				<?php } ;?>
				<?php } ;?>
			</div>
		</div>
        <?php		

	}

}