<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Bauen_Image extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-image';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen Image', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-image';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-addons' ];
 	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_image',
			[
				'label' => __( 'Image', 'bauen-plugin' ),
			]
		);
		$this->add_control(
			'style_type',
			[
				'label' => __( 'Style Type', 'bauen-plugin' ),
				'description' => __( 'Select heading style type.', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'st1' => 'Style 1',
					'st2' => 'Style 2',
				],
				'default' => 'st1',
				'label_block' => true,
			]
		);			
		$this->add_control(
			'image',
			[
				'label' => __( 'Image', 'bauen-plugin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => '',
				],
				'label_block' => true,			
			]
		);
		
		$this->add_control(
			'caption',
			[
				'label' => __( 'Image Caption', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'style_type' => 'st1',
					'image[url]!' => '',
				],					
			]
		);		
		
		$this->add_control(
			'button_url',
			[
				'label' => __( 'Custom URL', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
                'condition' => [
					'image[url]!' => '',
				],
			]
		);
		
		$this->add_control(
			'button_target',
			[
				'label' => __( 'Custom URL Target', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'_self' => 'Self',
					'_blank' => 'Blank',
					'_parent' => 'Parent',
					'_top' => 'Top',
				],
				'default' => '_self',
				'label_block' => true,
				'condition' => [
					'image[url]!' => '',
				],
			]
		);			
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_caption',
			[
				'label' => __( 'Caption', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'style_type' => 'st1',
				],					
			]
		);

		$this->add_control(
			'caption_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .about-img .about-img-2' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'caption_typography',
				'selector' => '{{WRAPPER}} .about-img .about-img-2',
			]
		);		
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_background',
			[
				'label' => __( 'Background Color', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'style_type' => 'st1',
				],					
			]
		);	
		
		$this->add_control(
			'image_bg_color',
			[
				'label' => __( 'Image Background', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .about .about-img .img:before' => 'background-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);		
		$this->add_control(
			'image_border_color',
			[
				'label' => __( 'Image Border', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .about .about-img .img:before' => 'border-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);	
		$this->add_control(
			'caption_bg_color',
			[
				'label' => __( 'Caption Background', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .about-buro' => 'background-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);	
		
		$this->end_controls_section();
	
		
		
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>
		
		<?php if ( $settings['style_type'] == 'st2' ) { ?>
		
			<div class="sec-img">
			    <?php if ( $settings['button_url'] ) { ?>
				<a href="<?php echo esc_url($settings['button_url']); ?>" target="<?php echo esc_attr($settings['button_target']); ?>" rel="noopener noreferrer">
				<?php } ;?>			
				 <img src="<?php echo esc_url($settings['image']['url']); ?>" class="img-responsive" alt="<?php echo esc_attr($settings['image']['alt']); ?>"> 
				<?php if ( $settings['button_url'] ) { ?>
				</a>
				<?php } ;?>	
			</div>
		
		<?php } 
		else { ?>	
		
			<div class="about">
				<div class="about-img">
					<?php if ( $settings['button_url'] ) { ?>
					<a href="<?php echo esc_url($settings['button_url']); ?>" target="<?php echo esc_attr($settings['button_target']); ?>" rel="noopener noreferrer">
					<?php } ;?>			
					<div class="img"> <img src="<?php echo esc_url($settings['image']['url']); ?>" class="img-fluid" alt="<?php echo esc_attr($settings['image']['alt']); ?>"> </div>
					<?php if ( $settings['button_url'] ) { ?>
					</a>
					<?php } ;?>					
					<?php if ( $settings['caption'] ) { ?>
					<div class="about-img-2 about-buro"><?php echo do_shortcode($settings['caption']); ?></div>
					<?php };?>
				</div>		
			</div>	

	    <?php } ;?>			
		
			
        <?php
		

	}

}