<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Bauen_List_Icon extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-list-icon';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen List Item', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-editor-list-ul';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-addons' ];
 	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
			]
		);
		
		$repeater = new \Elementor\Repeater();
		
		$repeater->add_control(
			'icon_class',
			[
				'label' => esc_html__( 'Icon', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'ti-check',
					'library' => 'solid',
				],
				
                'skin' =>'inline',
				'label_block' => false,
			]
		);
		
		$repeater->add_control(
			'title',
			[
				'label' => __( 'List Item', 'tank-plugin' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => '',
				'description' => __( 'Ex: Over 15 years of experience', 'bauen-plugin' ),
				'dynamic' => [
					'active' => true,
				],
			]
		);
		$this->add_control(
			'bauen_lists',
			[
				'label' => __( 'List Items', 'bauen-plugin' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
									
				],
			]
		);	

		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_icon',
			[
				'label' => __( 'Icon', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'icon_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .page-list-icon i' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		
		$this->add_control(
			'icon_border_color',
			[
				'label' => __( 'Border Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .page-list-icon i' => 'border-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		
			
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_text',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'content_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .page-list-text p' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'text_typography',
				'selector' => '{{WRAPPER}} .page-list-text p',
			]
		);
		$this->end_controls_section();
	
		
		
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>
		
         <ul class="list-unstyled page-list mb-30">	
			<?php foreach( $settings['bauen_lists'] as $bauen_list ) { ?>
				<li>
                    <?php if ( $bauen_list['icon_class'] ) { ?>
					<div class="page-list-icon"> <?php \Elementor\Icons_Manager::render_icon( $bauen_list['icon_class'], [ 'aria-hidden' => 'true' ] ); ?> </div>
					<?php } ;?>
                    <div class="page-list-text">
                        <p><?php echo do_shortcode($bauen_list['title']); ?></p>
                    </div>
                </li>
			<?php } ;?>		
		</ul>
			
        <?php
		

	}

}