<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;
//use Elementor\WP_Query;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Bauen_Portfolio_Carousel extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-portfolio-carousel';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen Portfolio Carousel', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-slider-3d';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-addons' ];
 	}
	
	/**
	 * A list of scripts that the widgets is depended in
	 **/
	public function get_script_depends() {
		return [ 
			'owl-carousel',
			'elementor-portfolio-carousel',			
		 ];
	}	

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Post Options', 'bauen-plugin' ),
			]
		);	
		$this->add_control(
			'postcount', [
				'label' => __( 'Number of posts to show', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '6' , 'bauen-plugin' ),
				'description' => __( '(Optional) Insert number of post show in format: 8', 'bauen-plugin' ),
				'label_block' => true,
			]
		);		
		$this->add_control(
			'categoryname', [
				'label' => __( 'Include Category', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '' , 'bauen-plugin' ),
				'description' => __( '(Optional) Insert category name in format: Graphic', 'bauen-plugin' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'categoryname_exclude', [
				'label' => __( 'Exclude Category Information', 'tank-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '' , 'tank-plugin' ),
				'description' => __( 'Exclude category information from the portfolio list by the category ID Ex: 6 <br>For multiple category ID Ex: 6 7', 'bauen-plugin' ),
				'label_block' => true,
			]
		);		
		$this->add_control(
			'postoffset', [
				'label' => __( 'Post Offset', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '' , 'bauen-plugin' ),
				'description' => __( '(Optional)', 'bauen-plugin' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'image_resize',
			[
				'label' => esc_html__( 'Image Resize', 'candore-plugin' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'On', 'candore-plugin' ),
				'label_off' => esc_html__( 'Off', 'candore-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		
		$this->add_control(
			'icon_type',
			[
				'label' => __( 'Icon Type', 'bauen-plugin' ),
				'description' => __( 'Select icon type.', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'st1' => 'Themify',
					'st2' => 'Fontawesome',
				],
				'default' => 'st1',
				'label_block' => true,
			]
		);	
		$this->add_control(
			'icon_class2',
			[
				'label' => __( 'Icon Class', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'ti-arrow-right',
				'description' => __( 'Insert <strong><a href="https://themify.me/themify-icons" target="_blank">Themify</a></strong> Icon Class here. Ex: ti-arrow-right ', 'bauen-plugin' ),
				'label_block' => true,
				'condition' => [
					'icon_type' => 'st1',
				],				
			]
		);			
        $this->add_control(
			'icon_class',
			[
				'label' => esc_html__( 'Icon', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fa fa-arrow-right',
					'library' => 'solid',
				],
                'skin' =>'inline',
				'label_block' => false,
				'exclude_inline_options' => [ 'svg' ],
				'condition' => [
					'icon_type' => 'st2',
				],				
			]
		);				
        $this->add_control(
			'title_tag',
			[
				'label' => __( 'Title Tag', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'1' => 'h1',
					'2' => 'h2',
					'3' => 'h3',
					'4' => 'h4',
					'5' => 'h5',
					'6' => 'h6',
				],
				'default' => '5',
				'label_block' => true,
			]
		);	

		$this->end_controls_section();
		
				
		
		$this->start_controls_section(
			'section_style_settings',
			[
				'label' => __( 'Carousel Settings', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,					
			]
		);
		
		$this->add_control(
			'style_car_column',
			[
				'label' => __( 'Carousel Columns', 'bauen-plugin' ),
				'description' => __( 'Select style type.', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'3' => '3 Columns',
					'2' => '2 Columns',
					'1' => '1 Column',
				],
				'default' => '2',
				'label_block' => true,
			]
		);
		
		$this->add_control(
			'data_car_loop',
			[
				'label' => __( 'Carousel Loop', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'true' => 'Enable',
					'false' => 'Disable',
				],
				'default' => 'true',
				'label_block' => true,
			]			
		);
		
		$this->add_control(
			'projects_autoplay',
			[
				'label' => __( 'Carousel Autoplay', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'true' => 'Enable',
					'false' => 'Disable',
				],
				'default' => 'false',
				'label_block' => true,
			]			
		);	

		$this->add_control(
			'projects_autoplay_speed',
			[
				'label' => __( 'Autoplay Timeout', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '5000',
				'description' => __( 'Default: 5000', 'bauen-plugin' ),
				'label_block' => true,
				'condition' => [
					'projects_autoplay' => 'true',
				],
			]
		);
		
		$this->add_control(
			'projects_speed',
			[
				'label' => __( 'Carousel Speed', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '500',
				'description' => __( 'Ex: 500', 'bauen-plugin' ),
				'label_block' => true,
				'condition' => [
					'projects_autoplay' => 'true',
				],
			]
		);
		$this->add_control(
			'slider_nav',
			[
				'label' => __( 'Carousel Navigation', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'true' => 'Enable',
					'false' => 'Disable',
				],
				'default' => 'false',
				'label_block' => true,
			]			
		);	
		$this->add_control(
			'navination_color',
			[
				'label' => __( 'Navigation Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .projects .owl-theme .owl-nav [class*=owl-]' => 'border-color: {{VALUE}};',
				],
				'default' =>'',
				'condition' => [
					'slider_nav' => 'true',
				],				
			]
		);	
		$this->add_control(
			'navination__icon_color',
			[
				'label' => __( 'Navigation Icon Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .projects .owl-theme .owl-nav [class*=owl-]' => 'color: {{VALUE}};',
				],
				'default' =>'',
				'condition' => [
					'slider_nav' => 'true',
				],				
			]
		);			
		
		$this->add_control(
			'slider_pagination',
			[
				'label' => __( 'Carousel Pagination', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'true' => 'Enable',
					'false' => 'Disable',
				],
				'default' => 'true',
				'label_block' => true,
			]			
		);
		$this->add_control(
			'slider_desktop_pagination',
			[
				'label' => __( 'Desktop Pagination', 'bauen-plugin' ),
				'description' => __( 'Enable/ Disable pagination for desktop version.', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'true' => 'Enable',
					'false' => 'Disable',
				],
				'default' => 'true',
				'label_block' => true,
			]			
		);
		$this->add_control(
			'pagination_color',
			[
				'label' => __( 'Pagination Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .owl-theme .owl-dots .owl-dot span' => 'border-color: {{VALUE}};',
				],
				'default' =>'',
				'condition' => [
					'slider_pagination' => 'true',
				],				
			]
		);	
		$this->add_control(
			'pagination_color_hv',
			[
				'label' => __( 'Pagination Hover Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .owl-theme .owl-dots .owl-dot.active span' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .owl-theme .owl-dots .owl-dot:hover span' => 'border-color: {{VALUE}};',
				],
				'default' =>'',
				'condition' => [
					'slider_pagination' => 'true',
				],				
			]
		);	

		$this->end_controls_section();							
		
		$this->start_controls_section(
			'port_overlay',
			[
				'label' => __( 'Portfolio Overlay', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'port_overlay',
				'label' => esc_html__( 'Item Overlay', 'bauen-plugin' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .projects .item .con',
			]
		);
		
		$this->add_control(
			'overlay_height',
			[
				'label' => __( 'Overlay Height', 'bauen-plugin' ),
				'description' => __( 'Select overlay height.', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'overlay-full-auto' => 'Default',
					'overlay-full-height' => 'Full Height',
				],
				'default' => 'overlay-full-auto',
				'label_block' => true,
				
			]
		);
		
		$this->end_controls_section();		
		
		$this->start_controls_section(
			'port_item',
			[
				'label' => __( 'Title', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);			
				
		$this->add_control(
			'title_color',
			[
				'label' => __( 'Title Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .projects .item .con h1.title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h2.title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h3.title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h4.title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h5.title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h6.title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h1.title a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h2.title a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h3.title a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h4.title a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h5.title a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h6.title a' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);	
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .projects .item .con h1.title, {{WRAPPER}} .projects .item .con h2.title, {{WRAPPER}} .projects .item .con h3.title, {{WRAPPER}} .projects .item .con h4.title, {{WRAPPER}} .projects .item .con h5.title, {{WRAPPER}} .projects .item .con h6.title, {{WRAPPER}} .projects .item .con h1.title a, {{WRAPPER}} .projects .item .con h2.title a, {{WRAPPER}} .projects .item .con h3.title a, {{WRAPPER}} .projects .item .con h4.title a, {{WRAPPER}} .projects .item .con h5.title a, {{WRAPPER}} .projects .item .con h6.title a',
			]
		);	

		$this->add_control(
			'icon_color',
			[
				'label' => __( 'Icon Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .projects .item .con i' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_control(
			'icon_color_hv',
			[
				'label' => __( 'Icon Hover Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .projects .item .con i:hover' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'port_item_cat',
			[
				'label' => __( 'Category', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);	
		$this->add_control(
			'meta_info_color',
			[
				'label' => __( 'Category Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .projects .item .con h6.category' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h6.category a' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'meta_info_typography',
				'selector' => '{{WRAPPER}} .projects .item .con h6.category, {{WRAPPER}} .projects .item .con h6.category a',
			]
		);	

		$this->end_controls_section();
								
		
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>

		<div class="sec-portfolio projects">
            <div class="owl-carousel owl-theme" data-projects-autoplay="<?php echo esc_attr($settings['projects_autoplay']); ?>" data-projects-speed="<?php echo esc_attr($settings['projects_speed']); ?>" data-projects-nav="<?php echo esc_attr($settings['slider_nav']); ?>" data-projects-dots="<?php echo esc_attr($settings['slider_pagination']); ?>" data-post-item="<?php echo esc_attr($settings['style_car_column']); ?>" data-bn-car-loop="<?php echo esc_attr($settings['data_car_loop']); ?>" data-projects-autoplay-timeout="<?php echo esc_attr($settings['projects_autoplay_speed']); ?>" data-carousel-dots-desktop="<?php echo esc_attr($settings['slider_desktop_pagination']); ?>" <?php if ( is_rtl() ) { ?>data-rtl="true"<?php } else { ?>data-rtl="false"<?php } ;?>>				
			<?php
			global $post, $bauen_image;
			$paged=(get_query_var('paged'))?get_query_var('paged'):1;
			$loop = new \WP_Query( array( 'post_type' => 'portfolio','portfolio_category'=> $settings['categoryname'], 'posts_per_page'=> $settings['postcount'], 'post_status' => 'publish', 'offset' => $settings['postoffset']) );
			while ( $loop->have_posts() ) : $loop->the_post();
			$bauen_portfolio_category = wp_get_post_terms($post->ID,'portfolio_category', array('exclude' => $settings['categoryname_exclude']));
			$bauen_class = ""; 
			$bauen_categories = ""; 
			foreach ($bauen_portfolio_category as $bauen_item) {
				$bauen_class.=esc_attr($bauen_item->slug . ' ');
				$bauen_categories.='<span class="cat-divider">';
				$bauen_categories.=esc_attr($bauen_item->name . '  ');
				$bauen_categories.='</span>';
			}			
			if (has_post_thumbnail( $post->ID ) ):
			$bauen_image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), '' );
			?>	<a href="<?php the_permalink();?>" <?php if ( 'yes' === $settings['image_resize'] ) { ?>class="position-re-block"<?php } ;?>>		
				    <div class="item">				    
						<?php if ( 'yes' === $settings['image_resize'] ) { ?>
						<div class="position-re position-re-order-carousel o-hidden">
							<div class="cd-pt-ab">
							<img src="<?php echo esc_url($bauen_image[0]);?>" alt="<?php the_title();?>">
							</div>
						</div>
						<?php } else { ?>
						<div class="position-re o-hidden">
							<img src="<?php echo esc_url($bauen_image[0]);?>" alt="<?php the_title();?>">
						</div>
						<?php } ;?>						
						<div class="con <?php echo esc_attr($settings['overlay_height']); ?>">
							<h6 class="category"><?php echo do_shortcode($bauen_categories);?></h6>
							<h<?php echo esc_attr($settings['title_tag']); ?> class="title bn-post-title-grid"><?php the_title();?></h<?php echo esc_attr($settings['title_tag']); ?>>
							<div class="line"></div> 
							<?php if ( $settings['icon_type'] == 'st2' ) { ?>
								<?php \Elementor\Icons_Manager::render_icon( $settings['icon_class'], [ 'aria-hidden' => 'true' ] ); ?>
							<?php } 
							else { ?>	
								<i class="<?php echo esc_attr($settings['icon_class2']); ?>"></i>
							<?php } ;?>							
						</div>					
				    </div>	
				</a> 		
			<?php
			endif;
			endwhile;
			wp_reset_postdata();
			?>
			</div>			
		</div>
		
        <?php
		

	}

}