<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;
//use Elementor\WP_Query;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Bauen_Portfolio_Grid extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-portfolio-grid';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen Portfolio Grid', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-gallery-grid';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-addons' ];
 	}
	
	/**
	 * A list of scripts that the widgets is depended in
	 **/
	public function get_script_depends() {
		return [ 		
			'isotope',
			'imagesloaded',
			'elementor-load-more',
		 ];
	}	

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Post Options', 'bauen-plugin' ),
			]
		);	
		
		$this->add_control(
			'grid_style',
			[
				'label' => __( 'Grid Style', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'st1' => 'Default',
					'st2' => 'Fancy',
				],
				'default' => 'st1',
				'label_block' => true,
			]			
		);	
		
		$this->add_control(
			'col_size',
			[
				'label' => __( 'Grid Column', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'col-md-6' => '1/2 Column',
					'col-md-4' => '1/3 Column',
					'col-md-3' => '1/4 Column',
					'col-md-12' => '1/1 Column',
				],
				'default' => 'col-md-6',
				'label_block' => true,
			]			
		);	
		
		$this->add_control(
			'post_pagination',
			[
				'label' => __( 'Load More Button', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'st1' => 'Disable',
					'st2' => 'Enable',
				],
				'default' => 'st1',
				'label_block' => true,
			]			
		);		
		$this->add_control(
			'post_show_before_loadmore',
			[
				'label' => __( 'Number of posts to show before load more button.', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '4',
				'description' => __( 'Ex: 4', 'bauen-plugin' ),
				'label_block' => true,
				'condition' => [
					'post_pagination' => 'st2',
				],
			]
		);
		$this->add_control(
			'load_btn_text_translate',
			[
				'label' => __( 'Load More Text', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Load More',
				'description' => __( 'Translate Option.', 'bauen-plugin' ),
				'label_block' => true,
				'condition' => [
					'post_pagination' => 'st2',
				],
			]
		);	
		
		$this->add_control(
			'enable_filter',
			[
				'label' => __( 'Portfolio Filter', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'st1' => 'Disable',
					'st2' => 'Enable',
				],
				'default' => 'st1',
				'label_block' => true,
			]
		);
		
		$this->add_control(
			'port_filter_cat_count', [
				'label' => __( 'Number of categories to show', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '' , 'bauen-plugin' ),
				'description' => __( 'Number of categories to show in portfolio filter list. e.x: 5', 'bauen-plugin' ),
				'label_block' => true,
				'condition' => [
					'enable_filter' => 'st2',
				],
			]
		);
		
		$this->add_control(
			'port_filter_cat_exclude', [
				'label' => __( 'Exclude category', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '' , 'bauen-plugin' ),
				'description' => __( 'Exclude category from the filter list by the category ID e.x: 6 <br>For multiple category ID e.x: 6 7', 'bauen-plugin' ),
				'label_block' => true,
				'condition' => [
					'enable_filter' => 'st2',
				],
			]
		);
		
		
		$this->add_control(
			'text_filter', [
				'label' => __( 'All Project', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'All Project' , 'bauen-plugin' ),
				'description' => __( 'Translet Option.', 'bauen-plugin' ),
				'label_block' => true,
				'condition' => [
					'enable_filter' => 'st2',
				],
			]
		);
		
		$this->add_control(
			'postcount', [
				'label' => __( 'Number of posts to show', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '6' , 'bauen-plugin' ),
				'description' => __( '(Optional) Insert number of post show in format: 8', 'bauen-plugin' ),
				'label_block' => true,
			]
		);		
		$this->add_control(
			'categoryname', [
				'label' => __( 'Include Category', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '' , 'bauen-plugin' ),
				'description' => __( '(Optional) Insert category name in format: Graphic', 'bauen-plugin' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'categoryname_exclude', [
				'label' => __( 'Exclude Category Information', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '' , 'bauen-plugin' ),
				'description' => __( 'Exclude category information from the portfolio item info. Ex: 6 <br>For multiple category ID Ex: 6 7', 'bauen-plugin' ),
				'label_block' => true,
			]
		);		
		$this->add_control(
			'postoffset', [
				'label' => __( 'Post Offset', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '' , 'bauen-plugin' ),
				'description' => __( '(Optional)', 'bauen-plugin' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'image_resize',
			[
				'label' => esc_html__( 'Image Resize', 'candore-plugin' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'On', 'candore-plugin' ),
				'label_off' => esc_html__( 'Off', 'candore-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
				'condition' => [
					'grid_style' => 'st1',
				],
			]
		);
		
		
		$this->add_control(
			'icon_type',
			[
				'label' => __( 'Icon Type', 'bauen-plugin' ),
				'description' => __( 'Select icon type.', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'st1' => 'Themify',
					'st2' => 'Fontawesome',
				],
				'default' => 'st1',
				'label_block' => true,
				'condition' => [
					'grid_style' => 'st1',
				],
			]
		);	
		$this->add_control(
			'icon_class2',
			[
				'label' => __( 'Icon Class', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'ti-arrow-right',
				'description' => __( 'Insert <strong><a href="https://themify.me/themify-icons" target="_blank">Themify</a></strong> Icon Class here. Ex: ti-arrow-right ', 'bauen-plugin' ),
				'label_block' => true,
				'condition' => [
					'icon_type' => 'st1',
				],				
			]
		);			
        $this->add_control(
			'icon_class',
			[
				'label' => esc_html__( 'Icon', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fa fa-arrow-right',
					'library' => 'solid',
				],
                'skin' =>'inline',
				'label_block' => false,
				'exclude_inline_options' => [ 'svg' ],
				'condition' => [
					'icon_type' => 'st2',
				],				
			]
		);				
        $this->add_control(
			'title_tag',
			[
				'label' => __( 'Title Tag', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'1' => 'h1',
					'2' => 'h2',
					'3' => 'h3',
					'4' => 'h4',
					'5' => 'h5',
					'6' => 'h6',
				],
				'default' => '5',
				'label_block' => true,
			]
		);

		$this->end_controls_section();							
		
		$this->start_controls_section(
			'port_overlay',
			[
				'label' => __( 'Portfolio Overlay', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'grid_style' => 'st1',
				],
			]
		);
		
		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'port_overlay',
				'label' => esc_html__( 'Item Overlay', 'bauen-plugin' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .projects .item .con',
			]
		);
		
		$this->add_control(
			'overlay_height',
			[
				'label' => __( 'Overlay Height', 'bauen-plugin' ),
				'description' => __( 'Select overlay height.', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'overlay-full-auto' => 'Default',
					'overlay-full-height' => 'Full Height',
				],
				'default' => 'overlay-full-auto',
				'label_block' => true,
			]
		);

		$this->end_controls_section();							
		
		$this->start_controls_section(
			'port_item',
			[
				'label' => __( 'Portfolio Title', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
				'new_sec_back',
				[
					'label' => __( 'Section Background', 'bauen-plugin' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .bauen-project-content' => 'background-color: {{VALUE}};',
					],
					'default' =>'',
					'condition' => [
						'grid_style' => 'st2',
					],
				]
		);			
				
		$this->add_control(
			'title_color',
			[
				'label' => __( 'Title Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .projects .item .con h1.title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h2.title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h3.title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h4.title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h5.title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h6.title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h1.title a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h2.title a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h3.title a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h4.title a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h5.title a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h6.title a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bu-post-title' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .projects .item .con h1.title, {{WRAPPER}} .projects .item .con h2.title, {{WRAPPER}} .projects .item .con h3.title, {{WRAPPER}} .projects .item .con h4.title, {{WRAPPER}} .projects .item .con h5.title, {{WRAPPER}} .projects .item .con h6.title, {{WRAPPER}} .projects .item .con h1.title a, {{WRAPPER}} .projects .item .con h2.title a, {{WRAPPER}} .projects .item .con h3.title a, {{WRAPPER}} .projects .item .con h4.title a, {{WRAPPER}} .projects .item .con h5.title a, {{WRAPPER}} .projects .item .con h6.title a, {{WRAPPER}} .bu-post-title',
			]
		);	

		$this->add_control(
			'icon_color',
			[
				'label' => __( 'Icon Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .projects .item .con i' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_control(
			'icon_color_hv',
			[
				'label' => __( 'Icon Hover Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .projects .item .con i:hover' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'port_item_cat',
			[
				'label' => __( 'Category', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);	
		$this->add_control(
			'meta_info_color',
			[
				'label' => __( 'Category Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .projects .item .con h6.category' => 'color: {{VALUE}};',
					'{{WRAPPER}} .projects .item .con h6.category a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-project-wrap p' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'meta_info_typography',
				'selector' => '{{WRAPPER}} .projects .item .con h6.category, {{WRAPPER}} .projects .item .con h6.category a, {{WRAPPER}} .bauen-project-wrap p',
			]
		);	

		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_form_button',
			[
				'label' => __( 'Button', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'button_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .butn-dark a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'button_color_hover',
			[
				'label' => __( 'Color Hover', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .butn-dark a:hover span' => 'color: {{VALUE}};',
				],
			]
		);		
		$this->add_control(
			'button_background',
			[
				'label' => __( 'Background Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .butn-dark a, {{WRAPPER}} button' => 'background: {{VALUE}};',
				],
			]
		);		
		$this->add_control(
			'button_background_hover',
			[
				'label' => __( 'Background Color Hover', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .butn-dark a:after, {{WRAPPER}} button:hover' => 'background: {{VALUE}};',
				],
			]
		);		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_typo',
				'selector' => '{{WRAPPER}} .butn-dark a',
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'port_filter_nav',
			[
				'label' => __( 'Filter Navigation', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'enable_filter' => 'st2',
				],
			]
			
		);	
		$this->add_control(
			'port_filter_nav_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .gallery-filters li' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_control(
			'port_filter_nav_color_active',
			[
				'label' => __( 'Active/ Hover Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .gallery-filters li:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .gallery-filters li.active' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'port_filter_nav_typography',
				'selector' => '{{WRAPPER}} .gallery-filters li',
			]
		);
					
		$this->end_controls_section();
									
		
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>

		<div class="sec-portfolio projects"> 
		<?php 
		//filter start
		if( $settings['enable_filter'] == 'st2' ) { ?>	
		<?php 
		if(!get_post_meta(get_the_ID(), 'portfolio_category', true)):
		$portfolio_category = get_terms('portfolio_category', array('exclude' => $settings['port_filter_cat_exclude'], 'number'=>$settings['port_filter_cat_count'], 'hide_empty'  => true,));
		if($portfolio_category):
		?>
		<div class="text-center col-md-12">
		    <ul class="gallery-filters inline-dark-filters">  
                <li class="gallery-filter active" data-filter="*"><?php echo esc_html($settings['text_filter']); ?></li>
				<?php foreach($portfolio_category as $portfolio_cat) { ?>
                <li class="gallery-filter" data-filter=".<?php echo esc_attr($portfolio_cat->slug);?>"><?php echo esc_attr($portfolio_cat->name);?></li>
				<?php } ;?>
            </ul>
		</div>
		<?php 
		endif;
		endif;
		} ;
		//filter end
		?>
			
			<div class="container-after">
		        <?php if ( $settings['post_pagination'] == 'st2' ) { 
				    $load_main_count= $settings['post_show_before_loadmore'];
				}
			    else {
					$load_main_count='10000000';
				}
				?>
				<div class="row isotope-items-wrap  no-hide-last loadmore-wrapper <?php if ( $settings['grid_style'] == 'st2' ) { ?>bauen-project-items<?php } ;?>" data-load-item="<?php echo esc_attr($load_main_count); ?>" data-button-text="<?php echo esc_attr($settings['load_btn_text_translate']); ?>">	
				
				<?php
				global $post, $bauen_image, $post_show_before_loadmore;
				$bauen_paged=(get_query_var('paged'))?get_query_var('paged'):1;
				$loop = new \WP_Query( array( 'post_type' => 'portfolio','portfolio_category'=> $settings['categoryname'], 'posts_per_page'=> $settings['postcount'], 'post_status' => 'publish', 'offset' => $settings['postoffset'], 'paged'=>$bauen_paged) );
				while ( $loop->have_posts() ) : $loop->the_post();
				if( $settings['enable_filter'] == 'st2' ) {
				$bauen_portfolio_category = wp_get_post_terms($post->ID,'portfolio_category', array('exclude' => $settings['port_filter_cat_exclude']));
				}
				else {
				$bauen_portfolio_category = wp_get_post_terms($post->ID,'portfolio_category', array('exclude' => $settings['categoryname_exclude']));	
				}
				$bauen_class = ""; 
				$bauen_categories = ""; 
				foreach ($bauen_portfolio_category as $bauen_item) {
					$bauen_class.=esc_attr($bauen_item->slug . ' ');
					$bauen_categories.='<span class="cat-divider">';
					$bauen_categories.=esc_attr($bauen_item->name . '  ');
					$bauen_categories.='</span>';
				}			
				if (has_post_thumbnail( $post->ID ) ):
				$bauen_image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), '' );
				?>					
					<?php if ( $settings['grid_style'] == 'st2' ) { ?>
					<div class="isotope-item <?php echo esc_attr($settings['col_size']); ?> <?php echo esc_attr($bauen_class);?>">
                        <div class="bauen-project-wrap">
                            <a href="<?php the_permalink();?>"><img src="<?php echo esc_url($bauen_image[0]);?>" alt="<?php the_title();?>"></a>
                            <div class="bauen-project-content">
                                <p><?php echo do_shortcode($bauen_categories);?></p>
                                <h<?php echo esc_attr($settings['title_tag']); ?> class="bu-post-title"><a href="<?php the_permalink();?>"><?php the_title();?></a></h<?php echo esc_attr($settings['title_tag']); ?>>
                            </div>
                        </div>
                    </div>
					<?php } else {?>
					<div class="isotope-item <?php echo esc_attr($settings['col_size']); ?> <?php echo esc_attr($bauen_class);?>">
					    <a href="<?php the_permalink();?>" <?php if ( 'yes' === $settings['image_resize'] ) { ?>class="position-re-block"<?php } ;?>>
							<div class="item">								
								<?php if ( 'yes' === $settings['image_resize'] ) { ?>
								<div class="position-re position-re-order-carousel o-hidden">
									<div class="cd-pt-ab">
									<img src="<?php echo esc_url($bauen_image[0]);?>" alt="<?php the_title();?>">
									</div>
								</div>
								<?php } else { ?>
								<div class="position-re o-hidden">
									<img src="<?php echo esc_url($bauen_image[0]);?>" alt="<?php the_title();?>">
								</div>
								<?php } ;?>
								<div class="con <?php echo esc_attr($settings['overlay_height']); ?>">
									<h6 class="category"><?php echo do_shortcode($bauen_categories);?></h6>
									<h<?php echo esc_attr($settings['title_tag']); ?> class="title bn-post-title-grid"><?php the_title();?></h<?php echo esc_attr($settings['title_tag']); ?>>
									<div class="line"></div>
									<?php if ( $settings['icon_type'] == 'st2' ) { ?>
										<?php \Elementor\Icons_Manager::render_icon( $settings['icon_class'], [ 'aria-hidden' => 'true' ] ); ?>
									<?php } 
									else { ?>	
										<i class="<?php echo esc_attr($settings['icon_class2']); ?>"></i>
									<?php } ;?>							
								</div>									
							</div>	
						</a>										
					</div>
					<?php } ;?>					
				<?php
				endif;
				endwhile;
				wp_reset_postdata();
				?>					
		        </div> 
		    </div> 			
		</div>
		
        <?php
		

	}

}