<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;
//use Elementor\WP_Query;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Bauen_Portfolio_List extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-portfolio-list';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen Portfolio List', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post-list';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-addons' ];
 	}
	
	/**
	 * A list of scripts that the widgets is depended in
	 **/
	public function get_script_depends() {
		return [ 		
			'isotope',
			'imagesloaded',
			'elementor-portlist-load-more',
		 ];
	}
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Post Options', 'bauen-plugin' ),
			]
		);	
		
		$this->add_control(
			'post_pagination',
			[
				'label' => __( 'Load More Button', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'st1' => 'Disable',
					'st2' => 'Enable',
				],
				'default' => 'st1',
				'label_block' => true,
			]			
		);		
		$this->add_control(
			'post_show_before_loadmore',
			[
				'label' => __( 'Number of posts to show before load more button.', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '4',
				'description' => __( 'Ex: 4', 'bauen-plugin' ),
				'label_block' => true,
				'condition' => [
					'post_pagination' => 'st2',
				],
			]
		);
		$this->add_control(
			'load_btn_text_translate',
			[
				'label' => __( 'Load More Text', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Load More',
				'description' => __( 'Translate Option.', 'bauen-plugin' ),
				'label_block' => true,
				'condition' => [
					'post_pagination' => 'st2',
				],
			]
		);
		
		$this->add_control(
			'postcount', [
				'label' => __( 'Number of posts to show', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '6' , 'bauen-plugin' ),
				'description' => __( '(Optional) Insert number of post show in format: 8', 'bauen-plugin' ),
				'label_block' => true,
			]
		);		
		$this->add_control(
			'categoryname', [
				'label' => __( 'Include Category', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '' , 'bauen-plugin' ),
				'description' => __( '(Optional) Insert category name in format: Graphic', 'bauen-plugin' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'categoryname_exclude', [
				'label' => __( 'Exclude Category Information', 'tank-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '' , 'tank-plugin' ),
				'description' => __( 'Exclude category information from the portfolio list by the category ID Ex: 6 <br>For multiple category ID Ex: 6 7', 'bauen-plugin' ),
				'label_block' => true,
			]
		);		
		$this->add_control(
			'postoffset', [
				'label' => __( 'Post Offset', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '' , 'bauen-plugin' ),
				'description' => __( '(Optional)', 'bauen-plugin' ),
				'label_block' => true,
			]
		);	

					
        $this->add_control(
			'title_tag',
			[
				'label' => __( 'Title Tag', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'1' => 'h1',
					'2' => 'h2',
					'3' => 'h3',
					'4' => 'h4',
					'5' => 'h5',
					'6' => 'h6',
				],
				'default' => '4',
				'label_block' => true,
			]
		);	
		
		$this->add_control(
			'image_resize',
			[
				'label' => __( 'Image Resize', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'st1' => 'Enable',
					'st2' => 'Disable',
				],
				'default' => 'st1',
				'label_block' => true,
			]
		);	
		
		$this->add_control(
			'text_1', [
				'label' => __( 'Discover', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Discover' , 'bauen-plugin' ),
				'description' => __( 'Translet Option.', 'bauen-plugin' ),
				'label_block' => true,
			]
		);

		$this->end_controls_section();
				
		
		$this->start_controls_section(
			'port_item',
			[
				'label' => __( 'Title', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);			
				
		$this->add_control(
			'title_color',
			[
				'label' => __( 'Title Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project4-title' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);	
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .project4-title',
			]
		);	

			
		$this->end_controls_section();
		
		$this->start_controls_section(
			'port_item_cat',
			[
				'label' => __( 'Category', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);	
		$this->add_control(
			'meta_info_color',
			[
				'label' => __( 'Category Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .projects4 .caption h6' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'meta_info_typography',
				'selector' => '{{WRAPPER}} .projects4 .caption h6',
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'port_item_content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);	
		$this->add_control(
			'content_seccolor',
			[
				'label' => __( 'Section Background', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .projects4 .caption' => 'background: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_control(
			'content_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} p' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'content_typography',
				'selector' => '{{WRAPPER}} p',
			]
		);

		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_form_button',
			[
				'label' => __( 'Button', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'button_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .butn-dark a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'button_color_hover',
			[
				'label' => __( 'Color Hover', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .butn-dark a:hover span' => 'color: {{VALUE}};',
				],
			]
		);		
		$this->add_control(
			'button_background',
			[
				'label' => __( 'Background Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .butn-dark a, {{WRAPPER}} button' => 'background: {{VALUE}};',
				],
			]
		);		
		$this->add_control(
			'button_background_hover',
			[
				'label' => __( 'Background Color Hover', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .butn-dark a:after, {{WRAPPER}} button:hover' => 'background: {{VALUE}};',
				],
			]
		);		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_typo',
				'selector' => '{{WRAPPER}} .butn-dark a',
			]
		);

		$this->end_controls_section();
								
		
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>

		<div class="bauen-project">
			<div class="container-after-list">
			<?php if ( $settings['post_pagination'] == 'st2' ) { 
				 $load_main_count= $settings['post_show_before_loadmore'];
			}
			else {
				$load_main_count='10000000';
			}
			?>
			<div class="row isotope-items-wrap  no-hide-last loadmore-wrapper-list" data-load-item="<?php echo esc_attr($load_main_count); ?>" data-button-text="<?php echo esc_attr($settings['load_btn_text_translate']); ?>">
				<div class="col-md-12">				
				<?php
				global $post, $bauen_image;
				$paged=(get_query_var('paged'))?get_query_var('paged'):1;
				$loop = new \WP_Query( array( 'post_type' => 'portfolio','portfolio_category'=> $settings['categoryname'], 'posts_per_page'=> $settings['postcount'], 'post_status' => 'publish', 'offset' => $settings['postoffset']) );
				while ( $loop->have_posts() ) : $loop->the_post();
				$bauen_portfolio_category = wp_get_post_terms($post->ID,'portfolio_category', array('exclude' => $settings['categoryname_exclude']));
				$bauen_class = ""; 
				$bauen_categories = ""; 
				foreach ($bauen_portfolio_category as $bauen_item) {
					$bauen_class.=esc_attr($bauen_item->slug . ' ');
					$bauen_categories.='<span class="cat-divider">';
					$bauen_categories.=esc_attr($bauen_item->name . '  ');
					$bauen_categories.='</span>';
				}			
				if (has_post_thumbnail( $post->ID ) ) {
				if ( $settings['image_resize'] == 'st2' ) {
					$bauen_image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), '' );
				}
				else {
					$bauen_image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'bauen_portfolio_image_list' );
				}
				?>	
				<div class="projects4 full-width isotope-item" >
                    <figure><img src="<?php echo esc_url($bauen_image[0]);?>" alt="<?php the_title();?>" class="img-fluid"></figure>
                        <div class="caption">
                            <h6><?php echo do_shortcode($bauen_categories);?></h6>
                            <h<?php echo esc_attr($settings['title_tag']); ?> class="project4-title"><a href="<?php the_permalink();?>"><?php the_title();?></a></h<?php echo esc_attr($settings['title_tag']); ?>>
                            <?php if (( get_post_meta($post->ID,'bauen_portfolio_short_des_opt',true))) { ?>
							<p><?php echo esc_html(get_post_meta($post->ID,'bauen_portfolio_short_des_opt',true)); ?></p>
							<?php } else { ?>
							<p><?php echo wp_trim_words(get_the_excerpt(), 18); ?></p>
							<?php } ;?>
                            <div class="butn-dark mt-15"> <a href="<?php the_permalink();?>"><span><?php echo esc_html($settings['text_1']); ?></span></a> </div>
                        </div>
                </div>		
				<?php
				} ;
				endwhile;
				wp_reset_postdata();
				?>
				</div>			
			</div>
			</div>
		</div>
		
        <?php
		

	}

}