<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;
//use Elementor\WP_Query;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Bauen_Post_Grid extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-post-grid';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen Post Grid', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-gallery-grid';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-addons' ];
 	}
	
	

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Post Options', 'bauen-plugin' ),
			]
		);		
		$this->add_control(
			'col_size',
			[
				'label' => __( 'Grid Column', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'col-md-6' => '1/2 Column',
					'col-md-4' => '1/3 Column',
					'col-md-3' => '1/4 Column',
					'col-md-12' => '1/1 Column',
				],
				'default' => 'col-md-6',
				'label_block' => true,
			]			
		);	
		
		$this->add_control(
			'postcount', [
				'label' => __( 'Number of posts to show', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '' , 'bauen-plugin' ),
				'description' => __( '(Optional) Insert number of post show in format: 8', 'bauen-plugin' ),
				'label_block' => true,
			]
		);		
		$this->add_control(
			'categoryname', [
				'label' => __( 'Include Category', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '' , 'bauen-plugin' ),
				'description' => __( '(Optional) Insert category name in format: Graphic', 'bauen-plugin' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'postoffset', [
				'label' => __( 'Post Offset', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '' , 'bauen-plugin' ),
				'description' => __( '(Optional)', 'bauen-plugin' ),
				'label_block' => true,
			]
		);				

		$this->end_controls_section();
		
		$this->start_controls_section(
			'port_item',
			[
				'label' => __( 'Post Options', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);			
		$this->add_control(
			'image_resize',
			[
				'label' => esc_html__( 'Image Resize', 'candore-plugin' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'On', 'candore-plugin' ),
				'label_off' => esc_html__( 'Off', 'candore-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);	
		$this->add_control(
			'bg_color',
			[
				'label' => __( 'Background', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bauen-blog .item .con' => 'background-color: {{VALUE}} !important;',
				],
				'default' =>'',
			]
		);
		$this->add_control(
			'border_color',
			[
				'label' => __( 'Border', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bauen-blog .item .con' => 'border-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);		
        $this->add_control(
			'title_tag',
			[
				'label' => __( 'Title Tag', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'1' => 'h1',
					'2' => 'h2',
					'3' => 'h3',
					'4' => 'h4',
					'5' => 'h5',
					'6' => 'h6',
				],
				'default' => '5',
				'label_block' => true,
			]
		);			
		$this->add_control(
			'title_color',
			[
				'label' => __( 'Title Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bauen-blog .item .con h1' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h2' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h3' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h4' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h5' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h6' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h1 a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h2 a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h3 a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h4 a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h5 a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h6 a' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);	
		$this->add_control(
			'title_color-hv',
			[
				'label' => __( 'Title Hover Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bauen-blog .item .con h1:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h2:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h3:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h4:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h5:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h6:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h1 a:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h2 a:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h3 a:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h4 a:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h5 a:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h6 a:hover' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .bauen-blog .item .con h1, {{WRAPPER}} .bauen-blog .item .con h2, {{WRAPPER}} .bauen-blog .item .con h3, {{WRAPPER}} .bauen-blog .item .con h4, {{WRAPPER}} .bauen-blog .item .con h5, {{WRAPPER}} .bauen-blog .item .con h6, {{WRAPPER}} .bauen-blog .item .con h1 a, {{WRAPPER}} .bauen-blog .item .con h2 a, {{WRAPPER}} .bauen-blog .item .con h3 a, {{WRAPPER}} .bauen-blog .item .con h4 a, {{WRAPPER}} .bauen-blog .item .con h5 a, {{WRAPPER}} .bauen-blog .item .con h6 a',
			]
		);		
		$this->add_control(
			'meta_info_color',
			[
				'label' => __( 'Meta Info Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bauen-blog .item .con .category' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'meta_info_typography',
				'selector' => '{{WRAPPER}} .bauen-blog .item .con .category',
			]
		);		
		
		$this->end_controls_section();
									
		
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>

		<div class="sec-blog bauen-blog bauen-blog-el">
		<div class="row">
            <?php
			global $post, $bauen_image;
			$paged=(get_query_var('paged'))?get_query_var('paged'):1;
			$loop = new \WP_Query( array( 'post_type' => 'post','category_name'=> $settings['categoryname'], 'posts_per_page'=> $settings['postcount'], 'post_status' => 'publish', 'offset' => $settings['postoffset']) );
			while ( $loop->have_posts() ) : $loop->the_post();
			if (has_post_thumbnail( $post->ID ) ):
			$bauen_image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), '' );
			?>				
				<div class="item <?php echo esc_attr($settings['col_size']); ?> ">
					<?php if ( 'yes' === $settings['image_resize'] ) { ?>
					<div class="position-re o-hidden position-re-order-blog-grid">
						<a href="<?php the_permalink();?>" class="cd-pt-ab"><img src="<?php echo esc_url($bauen_image[0]);?>" alt="<?php the_title();?>"></a>
					</div>	
					<?php } else { ?>
					<div class="position-re o-hidden">
						<a href="<?php the_permalink();?>"><img src="<?php echo esc_url($bauen_image[0]);?>" alt="<?php the_title();?>"></a>
					</div>	
					<?php } ;?>	
					<div class="con">
						<span class="category"><?php the_category(', ');?> <?php esc_html_e('-','bauen');?> <?php the_time( get_option( 'date_format' ) ); ?></span>
						<h<?php echo esc_attr($settings['title_tag']); ?>><a href="<?php the_permalink();?>"><?php the_title();?></a></h<?php echo esc_attr($settings['title_tag']); ?>>
					</div>			
				</div>			
			<?php
			endif;
			endwhile;
			wp_reset_postdata();
			?>
			
		</div>
		</div>
		
        <?php
		

	}

}