<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;
//use Elementor\WP_Query;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Bauen_Post extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-post';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen Post Carousel', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-carousel';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-addons' ];
 	}
	
	/**
	 * A list of scripts that the widgets is depended in
	 **/
	public function get_script_depends() {
		return [ 
			'owl-carousel',
			'elementor-post-carousel',
		 ];
	}	

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Post Options', 'bauen-plugin' ),
			]
		);		
		$this->add_control(
			'postcount', [
				'label' => __( 'Number of posts to show', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '' , 'bauen-plugin' ),
				'description' => __( '(Optional) Insert number of post show in format: 8', 'bauen-plugin' ),
				'label_block' => true,
			]
		);		
		$this->add_control(
			'categoryname', [
				'label' => __( 'Include Category', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '' , 'bauen-plugin' ),
				'description' => __( '(Optional) Insert category name in format: Graphic', 'bauen-plugin' ),
				'label_block' => true,
			]
		);
		$this->add_control(
			'postoffset', [
				'label' => __( 'Post Offset', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '' , 'bauen-plugin' ),
				'description' => __( '(Optional)', 'bauen-plugin' ),
				'label_block' => true,
			]
		);				

		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_settings',
			[
				'label' => __( 'Carousel Settings', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,					
			]
		);
		
		$this->add_control(
			'style_car_column',
			[
				'label' => __( 'Carousel Columns', 'bauen-plugin' ),
				'description' => __( 'Select style type.', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'3' => '3 Columns',
					'2' => '2 Columns',
					'1' => '1 Column',
				],
				'default' => '2',
				'label_block' => true,
			]
		);
		
		$this->add_control(
			'data_car_loop',
			[
				'label' => __( 'Carousel Loop', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'true' => 'Enable',
					'false' => 'Disable',
				],
				'default' => 'true',
				'label_block' => true,
			]			
		);
		
		$this->add_control(
			'blog_autoplay',
			[
				'label' => __( 'Carousel Autoplay', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'true' => 'Enable',
					'false' => 'Disable',
				],
				'default' => 'false',
				'label_block' => true,
			]			
		);
			
		$this->add_control(
			'blog_autoplay_speed',
			[
				'label' => __( 'Autoplay Timeout', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '5000',
				'description' => __( 'Default: 5000', 'bauen-plugin' ),
				'label_block' => true,
				'condition' => [
					'blog_autoplay' => 'true',
				],
			]
		);
		
		$this->add_control(
			'blog_speed',
			[
				'label' => __( 'Carousel Speed', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '500',
				'description' => __( 'Ex: 500', 'bauen-plugin' ),
				'label_block' => true,
				'condition' => [
					'blog_autoplay' => 'true',
				],
			]
		);
		$this->add_control(
			'slider_nav',
			[
				'label' => __( 'Carousel Navigation', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'true' => 'Enable',
					'false' => 'Disable',
				],
				'default' => 'false',
				'label_block' => true,
			]			
		);	
		$this->add_control(
			'navination_color',
			[
				'label' => __( 'Navigation Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bauen-blog .owl-theme .owl-nav [class*=owl-]' => 'border-color: {{VALUE}};',
				],
				'default' =>'',
				'condition' => [
					'slider_nav' => 'true',
				],				
			]
		);	
		$this->add_control(
			'navination__icon_color',
			[
				'label' => __( 'Navigation Icon Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bauen-blog .owl-theme .owl-nav [class*=owl-]' => 'color: {{VALUE}};',
				],
				'default' =>'',
				'condition' => [
					'slider_nav' => 'true',
				],				
			]
		);			
		$this->add_control(
			'slider_pagination',
			[
				'label' => __( 'Carousel Pagination', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'true' => 'Enable',
					'false' => 'Disable',
				],
				'default' => 'true',
				'label_block' => true,
			]			
		);	
		$this->add_control(
			'slider_desktop_pagination',
			[
				'label' => __( 'Desktop Pagination', 'bauen-plugin' ),
				'description' => __( 'Enable/ Disable pagination for desktop version.', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'true' => 'Enable',
					'false' => 'Disable',
				],
				'default' => 'true',
				'label_block' => true,
			]			
		);
		$this->add_control(
			'pagination_color',
			[
				'label' => __( 'Pagination Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .owl-theme .owl-dots .owl-dot span' => 'border-color: {{VALUE}};',
				],
				'default' =>'',
				'condition' => [
					'slider_pagination' => 'true',
				],				
			]
		);	
		$this->add_control(
			'pagination_color_hv',
			[
				'label' => __( 'Pagination Hover Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .owl-theme .owl-dots .owl-dot.active span' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .owl-theme .owl-dots .owl-dot:hover span' => 'border-color: {{VALUE}};',
				],
				'default' =>'',
				'condition' => [
					'slider_pagination' => 'true',
				],				
			]
		);		
		$this->end_controls_section();		
		
		$this->start_controls_section(
			'port_item',
			[
				'label' => __( 'Post Options', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);			
		$this->add_control(
			'image_resize',
			[
				'label' => esc_html__( 'Image Resize', 'candore-plugin' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'On', 'candore-plugin' ),
				'label_off' => esc_html__( 'Off', 'candore-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		$this->add_control(
			'bg_color',
			[
				'label' => __( 'Background', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bauen-blog .item .con' => 'background-color: {{VALUE}} !important;',
				],
				'default' =>'',
			]
		);
		$this->add_control(
			'border_color',
			[
				'label' => __( 'Border', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bauen-blog .item .con' => 'border-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);		
        $this->add_control(
			'title_tag',
			[
				'label' => __( 'Title Tag', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'1' => 'h1',
					'2' => 'h2',
					'3' => 'h3',
					'4' => 'h4',
					'5' => 'h5',
					'6' => 'h6',
				],
				'default' => '5',
				'label_block' => true,
			]
		);			
		$this->add_control(
			'title_color',
			[
				'label' => __( 'Title Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bauen-blog .item .con h1' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h2' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h3' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h4' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h5' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h6' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h1 a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h2 a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h3 a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h4 a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h5 a' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h6 a' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);	
		$this->add_control(
			'title_color-hv',
			[
				'label' => __( 'Title Hover Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bauen-blog .item .con h1:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h2:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h3:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h4:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h5:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h6:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h1 a:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h2 a:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h3 a:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h4 a:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h5 a:hover' => 'color: {{VALUE}};',
					'{{WRAPPER}} .bauen-blog .item .con h6 a:hover' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .bauen-blog .item .con h1, {{WRAPPER}} .bauen-blog .item .con h2, {{WRAPPER}} .bauen-blog .item .con h3, {{WRAPPER}} .bauen-blog .item .con h4, {{WRAPPER}} .bauen-blog .item .con h5, {{WRAPPER}} .bauen-blog .item .con h6, {{WRAPPER}} .bauen-blog .item .con h1 a, {{WRAPPER}} .bauen-blog .item .con h2 a, {{WRAPPER}} .bauen-blog .item .con h3 a, {{WRAPPER}} .bauen-blog .item .con h4 a, {{WRAPPER}} .bauen-blog .item .con h5 a, {{WRAPPER}} .bauen-blog .item .con h6 a',
			]
		);		
		$this->add_control(
			'meta_info_color',
			[
				'label' => __( 'Meta Info Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bauen-blog .item .con .category' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'meta_info_typography',
				'selector' => '{{WRAPPER}} .bauen-blog .item .con .category',
			]
		);		
		
		$this->end_controls_section();
									
		
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>

		<div class="sec-blog bauen-blog bauen-blog-el">
            <div class="owl-carousel owl-theme" data-blog-autoplay="<?php echo esc_attr($settings['blog_autoplay']); ?>" data-blog-speed="<?php echo esc_attr($settings['blog_speed']); ?>" data-projects-nav="<?php echo esc_attr($settings['slider_nav']); ?>" data-post-item="<?php echo esc_attr($settings['style_car_column']); ?>" data-projects-dots="<?php echo esc_attr($settings['slider_pagination']); ?>" data-blog-autoplay-timeout="<?php echo esc_attr($settings['blog_autoplay_speed']); ?>" data-bn-car-loop="<?php echo esc_attr($settings['data_car_loop']); ?>" data-carousel-dots-desktop="<?php echo esc_attr($settings['slider_desktop_pagination']); ?>" <?php if ( is_rtl() ) { ?>data-rtl="true"<?php } else { ?>data-rtl="false"<?php } ;?>>	
			
			<?php
			global $post, $bauen_image;
			$paged=(get_query_var('paged'))?get_query_var('paged'):1;
			$loop = new \WP_Query( array( 'post_type' => 'post','category_name'=> $settings['categoryname'], 'posts_per_page'=> $settings['postcount'], 'post_status' => 'publish', 'offset' => $settings['postoffset']) );
			while ( $loop->have_posts() ) : $loop->the_post();
			if (has_post_thumbnail( $post->ID ) ):
			$bauen_image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), '' );
			?>				
				<div class="item">
					<?php if ( 'yes' === $settings['image_resize'] ) { ?>
					<div class="position-re o-hidden position-re-order-blog-carousel">
						<a href="<?php the_permalink();?>" class="cd-pt-ab"><img src="<?php echo esc_url($bauen_image[0]);?>" alt="<?php the_title();?>"></a>
					</div>	
					<?php } else { ?>
					<div class="position-re o-hidden">
						<a href="<?php the_permalink();?>"><img src="<?php echo esc_url($bauen_image[0]);?>" alt="<?php the_title();?>"></a>
					</div>	
					<?php } ;?>
					<div class="con">
						<span class="category"><?php the_category(', ');?> <?php esc_html_e('-','bauen');?> <?php the_time( get_option( 'date_format' ) ); ?></span>
						<h<?php echo esc_attr($settings['title_tag']); ?>><a href="<?php the_permalink();?>"><?php the_title();?></a></h<?php echo esc_attr($settings['title_tag']); ?>>
					</div>			
				</div>			
			<?php
			endif;
			endwhile;
			wp_reset_postdata();
			?>
			</div>
		</div>
		
        <?php
		

	}

}