<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Bauen_Pricing extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-pricing';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen Pricing', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-price-list';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-addons' ];
 	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
			]
		);
		
		$this->add_control(
			'maintitle',
			[
				'label' => __( 'Title', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Add Title',
				'description' => __( 'Ex: Basic Plan', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);
		
		$this->add_control(
			'subtitle',
			[
				'label' => __( 'Price', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Add $30.000',
				'description' => __( 'Ex: $30.000', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);	
		$this->add_control(
			'button_name',
			[
				'label' => __( 'Button Text', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'description' => __( 'Ex: Discover', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);		
		$this->add_control(
			'button_url',
			[
				'label' => __( 'Button URL', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'button_name!' => '',
				],					
			]
		);		
		$this->add_control(
			'button_target',
			[
				'label' => __( 'Button URL Target', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'_self' => 'Self',
					'_blank' => 'Blank',
					'_parent' => 'Parent',
					'_top' => 'Top',
				],
				'default' => '_self',
				'label_block' => true,
				'condition' => [
					'button_url!' => '',
				],					
			]
		);		

		$repeater = new \Elementor\Repeater();
		
		$repeater->add_control(
			'title',
			[
				'label' => __( 'List Item', 'tank-plugin' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => '',
				'description' => __( 'Ex: Information architecture', 'bauen-plugin' ),
			]
		);
		$repeater->add_control(
			'line',
			[
				'label' => __( 'Item Type', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'check' => 'Check',
					'close unavailable' => 'Close',
				],
				'default' => 'check',
				'label_block' => true,
			]
		);			
		$this->add_control(
			'bauen_pricings',
			[
				'label' => __( 'List Items', 'bauen-plugin' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'title' => __('Information architecture', 'bauen-plugin'),
					],
					[
						'title' => __('Lifetime support', 'bauen-plugin'),
					],
					[
						'title' => __('A-Z design', 'bauen-plugin'),
					],	
					[
						'title' => __('A-Z design', 'bauen-plugin'),
					],					
				],
			]
		);			

		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_title',
			[
				'label' => __( 'Title', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pricing-card-name' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .pricing-card-name',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_subtitle',
			[
				'label' => __( 'Price', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'subtitle_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pricing-card-amount' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'subtitle_typography',
				'selector' => '{{WRAPPER}} .pricing-card-amount',
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_content',
			[
				'label' => __( 'List Item', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);	
		$this->add_control(
			'content_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pricing-card-list li' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);		
		$this->add_control(
			'content_color_icon',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pricing-card-list li i' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'text_typography2',
				'selector' => '{{WRAPPER}} .pricing-card-list li',
			]
		);		
		
		$this->end_controls_section();

		$this->start_controls_section(
			'section_style_button',
			[
				'label' => __( 'Button', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,					
			]
		);	
		$this->add_control(
			'button_tx_color',
			[
				'label' => __( 'Button Text Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .butn-pricing a' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_control(
			'button_tx_color_hv',
			[
				'label' => __( 'Button Text Hover Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .butn-pricing a:hover span' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);			
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'text_typography',
				'selector' => '{{WRAPPER}} .butn-pricing a',
			]
		);			
		$this->add_control(
			'button_bg_color',
			[
				'label' => __( 'Button Background', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .butn-pricing a' => 'background: {{VALUE}};',
				],
				'default' =>'',
			]
		);			
		$this->add_control(
			'button_bg_color_hv',
			[
				'label' => __( 'Button Background Hover', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .butn-pricing a:after' => 'background: {{VALUE}};',
					
				],
				'default' =>'',
			]
		);	
		
       	$this->end_controls_section();	

		$this->start_controls_section(
			'section_style_background',
			[
				'label' => __( 'Background Color', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,					
			]
		);	
		
		$this->add_control(
			'box_bg_color',
			[
				'label' => __( 'Box Background', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pricing-card' => 'background-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);	

       	$this->end_controls_section();			
		
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>
		
		
						
		<div class="pricing-card">		
			<div class="priceCard__content">
			    <?php if ( $settings['maintitle'] ) { ?>
				<p class="pricing-card-name"><?php echo esc_html($settings['maintitle']); ?></p>
				<?php }; ?>
				<?php if ( $settings['subtitle'] ) { ?>
				<h3 class="pricing-card-amount"><?php echo esc_html($settings['subtitle']); ?></h3>
				<?php }; ?>	
				<?php if ( $settings['bauen_pricings'] ) { ?>
				<div class="pricing-card-bottom">
				    <ul class="list-unstyled pricing-card-list">
					<?php foreach( $settings['bauen_pricings'] as $bauen_pricing ) { ?>
						<?php if ( $bauen_pricing['title'] ) { ?>
						<li><i class="ti-<?php echo esc_attr($bauen_pricing['line']); ?>"></i><?php echo esc_html($bauen_pricing['title']); ?></li>
						<?php } ;?>					
					<?php } ;?>				   
				   </ul>
				</div>
				<?php }; ?>
				<?php if ( $settings['button_name'] ) { ?>
				<div class="butn-pricing">
		    		<a href="<?php echo esc_url($settings['button_url']); ?>" target="<?php echo esc_attr($settings['button_target']); ?>"><span><?php echo esc_html($settings['button_name']); ?></span></a>
		        </div>	
				<?php } ;?>		
		    </div>					
		</div>									
        <?php
		

	}

}