<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Bauen_Process extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-process';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen Process', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-addons' ];
 	}	

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
			]
		);		
		$this->add_control(
			'df_class',
			[
				'label' => __( 'Position', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'custom' => 'Default',
					'first' => 'First',
					'odd' => 'Odd',
					'odd mb-md50' => 'Odd MB',
				],
				'default' => 'custom',
				'label_block' => true,
			]
		);	
		$this->add_control(
			'style_type',
			[
				'label' => __( 'Arrow Style', 'bauen-plugin' ),
				'description' => __( 'Select style type.', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'st1' => 'Enable',
					'st2' => 'Disable',
				],
				'default' => 'st1',
				'label_block' => true,
			]
		);	
		$this->add_control(
			'df_class2',
			[
				'label' => __( 'Arrow Position', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'custom' => 'UP',
					'tobotm' => 'Down',
				],
				'default' => 'custom',
				'label_block' => true,
				'condition' => [
					'style_type' => 'st1',
				],				
			]
		);			
		$this->add_control(
			'icon_type',
			[
				'label' => __( 'Icon Type', 'bauen-plugin' ),
				'description' => __( 'Select icon type.', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'st1' => 'Themify',
					'st2' => 'Fontawesome',
				],
				'default' => 'st1',
				'label_block' => true,
			]
		);	
		$this->add_control(
			'icon_class2',
			[
				'label' => __( 'Icon Class', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'ti-thought',
				'description' => __( 'Insert <strong><a href="https://themify.me/themify-icons" target="_blank">Themify</a></strong> Icon Class here. Ex: ti-ruler-pencil ', 'bauen-plugin' ),
				'label_block' => true,
				'condition' => [
					'icon_type' => 'st1',
				],				
			]
		);			
        $this->add_control(
			'icon_class',
			[
				'label' => esc_html__( 'Icon', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fa fa-paw',
					'library' => 'solid',
				],
				
				'skin' =>'inline',
				'label_block' => false,
				'condition' => [
					'icon_type' => 'st2',
				],				
			]
		);				
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Add Title',
				'description' => __( '', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);			
		$this->add_control(
			'subtitle',
			[
				'label' => __( 'Number', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Add 01',
				'description' => __( 'Ex: 02', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);			
		$this->add_control(
			'block-content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => '',				
			]				
		);	
	
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_icon',
			[
				'label' => __( 'Icon', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,							
			]
		);
		$this->add_control(
			'icon_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .process .item .icon' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_control(
			'icon_border_color',
			[
				'label' => __( 'Border', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .process .item .icon' => 'border-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);	
		
		$this->end_controls_section();			
		
		$this->start_controls_section(
			'section_style_title',
			[
				'label' => __( 'Title Options', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        $this->add_control(
			'title_tag',
			[
				'label' => __( 'Title Tag', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'1' => 'h1',
					'2' => 'h2',
					'3' => 'h3',
					'4' => 'h4',
					'5' => 'h5',
					'6' => 'h6',
				],
				'default' => '6',
				'label_block' => true,
			]
		);			
		$this->add_control(
			'title_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .process .item h1.title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .process .item h2.title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .process .item h3.title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .process .item h4.title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .process .item h5.title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .process .item h6.title' => 'color: {{VALUE}};',
				],				
			]
		);
		$this->add_control(
			'title_color_hv',
			[
				'label' => __( 'Color Hover', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .process .item .cont:hover h1.title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .process .item .cont:hover h2.title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .process .item .cont:hover h3.title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .process .item .cont:hover h4.title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .process .item .cont:hover h5.title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .process .item .cont:hover h6.title' => 'color: {{VALUE}};',
				],				
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .process .item h1.title, {{WRAPPER}} .process .item h2.title, {{WRAPPER}} .process .item h3.title, {{WRAPPER}} .process .item h4.title, {{WRAPPER}} .process .item h5.title, {{WRAPPER}} .process .item h6.title',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,					
			]
		);
		$this->add_control(
			'content_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .process .item .cont p' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);		
		$this->add_control(
			'content_color_hv',
			[
				'label' => __( 'Color Hover', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .process .item .cont:hover p' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'text_typography',
				'selector' => '{{WRAPPER}} .process .item .cont p',
			]
		);			
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_subtitle',
			[
				'label' => __( 'Number', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'subtitle_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .process .item h3.number' => '-webkit-text-stroke: 1px {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_control(
			'subtitle_color_hv',
			[
				'label' => __( 'Hover Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .process .item .cont:hover h3.number' => '-webkit-text-stroke: 1px {{VALUE}};',
				],
				'default' =>'',
			]
		);		
		
		$this->end_controls_section();		
		
		$this->start_controls_section(
			'section_style_background',
			[
				'label' => __( 'Background Color', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,					
			]
		);	
		$this->add_control(
			'bg_color',
			[
				'label' => __( 'Background', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .process .item .cont' => 'background-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);	
		$this->add_control(
			'bg_color_hv',
			[
				'label' => __( 'Background Hover', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .process .item .cont:hover' => 'background-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);	
		$this->add_control(
			'border_color',
			[
				'label' => __( 'Border', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .process .item .cont' => 'border-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);	
		$this->add_control(
			'border_color_hv',
			[
				'label' => __( 'Border Hover', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .process .item .cont:hover' => 'border-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);		
		$this->add_control(
			'divider_color',
			[
				'label' => __( 'Divider Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .process .item .line:after' => 'background-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);		
	
		
		$this->end_controls_section();		

	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>

		<div class="sec-process process">		
			<div class="item text-center <?php echo esc_attr($settings['df_class']); ?>">
				<?php if ( $settings['style_type'] == 'st1' ) { ?>
					<img src="<?php echo (BAUEN_THEME_URL) ;?>/includes/images/arrow.png" alt="<?php esc_attr_e('arrow','bauen');?>" class="<?php echo esc_attr($settings['df_class2']); ?>" /> 
				<?php } ;?>	
				<?php if ( $settings['icon_type'] == 'st2' ) { ?>
					<span class="icon"><?php \Elementor\Icons_Manager::render_icon( $settings['icon_class'], [ 'aria-hidden' => 'true' ] ); ?></span>
				<?php } 
				else { ?>	
					<span class="icon <?php echo esc_attr($settings['icon_class2']); ?>"></span>
				<?php } ;?>	
   				<div class="cont">	
					<?php if ( $settings['title'] ) { ?>
					<h<?php echo esc_attr($settings['title_tag']); ?> class="title"><?php echo do_shortcode($settings['title']); ?></h<?php echo esc_attr($settings['title_tag']); ?>>
					<?php }; ?>	
					<div class="line"></div>
					<?php if ( $settings['block-content'] ) { ?>
					<p><?php echo do_shortcode($settings['block-content']); ?></p>
					<?php }; ?>	
					<?php if ( $settings['subtitle'] ) { ?>
					<h3 class="number"><?php echo do_shortcode($settings['subtitle']); ?></h3>
					<?php }; ?>					
			    </div>	
			</div>	
		</div>		

        <?php		

	}

}