<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Bauen_Services extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-services';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen Services', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-icon-box';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-addons' ];
 	}	

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
			]
		);		

		$this->add_control(
			'style_type',
			[
				'label' => __( 'Logo Type', 'bauen-plugin' ),
				'description' => __( 'Select style type.', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'st1' => 'Icon',
					'st2' => 'Image',
				],
				'default' => 'st1',
				'label_block' => true,
			]
		);	
        $this->add_control(
			'icon_class',
			[
				'label' => esc_html__( 'Icon', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fa fa-paw',
					'library' => 'solid',
				],
				
                'skin' =>'inline',
				'label_block' => false,
				'condition' => [
					'style_type' => 'st1',
				],				
			]
		);	
		$this->add_control(
			'image',
			[
				'label' => __( 'Image', 'bauen-plugin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => '',
				],
				'label_block' => true,	
				'condition' => [
					'style_type' => 'st2',
				],					
			]
		);	
		$this->add_responsive_control(
			'image_wrapper_width',
			[
				'label' => esc_html__( 'Logo Image Width', 'annie-plugin' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'vh', '%', 'px' ],
				'range' => [
					'vh' => [
						'min' => 0,
						'max' => 100,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'{{WRAPPER}} .services .item img' => 'width: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'image[url]!' => '',
				],
			]
		);		
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Add Title',
				'description' => __( 'Ex: Architecture', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);	
		$this->add_control(
			'subtitle',
			[
				'label' => __( 'Number', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Add 01',
				'description' => __( 'Ex: 02', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);		
				
		$this->add_control(
			'button_url',
			[
				'label' => __( 'Custom URL', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);		
		$this->add_control(
			'button_target',
			[
				'label' => __( 'Custom URL Target', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'_self' => 'Self',
					'_blank' => 'Blank',
					'_parent' => 'Parent',
					'_top' => 'Top',
				],
				'default' => '_self',
				'label_block' => true,
			]
		);	

		$this->add_control(
			'block-content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => '',				
			]				
		);	
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_icon',
			[
				'label' => __( 'Icon', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'style_type' => 'st1',
				],								
			]
		);
		$this->add_control(
			'icon_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .services .item i' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);

		
		$this->end_controls_section();			
		
		$this->start_controls_section(
			'section_style_title',
			[
				'label' => __( 'Title Options', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        $this->add_control(
			'title_tag',
			[
				'label' => __( 'Title Tag', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'1' => 'h1',
					'2' => 'h2',
					'3' => 'h3',
					'4' => 'h4',
					'5' => 'h5',
					'6' => 'h6',
				],
				'default' => '5',
				'label_block' => true,
			]
		);			
		$this->add_control(
			'title_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .services .item h1' => 'color: {{VALUE}};',
					'{{WRAPPER}} .services .item h2' => 'color: {{VALUE}};',
					'{{WRAPPER}} .services .item h3' => 'color: {{VALUE}};',
					'{{WRAPPER}} .services .item h4' => 'color: {{VALUE}};',
					'{{WRAPPER}} .services .item h5' => 'color: {{VALUE}};',
					'{{WRAPPER}} .services .item h6' => 'color: {{VALUE}};',
				],				
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .services .item h1, {{WRAPPER}} .services .item h2, {{WRAPPER}} .services .item h3, {{WRAPPER}} .services .item h4, {{WRAPPER}} .services .item h5, {{WRAPPER}} .services .item h6',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,					
			]
		);
		
		$this->add_control(
			'content_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} p' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'text_typography',
				'selector' => '{{WRAPPER}} p',
			]
		);			
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_subtitle',
			[
				'label' => __( 'Number', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'subtitle_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .services .item .numb' => '-webkit-text-stroke: 1px {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_control(
			'subtitle_color_hv',
			[
				'label' => __( 'Hover Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .services .item:hover .numb' => '-webkit-text-stroke: 1px {{VALUE}};',
				],
				'default' =>'',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'number_text_typography',
				'selector' => '{{WRAPPER}} .services .item .numb',
			]
		);	
		
		$this->end_controls_section();		
		
		$this->start_controls_section(
			'section_style_background',
			[
				'label' => __( 'Background & Spacing', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,					
			]
		);	
		
		$this->add_responsive_control(
			'bn_block_padding',
			[
				'label' => esc_html__( 'Block Padding', 'bauen-plugin' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
				'selectors' => [
					'{{WRAPPER}} .services .item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
		$this->add_control(
			'divider_color_mn',
			[
				'label' => __( 'Divider Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .services .item .line:after' => 'background-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);	
		
		$this->add_control(
			'divider_color',
			[
				'label' => __( 'Divider Color Hover', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .services .item:hover .line:after' => 'background-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);	

		$this->add_control(
			'bg_color_mtt',
			[
				'label' => __( 'Background', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .services .item' => 'background-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_control(
			'bg_color_hv',
			[
				'label' => __( 'Background Hover', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .services .item:hover' => 'background-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);		
		
		$this->end_controls_section();		

	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>

		<div class="sec-services services">		
			<div class="item">
			    <?php if ( $settings['button_url'] ) { ?>
				<a href="<?php echo esc_url($settings['button_url']); ?>" target="<?php echo esc_attr($settings['button_target']); ?>" rel="noopener noreferrer">
				<?php } ;?>	
                    <?php if ( $settings['style_type'] == 'st2' ) { ?>
					    <img src="<?php echo esc_url($settings['image']['url']); ?>" alt="<?php echo esc_url($settings['image']['alt']); ?>"> 
					<?php } 
					else { ?>	
					    <?php \Elementor\Icons_Manager::render_icon( $settings['icon_class'], [ 'aria-hidden' => 'true' ] ); ?>
					<?php } ;?>	
					<?php if ( $settings['title'] ) { ?>
					<h<?php echo esc_attr($settings['title_tag']); ?>><?php echo do_shortcode($settings['title']); ?></h<?php echo esc_attr($settings['title_tag']); ?>>
					<?php }; ?>	
					<div class="line"></div>
					<?php if ( $settings['block-content'] ) { ?>
					<?php echo do_shortcode($settings['block-content']); ?>
					<?php }; ?>	
					<?php if ( $settings['subtitle'] ) { ?>
					<div class="numb"><?php echo do_shortcode($settings['subtitle']); ?></div>
					<?php }; ?>					
				<?php if ( $settings['button_url'] ) { ?>
				</a>
				<?php } ;?>	
			</div>	
		</div>		

        <?php		

	}

}