<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Bauen_Single_Img_Video extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-single-img-video';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen Single Popup Image & Video', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-image-bold';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-addons' ];
 	}	
	
	/**
	 * A list of scripts that the widgets is depended in
	 **/
	public function get_script_depends() {
		return [ 
			'elementor-single-gallery-popup',
		 ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Image & Video', 'bauen-plugin' ),
			]
		);
		
		
		$this->add_control(
			'image',
			[
				'label' => __( 'Image', 'bauen-plugin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => '',
				],
				'label_block' => true,
			]
		);
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name' => 'image', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_size` and `image_custom_dimension`.
				'default' => 'full',
				'separator' => 'none',
			]
		);		
		$this->add_control(
			'style_type',
			[
				'label' => __( 'Style Type', 'bauen-plugin' ),
				'description' => __( 'Select tab style type.', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'st1' => 'PopUp Image',
					'st2' => 'PopUp Video',
				],
				'default' => 'st1',
				'label_block' => true,
			]
		);	
		
		$this->add_control(
			'post_theme_lightbox',
			[
				'label' => esc_html__( 'Default Lightbox', 'bauen-plugin' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'On', 'bauen-plugin' ),
				'label_off' => esc_html__( 'Off', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
				'condition' => [
					'style_type' => 'st1',
					'image[url]!' => '',
				],
			]
		);

		$this->add_control(
			'video', [
				'label' => __( 'Video URL', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'description' => __( 'Insert video URL in format: https://youtu.be/RziCmLzpFNY  <br> https://vimeo.com/449554367', 'bauen-plugin' ),
				'label_block' => true,
				'condition' => [
					'style_type' => 'st2',
					'image[url]!' => '',
				],				
			]
		);		
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'port_overlay',
			[
				'label' => __( 'Hover Overlay', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'style_type' => 'st1',
				],
			]
		);
		
		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'port_overlay',
				'label' => esc_html__( 'Overlay Color', 'bauen-plugin' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .gallery-box:hover .gallery-img:after',
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_popup_button',
			[
				'label' => __( 'Popup Button', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'popup_button_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .video-gallery-polygon' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'popup_button_color_hover',
			[
				'label' => __( 'Color Hover', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .video-gallery-polygon:hover' => 'color: {{VALUE}};',
				],
			]
		);		
		$this->add_control(
			'popup_button_background',
			[
				'label' => __( 'Border Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .video-gallery-polygon' => 'border-color: {{VALUE}};',
				],
			]
		);		
		$this->add_control(
			'popup_button_background_hover',
			[
				'label' => __( 'Background Color Hover', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .video-gallery-polygon:hover' => 'background-color: {{VALUE}}; border-color: {{VALUE}};',
					
				],
			]
		);	

		$this->end_controls_section();
		

	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>		
		
			
			<?php $caption = wp_get_attachment_caption( $settings['image']['id'] );?>
			    <?php if( $settings['style_type'] == 'st2' ) { ?>
					<div class="sec-gallery vid-area">
						<div class="vid-icon">
							<?php Group_Control_Image_Size::print_attachment_image_html( $settings ); ?><a href="<?php echo esc_url($settings['video']); ?>" class="video-gallery-button vid"> <span class="video-gallery-polygon"> <i class="ti-control-play"></i> </span> </a>								 
						</div>																		
					</div>			
				<?php } 
				else { ?>				
					<div class="sec-gallery gallery-item">
						
						<a href="<?php echo esc_url($settings['image']['url']); ?>" title="<?php echo esc_attr($caption);?>" <?php if ( 'yes' === $settings['post_theme_lightbox'] ) { ?>class="img-zoom-gallery"<?php };?>>
							<div class="gallery-box">
								<div class="gallery-img"> <?php Group_Control_Image_Size::print_attachment_image_html( $settings ); ?> </div>
							</div>									
						</a>
						
					</div>
			    <?php } ;?>	
			
			
				

        <?php		

	}

}