<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Bauen_Team extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-team';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen Team', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-person';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-addons' ];
 	}
	
	/**
	 * A list of scripts that the widgets is depended in
	 **/
	public function get_script_depends() {
		return [ 
			'owl-carousel',
			'elementor-team-carousel',
		 ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
			]
		);
		
		$this->add_control(
			'style_type',
			[
				'label' => __( 'Style Type', 'bauen-plugin' ),
				'description' => __( 'Select style type.', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'st1' => 'Carousel',
					'st2' => 'Grid',
				],
				'default' => 'st1',
				'label_block' => true,
			]
		);

		$this->add_control(
			'style_car_column',
			[
				'label' => __( 'Carousel Columns', 'bauen-plugin' ),
				'description' => __( 'Select style type.', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'4' => '4 Columns',
					'3' => '3 Columns',
					'2' => '2 Columns',
					'1' => '1 Column',
				],
				'default' => '3',
				'label_block' => true,
				'condition' =>  ['style_type' => ['st1']],
			]
		);
		
		$this->add_control(
			'style_grid_column',
			[
				'label' => __( 'Grid Column', 'travol-plugin' ),
				'description' => __( '', 'travol-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'col-md-3' => '4 Columns',
					'col-md-4' => '3 Columns',
					'col-md-6' => '2 Columns',
					'col-md-12' => '1 Column',
				],
				'default' => 'col-md-4',
				'label_block' => true,
				'condition' =>  ['style_type' => ['st2']],
			]			
		);	
		
		$this->add_control(
			'style_type_hover',
			[
				'label' => __( 'Image Hover Effect', 'bauen-plugin' ),
				'description' => __( 'Working only if a Team member custom URL is found.', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'bn-team-overlay-off' => 'Disable',
					'bn-team-overlay' => 'Enable',
				],
				'default' => 'bn-team-overlay-off',
				'label_block' => true,
			]
		);
		
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'image',
			[
				'label' => __( 'Member Image', 'bauen-plugin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => '',
				],
				'label_block' => true,
			]
		);						
		$repeater->add_control(
			'title', [
				'label' => __( 'Data Title', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Jason Brown' , 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
                'condition' => [
					'image[url]!' => '',
				],				
			]
		);		
		$repeater->add_control(
			'subtitle', [
				'label' => __( 'Data Designation', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Architect' , 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
                'condition' => [
					'image[url]!' => '',
				],				
			]
		);			
		$repeater->add_control(
			'subtitle2', [
				'label' => __( 'Data Degree', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'dipl. Arch ETH/SIA' , 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
                'condition' => [
					'image[url]!' => '',
				],				
			]
		);	
		$repeater->add_control(
			'social_fb_url',
			[
				'label' => __( 'Facebook', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'description' => __( 'Insert soical url here.', 'bauen-plugin' ),
				'label_block' => true,
                'condition' => [
					'image[url]!' => '',
				],					
			]
		);	
		$repeater->add_control(
			'social_tw_url',
			[
				'label' => __( 'Twitter', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'description' => __( 'Insert soical url here.', 'bauen-plugin' ),
				'label_block' => true,
                'condition' => [
					'image[url]!' => '',
				],	
			]
		);	
		$repeater->add_control(
			'social_in_url',
			[
				'label' => __( 'Instagram', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'description' => __( 'Insert soical url here.', 'bauen-plugin' ),
				'label_block' => true,
                'condition' => [
					'image[url]!' => '',
				],	
			]
		);		
		$repeater->add_control(
			'social_ln_url',
			[
				'label' => __( 'Linkedin', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'description' => __( 'Insert soical url here.', 'bauen-plugin' ),
				'label_block' => true,
                'condition' => [
					'image[url]!' => '',
				],	
			]
		);	
		$repeater->add_control(
			'social_custom_url',
			[
				'label' => __( 'Custom Social', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => '',
				'description' => esc_attr__( '<a href="#0" target="_blank"><i class="ti-pinterest"></i></a>', 'bauen-plugin' ),
				'label_block' => true,
                'condition' => [
					'image[url]!' => '',
				],	
			]
		);	
		$repeater->add_control(
			'social_url_target',
			[
				'label' => __( 'Custom Social URL Target', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'_self' => 'Self',
					'_blank' => 'Blank',
					'_parent' => 'Parent',
					'_top' => 'Top',
				],
				'default' => '_blank',
				'label_block' => true,
                'condition' => [
					'social_custom_url!' => '',
				],					
			]
		);		
		$repeater->add_control(
			'alt', [
				'label' => __( 'Member Image Alter Text', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'label_block' => true,
                'condition' => [
					'image[url]!' => '',
				],				
			]
		);				
		$repeater->add_control(
			'button_url',
			[
				'label' => __( 'Custom URL', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'label_block' => true,
                'condition' => [
					'image[url]!' => '',
				],					
			]
		);		
		$repeater->add_control(
			'button_target',
			[
				'label' => __( 'Custom URL Target', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'_self' => 'Self',
					'_blank' => 'Blank',
					'_parent' => 'Parent',
					'_top' => 'Top',
				],
				'default' => '_self',
				'label_block' => true,
                'condition' => [
					'button_url!' => '',
				],					
			]
		);		
		$this->add_control(
			'bauen_team_members',
			[
				'label' => __( 'Team Member', 'bauen-plugin' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
			]
		);		

		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_settings',
			[
				'label' => __( 'Carousel Settings', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'style_type' => 'st1',
				],					
			]
		);
		
		$this->add_control(
			'data_car_loop',
			[
				'label' => __( 'Carousel Loop', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'true' => 'Enable',
					'false' => 'Disable',
				],
				'default' => 'true',
				'label_block' => true,
			]			
		);
		
		$this->add_control(
			'team_autoplay',
			[
				'label' => __( 'Carousel Autoplay', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'true' => 'Enable',
					'false' => 'Disable',
				],
				'default' => 'false',
				'label_block' => true,
			]			
		);	

		$this->add_control(
			'team_autoplay_speed',
			[
				'label' => __( 'Autoplay Timeout', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '5000',
				'description' => __( 'Default: 5000', 'bauen-plugin' ),
				'label_block' => true,
				'condition' => [
					'team_autoplay' => 'true',
				],
			]
		);
		
		$this->add_control(
			'team_speed',
			[
				'label' => __( 'Carousel Speed', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '500',
				'description' => __( 'Default: 500', 'bauen-plugin' ),
				'label_block' => true,
			]
		);
		
		$this->add_control(
			'slider_nav',
			[
				'label' => __( 'Carousel Navigation', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'true' => 'Enable',
					'false' => 'Disable',
				],
				'default' => 'false',
				'label_block' => true,
			]			
		);	
		$this->add_control(
			'navination_color',
			[
				'label' => __( 'Navigation Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team .owl-theme .owl-nav [class*=owl-]' => 'border-color: {{VALUE}};',
				],
				'default' =>'',
				'condition' => [
					'slider_nav' => 'true',
				],				
			]
		);	
		$this->add_control(
			'navination__icon_color',
			[
				'label' => __( 'Navigation Icon Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team .owl-theme .owl-nav [class*=owl-]' => 'color: {{VALUE}};',
				],
				'default' =>'',
				'condition' => [
					'slider_nav' => 'true',
				],				
			]
		);			
		$this->add_control(
			'slider_pagination',
			[
				'label' => __( 'Carousel Pagination', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'true' => 'Enable',
					'false' => 'Disable',
				],
				'default' => 'true',
				'label_block' => true,
			]			
		);	
		
		$this->add_control(
			'slider_desktop_pagination',
			[
				'label' => __( 'Desktop Pagination', 'bauen-plugin' ),
				'description' => __( 'Enable/ Disable pagination for desktop version.', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'true' => 'Enable',
					'false' => 'Disable',
				],
				'default' => 'true',
				'label_block' => true,
			]			
		);
		
		$this->add_control(
			'pagination_color',
			[
				'label' => __( 'Pagination Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .owl-theme .owl-dots .owl-dot span' => 'border-color: {{VALUE}};',
				],
				'default' =>'',
				'condition' => [
					'slider_pagination' => 'true',
				],				
			]
		);	
		$this->add_control(
			'pagination_color_hv',
			[
				'label' => __( 'Pagination Hover Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .owl-theme .owl-dots .owl-dot.active span' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .owl-theme .owl-dots .owl-dot:hover span' => 'border-color: {{VALUE}};',
				],
				'default' =>'',
				'condition' => [
					'slider_pagination' => 'true',
				],				
			]
		);		
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_title',
			[
				'label' => __( 'Title Options', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        $this->add_control(
			'title_tag',
			[
				'label' => __( 'Title Tag', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'1' => 'h1',
					'2' => 'h2',
					'3' => 'h3',
					'4' => 'h4',
					'5' => 'h5',
					'6' => 'h6',
				],
				'default' => '6',
				'label_block' => true,
			]
		);			
		$this->add_control(
			'title_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team .info h1' => 'color: {{VALUE}};',
					'{{WRAPPER}} .team .info h2' => 'color: {{VALUE}};',
					'{{WRAPPER}} .team .info h3' => 'color: {{VALUE}};',
					'{{WRAPPER}} .team .info h4' => 'color: {{VALUE}};',
					'{{WRAPPER}} .team .info h5' => 'color: {{VALUE}};',
					'{{WRAPPER}} .team .info h6' => 'color: {{VALUE}};',
				],				
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .team .info h1, {{WRAPPER}} .team .info h2, {{WRAPPER}} .team .info h3, {{WRAPPER}} .team .info h4, {{WRAPPER}} .team .info h5, {{WRAPPER}} .team .info h6',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_subtitle',
			[
				'label' => __( 'Designation Options ', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);		
		$this->add_control(
			'subtitle_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team .info p' => 'color: {{VALUE}};',
				],				
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'subtitle_typography',
				'selector' => '{{WRAPPER}} .team .info p',
			]
		);
		$this->end_controls_section();	

		$this->start_controls_section(
			'section_style_subtitle2',
			[
				'label' => __( 'Degree Options', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);		
		$this->add_control(
			'subtitle2_color',
			[
				'label' => __( 'Text Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team .info .social p' => 'color: {{VALUE}};',
				],				
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'subtitle2_typography',
				'selector' => '{{WRAPPER}} .team .info .social p',
			]
		);
		$this->end_controls_section();	

		$this->start_controls_section(
			'section_style_icon',
			[
				'label' => __( 'Icon Options', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,					
			]
		);			
		$this->add_control(
			'icon_color',
			[
				'label' => __( 'Icon Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team .info .social a' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);			
		$this->add_control(
			'icon_color_hv',
			[
				'label' => __( 'Icon Color Hover', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team .info .social a:hover' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);		
		$this->end_controls_section();				
		
		$this->start_controls_section(
			'section_style_background',
			[
				'label' => __( 'Background Color', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,					
			]
		);	
		
		$this->add_control(
			'bg_color',
			[
				'label' => __( 'Hover Background', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .team .info .social' => 'background-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);			
		
		$this->end_controls_section();	
		
		$this->start_controls_section(
			'section_style_image_overlay_background',
			[
				'label' => __( 'Image Overlay', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,	
				'condition' => [
					'style_type_hover' => 'bn-team-overlay',
				],				
			]
		);	
		
		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'back_flip_color',
				'label' => esc_html__( 'Overlay Color', 'bauen-plugin' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .bn-team-overlay:after',
			]
		);
		
		$this->add_control(
			'overlay_icon_color',
			[
				'label' => __( 'Icon Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bn-team-overlay:before' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);	
		
		$this->end_controls_section();				
		

	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>

		<div class="sec-team team">
		    <?php if ( $settings['style_type'] == 'st2' ) { ?>	
			<div class="row bn-team-grid">
				<?php foreach( $settings['bauen_team_members'] as $bauen_team_member ) { ?>
				<div class="<?php echo esc_attr($settings['style_grid_column']); ?> mb-40">
					<div class="item">
						<?php if ( $bauen_team_member['button_url'] ) { ?>
						<a class="<?php echo esc_attr($settings['style_type_hover']); ?>" href="<?php echo esc_url($bauen_team_member['button_url']); ?>" target="<?php echo esc_attr($bauen_team_member['button_target']); ?>">
						<?php } ;?>
						<div class="img"> <img src="<?php echo esc_url($bauen_team_member['image']['url']); ?>" class="img-fluid" alt="<?php echo esc_attr($bauen_team_member['alt']); ?>"> </div>					
						<?php if ( $bauen_team_member['button_url'] ) { ?>
						</a>
						<?php } ;?>
						<div class="info">
							<?php if ( $bauen_team_member['title'] ) { ?>
							<h<?php echo esc_attr($settings['title_tag']); ?>><?php echo do_shortcode($bauen_team_member['title']); ?></h<?php echo esc_attr($settings['title_tag']); ?>>					
							<?php } ;?>	
							<?php if ( $bauen_team_member['subtitle'] ) { ?>
							<p><?php echo do_shortcode($bauen_team_member['subtitle']); ?></p>
							<?php } ;?>
							<?php if ( $bauen_team_member['subtitle2'] || $bauen_team_member['social_fb_url'] || $bauen_team_member['social_tw_url'] || $bauen_team_member['social_in_url'] || $bauen_team_member['social_ln_url'] || $bauen_team_member['social_custom_url'] ) { ?>
							<div class="social valign">
								<div class="full-width">
									<?php if ( $bauen_team_member['subtitle2'] ) { ?>
									<p><?php echo do_shortcode($bauen_team_member['subtitle2']); ?></p>
									<?php } ;?>	
                                    <?php if ( $bauen_team_member['social_fb_url'] ) { ?> 
									<a href="<?php echo esc_url($bauen_team_member['social_fb_url']); ?>" target="<?php echo esc_attr($bauen_team_member['social_url_target']); ?>" rel="noopener noreferrer"><i class="ti-facebook"></i></a>		
									<?php } ;?>	
                                    <?php if ( $bauen_team_member['social_tw_url'] ) { ?> 
									<a href="<?php echo esc_url($bauen_team_member['social_tw_url']); ?>" target="<?php echo esc_attr($bauen_team_member['social_url_target']); ?>" rel="noopener noreferrer"><i class="fab fa-x-twitter"></i></a>		
									<?php } ;?>	
                                    <?php if ( $bauen_team_member['social_in_url'] ) { ?> 
									<a href="<?php echo esc_url($bauen_team_member['social_in_url']); ?>" target="<?php echo esc_attr($bauen_team_member['social_url_target']); ?>" rel="noopener noreferrer"><i class="fab fa-instagram"></i></a>		
									<?php } ;?>	
                                    <?php if ( $bauen_team_member['social_ln_url'] ) { ?> 
									<a href="<?php echo esc_url($bauen_team_member['social_ln_url']); ?>" target="<?php echo esc_attr($bauen_team_member['social_url_target']); ?>" rel="noopener noreferrer"><i class="ti-linkedin"></i></a>		
									<?php } ;?>										
									<?php echo do_shortcode($bauen_team_member['social_custom_url']); ?>	
								</div>
							</div>
						<?php } ;?>
						</div>
					</div>
				</div>
				<?php } ;?>
			</div>				
			<?php } 
			else { ?>				 
			<div class="owl-carousel owl-theme" data-team-autoplay="<?php echo esc_attr($settings['team_autoplay']); ?>" data-team-speed="<?php echo esc_attr($settings['team_speed']); ?>" data-team-item="<?php echo esc_attr($settings['style_car_column']); ?>" data-projects-nav="<?php echo esc_attr($settings['slider_nav']); ?>" data-projects-dots="<?php echo esc_attr($settings['slider_pagination']); ?>" data-team-autoplay-timeout="<?php echo esc_attr($settings['team_autoplay_speed']); ?>" data-bn-car-loop="<?php echo esc_attr($settings['data_car_loop']); ?>" data-carousel-dots-desktop="<?php echo esc_attr($settings['slider_desktop_pagination']); ?>" <?php if ( is_rtl() ) { ?>data-rtl="true"<?php } else { ?>data-rtl="false"<?php } ;?>>
				<?php foreach( $settings['bauen_team_members'] as $bauen_team_member ) { ?>
				<div class="item">
				    <?php if ( $bauen_team_member['button_url'] ) { ?>
					<a class="<?php echo esc_attr($settings['style_type_hover']); ?>" href="<?php echo esc_url($bauen_team_member['button_url']); ?>" target="<?php echo esc_attr($bauen_team_member['button_target']); ?>">
					<?php } ;?>
					<div class="img"> <img src="<?php echo esc_url($bauen_team_member['image']['url']); ?>" class="img-fluid" alt="<?php echo esc_attr($bauen_team_member['alt']); ?>"> </div>					
					<?php if ( $bauen_team_member['button_url'] ) { ?>
					</a>
					<?php } ;?>
					<div class="info">
						<?php if ( $bauen_team_member['title'] ) { ?>
						<h<?php echo esc_attr($settings['title_tag']); ?>><?php echo do_shortcode($bauen_team_member['title']); ?></h<?php echo esc_attr($settings['title_tag']); ?>>					
						<?php } ;?>	
						<?php if ( $bauen_team_member['subtitle'] ) { ?>
						<p><?php echo do_shortcode($bauen_team_member['subtitle']); ?></p>
						<?php } ;?>	
						<?php if ( $bauen_team_member['subtitle2'] || $bauen_team_member['social_fb_url'] || $bauen_team_member['social_tw_url'] || $bauen_team_member['social_in_url'] || $bauen_team_member['social_ln_url'] || $bauen_team_member['social_custom_url'] ) { ?>
						<div class="social valign">
							<div class="full-width">
								<?php if ( $bauen_team_member['subtitle2'] ) { ?>
								<p><?php echo do_shortcode($bauen_team_member['subtitle2']); ?></p>
								<?php } ;?>	
								<?php if ( $bauen_team_member['social_fb_url'] ) { ?> 
								<a href="<?php echo esc_url($bauen_team_member['social_fb_url']); ?>" target="<?php echo esc_attr($bauen_team_member['social_url_target']); ?>" rel="noopener noreferrer"><i class="ti-facebook"></i></a>		
								<?php } ;?>	
								<?php if ( $bauen_team_member['social_tw_url'] ) { ?> 
								<a href="<?php echo esc_url($bauen_team_member['social_tw_url']); ?>" target="<?php echo esc_attr($bauen_team_member['social_url_target']); ?>" rel="noopener noreferrer"><i class="fab fa-x-twitter" ></i></a>		
								<?php } ;?>	
								<?php if ( $bauen_team_member['social_in_url'] ) { ?> 
								<a href="<?php echo esc_url($bauen_team_member['social_in_url']); ?>" target="<?php echo esc_attr($bauen_team_member['social_url_target']); ?>" rel="noopener noreferrer"><i class="fab fa-instagram"></i></a>		
								<?php } ;?>	
								<?php if ( $bauen_team_member['social_ln_url'] ) { ?> 
								<a href="<?php echo esc_url($bauen_team_member['social_ln_url']); ?>" target="<?php echo esc_attr($bauen_team_member['social_url_target']); ?>" rel="noopener noreferrer"><i class="ti-linkedin"></i></a>		
								<?php } ;?>										
								<?php echo do_shortcode($bauen_team_member['social_custom_url']); ?>	
							</div>
						</div>
						<?php } ;?>
				    </div>
				</div>
				<?php } ;?>
			</div>		
			<?php } ;?>
		</div>		

        <?php		

	}

}