<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Bauen_Testimonials extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-testimonials';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen Testimonials', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-testimonial-carousel';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-addons' ];
 	}
	
	/**
	 * A list of scripts that the widgets is depended in
	 **/
	public function get_script_depends() {
		return [ 
			'owl-carousel',
			'elementor-testimonials-carousel',
		 ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
			]
		);
		$this->add_control(
			'style_type',
			[
				'label' => __( 'Style Type', 'bauen-plugin' ),
				'description' => __( 'Select style type.', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'st1' => 'Carousel',
					'st2' => 'Grid',
				],
				'default' => 'st1',
				'label_block' => true,
			]
		);	

		$this->add_control(
			'style_grid_column',
			[
				'label' => __( 'Grid Column', 'travol-plugin' ),
				'description' => __( '', 'travol-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'col-md-3' => '4 Columns',
					'col-md-4' => '3 Columns',
					'col-md-6' => '2 Columns',
					'col-md-12' => '1 Column',
				],
				'default' => 'col-md-4',
				'label_block' => true,
				'condition' =>  ['style_type' => ['st2']],
			]			
		);
		
		$this->add_control(
			'main_title',
			[
				'label' => __( 'Title', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => 'Add Title',
				'description' => __( '', 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'style_type' => 'st1',
				],				
			]
		);		
        $this->add_control(
			'title_tag',
			[
				'label' => __( 'Title Tag', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'1' => 'h1',
					'2' => 'h2',
					'3' => 'h3',
					'4' => 'h4',
					'5' => 'h5',
					'6' => 'h6',
				],
				'default' => '4',
				'label_block' => true,
				'condition' => [
					'style_type' => 'st1',
				],				
			]
		);			
		$repeater = new \Elementor\Repeater();
		
		$repeater->add_control(
			'image',
			[
				'label' => __( 'Client Image', 'bauen-plugin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => '',
				],
				'label_block' => true,				
			]
		);
		
		$repeater->add_control(
			'title', [
				'label' => __( 'Client Name', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Jason Brown' , 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);	

		$repeater->add_control(
			'subtitle', [
				'label' => __( 'Client Designation', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Crowne Plaza Owner' , 'bauen-plugin' ),
				'label_block' => true,
				'dynamic' => [
					'active' => true,
				],
			]
		);	

		$repeater->add_control(
			'block-content', [
				'label' => __( 'Client Quote', 'bauen-plugin' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => __('Architect dapibus augue metus the nec feugiat erat hendrerit nec. Duis ve ante the lemon sanleo nec feugiat erat hendrerit necuis ve ante.', 'bauen-plugin'),
				'label_block' => true,
			]
		);		
		
		$this->add_control(
			'bauen_testimonials',
			[
				'label' => __( 'Testimonial', 'bauen-plugin' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'title' => __('Jason Brown', 'bauen-plugin'),
					],
					[
						'title' => __('Emily White', 'bauen-plugin'),
					],
					[
						'title' => __('Jesica Smith', 'bauen-plugin'),
					],					
				],
			]
		);

		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_settings',
			[
				'label' => __( 'Carousel Settings', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'style_type' => 'st1',
				],				
			]
		);
		
		$this->add_control(
			'testimonials_autoplay',
			[
				'label' => __( 'Carousel Autoplay', 'bauen-plugin' ),
				'description' => __( '', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'true' => 'Enable',
					'false' => 'Disable',
				],
				'default' => 'false',
				'label_block' => true,
			]			
		);	

		$this->add_control(
			'testimonials_autoplay_speed',
			[
				'label' => __( 'Autoplay Timeout', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '5000',
				'description' => __( 'Default: 5000', 'bauen-plugin' ),
				'label_block' => true,
				'condition' => [
					'testimonials_autoplay' => 'true',
				],
			]
		);
		
		$this->add_control(
			'testimonials_speed',
			[
				'label' => __( 'Carousel Speed', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '500',
				'description' => __( 'Default: 500', 'bauen-plugin' ),
				'label_block' => true,
				'condition' => [
					'testimonials_autoplay' => 'true',
				],
			]
		);
		
		$this->add_control(
			'carousel_dots_bg_color',
			[
				'label' => __( 'Carousel Navigation Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .owl-theme .owl-dots .owl-dot.active span' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .owl-theme .owl-dots .owl-dot:hover span' => 'background-color: {{VALUE}};',			
				],
				'default' =>'',
			]
		);			
		$this->add_control(
			'carousel_dots_border_color',
			[
				'label' => __( 'Carousel Navigation Border Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .owl-theme .owl-dots .owl-dot.active span' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .owl-theme .owl-dots .owl-dot:hover span' => 'border-color: {{VALUE}};',					
					'{{WRAPPER}} .owl-theme .owl-dots .owl-dot span' => 'border-color: {{VALUE}};',					
				],
				'default' =>'',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_main_title',
			[
				'label' => __( 'Title Options', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'style_type' => 'st1',
				],				
			]
		);
		
		$this->add_control(
			'main_title_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonials-box .head-box h1' => 'color: {{VALUE}};',
					'{{WRAPPER}} .testimonials-box .head-box h2' => 'color: {{VALUE}};',
					'{{WRAPPER}} .testimonials-box .head-box h3' => 'color: {{VALUE}};',
					'{{WRAPPER}} .testimonials-box .head-box h4' => 'color: {{VALUE}};',
					'{{WRAPPER}} .testimonials-box .head-box h5' => 'color: {{VALUE}};',
					'{{WRAPPER}} .testimonials-box .head-box h6' => 'color: {{VALUE}};',
				],				
			]
		);
		$this->add_control(
			'border_bg_color',
			[
				'label' => __( 'Border Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonials-box .head-box h4' => 'border-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'main_title_typography',
				'selector' => '{{WRAPPER}} .testimonials-box .head-box h1, {{WRAPPER}} .testimonials-box .head-box h2, {{WRAPPER}} .testimonials-box .head-box h3, {{WRAPPER}} .testimonials-box .head-box h4, {{WRAPPER}} .testimonials-box .head-box h5, {{WRAPPER}} .testimonials-box .head-box h6',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_title',
			[
				'label' => __( 'Client Name', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonials .item .info h6' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .testimonials .item .info h6',
			]
		);
		$this->end_controls_section();		
		
		$this->start_controls_section(
			'section_style_subtitle',
			[
				'label' => __( 'Client Designation', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'subtitle_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonials .item .info span' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'subtitle_typography',
				'selector' => '{{WRAPPER}} .testimonials .item .info span',
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_content',
			[
				'label' => __( 'Client Quote', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'content_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonials .item p' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'text_typography',
				'selector' => '{{WRAPPER}} .testimonials .item p',
			]
		);		
				
		$this->end_controls_section();	

		$this->start_controls_section(
			'section_style_background',
			[
				'label' => __( 'Background Color', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,					
			]
		);	
		
		$this->add_control(
			'box_bg_color',
			[
				'label' => __( 'Box Background', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonials-box' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .light-version .sec-testimonials.testimonials .item' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .dark-version .sec-testimonials.testimonials .item' => 'background-color: {{VALUE}};',
				],
				'default' =>'',
			]
		);	

       	$this->end_controls_section();		

	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>

        <?php if ( $settings['style_type'] == 'st2' ) { ?>
		<div class="sec-testimonials testimonials">
		    <div class="row">
				<?php foreach( $settings['bauen_testimonials'] as $bauen_testimonial ) { ?>
				<div class="<?php echo esc_attr($settings['style_grid_column']); ?>">
					<div class="item testimonials-box bg"> 
						<span class="quote"><img src="<?php echo (BAUEN_THEME_URL) ;?>/includes/images/quot.png" alt="<?php esc_attr_e('quote','bauen');?>"></span>
						<p><?php echo do_shortcode($bauen_testimonial['block-content']); ?></p>
						<div class="info">
							<div class="author-img"> <img src="<?php echo esc_url($bauen_testimonial['image']['url']); ?>" alt="<?php echo esc_attr($bauen_testimonial['alt']); ?>"> </div>
							<div class="cont">
								<?php if ( $bauen_testimonial['title'] ) { ?>
								<h6><?php echo esc_html($bauen_testimonial['title']); ?></h6> 
								<?php } ;?>	
								<?php if ( $bauen_testimonial['subtitle'] ) { ?>
								<span><?php echo esc_html($bauen_testimonial['subtitle']); ?></span>
								<?php } ;?>		
							</div>
						</div>										
					</div>
				</div>
				<?php } ;?>	
			</div>		
		</div>			
		<?php } 
		else { ?>			
		<div class="testimonials">
			<div class="sec-testimonials-carousel testimonials-box">
			    <?php if ( $settings['main_title'] ) { ?>
				<div class="head-box">
					<h<?php echo esc_attr($settings['title_tag']); ?>><?php echo do_shortcode($settings['main_title']); ?></h<?php echo esc_attr($settings['title_tag']); ?>>
				</div>	
				<?php } ;?>
				<div class="owl-carousel owl-theme" data-testimonials-autoplay="<?php echo esc_attr($settings['testimonials_autoplay']); ?>" data-testimonials-speed="<?php echo esc_attr($settings['testimonials_speed']); ?>" data-testimonials-autoplay-timeout="<?php echo esc_attr($settings['testimonials_autoplay_speed']); ?>" <?php if ( is_rtl() ) { ?>data-rtl="true"<?php } else { ?>data-rtl="false"<?php } ;?>>
					<?php foreach( $settings['bauen_testimonials'] as $bauen_testimonial ) { ?>
					<div class="item"> <span class="quote"><img src="<?php echo (BAUEN_THEME_URL) ;?>/includes/images/quot.png" alt="<?php esc_attr_e('quote','bauen');?>"></span>
						<p><?php echo do_shortcode($bauen_testimonial['block-content']); ?></p>
						<div class="info">
							<?php if ( $bauen_testimonial['image']['url'] ) { ?>
							<div class="author-img"> <img src="<?php echo esc_url($bauen_testimonial['image']['url']); ?>" alt="<?php echo esc_attr($bauen_testimonial['image']['alt']); ?>"> </div>
							<?php } ;?>
							<div class="cont <?php if ( !$bauen_testimonial['image']['url'] ) { ?>bn-left-off<?php } ;?>">
								<?php if ( $bauen_testimonial['title'] ) { ?>
								<h6><?php echo esc_html($bauen_testimonial['title']); ?></h6><?php } ;?>	
								<?php if ( $bauen_testimonial['subtitle'] ) { ?>
								<span><?php echo esc_html($bauen_testimonial['subtitle']); ?></span>
								<?php } ;?>		
							</div>
						</div>										
					</div>
					<?php } ;?>
				</div>		
			</div>		
		</div>	
		<?php } ;?>

        <?php		

	}

}