<?php
namespace BAUENEL\Widgets;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Bauen_Video extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bauen-video';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Bauen Video', 'bauen-plugin' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-youtube';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'bauen-addons' ];
 	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'bauen-plugin' ),
			]
		);
		
		$this->add_control(
			'video_url',
			[
				'label' => __( 'YouTube Video URL', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'description' => __( 'Ex: https://youtu.be/RziCmLzpFNY', 'bauen-plugin' ),
				'label_block' => true,
			]
		);
		
		$this->add_control(
			'caption',
			[
				'label' => __( 'Video Caption', 'bauen-plugin' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => '',
				'description' => __( 'Ex: View promo video', 'bauen-plugin' ),
				'label_block' => true,
			]
		);						
		$this->add_control(
			'style_type',
			[
				'label' => __( 'Play Button Icon', 'bauen-plugin' ),
				'description' => __( 'Select style type.', 'bauen-plugin' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'st1' => 'Default Icon',
					'st2' => 'Custom Icon',
				],
				'default' => 'st1',
				'label_block' => true,
			]
		);	
        $this->add_control(
			'icon_class',
			[
				'label' => esc_html__( 'Icon', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fa fa-play',
					'library' => 'solid',
				],
                'skin' =>'inline',
				'label_block' => false,
				'exclude_inline_options' => [ 'svg' ],
				'condition' => [
					'style_type' => 'st2',
				],				
			]
		);		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_caption',
			[
				'label' => __( 'Caption', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'caption_color',
			[
				'label' => __( 'Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .vid-area h5' => 'color: {{VALUE}};',
				],
				'default' =>'',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'caption_typography',
				'selector' => '{{WRAPPER}} .vid-area h5',
			]
		);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_style_background',
			[
				'label' => __( 'Play Button', 'bauen-plugin' ),
				'tab' => Controls_Manager::TAB_STYLE,					
			]
		);			
		$this->add_control(
			'bg_color',
			[
				'label' => __( 'Background Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .circle-fill circle' => 'fill: {{VALUE}};',
				],
				'default' =>'',
			]
		);	
		$this->add_control(
			'icon_color',
			[
				'label' => __( 'Icon Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .vid-area i' => 'color: {{VALUE}};',
				],
				'default' =>'#fff',
			]
		);			
		$this->add_control(
			'border_color',
			[
				'label' => __( 'Border Color', 'bauen-plugin' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .circle-fill circle' => 'stroke: {{VALUE}};',
					'{{WRAPPER}} .circle-track circle' => 'stroke: {{VALUE}};',
				],
				'default' =>'',
			]
		);			
		$this->end_controls_section();			
		
		
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>
		
		<div class="vid-area">
		    <?php if ( $settings['video_url'] ) { ?>
			<div class="vid-icon">
				<a class="play-button vid" href="<?php echo esc_url($settings['video_url']); ?>"  class="play-button vid js-video-button glightbox">
					<svg class="circle-fill">
						<circle cx="43" cy="43" r="39" stroke="#fff" stroke-width=".5"></circle>
					</svg>
					<svg class="circle-fill">
						<circle cx="43" cy="43" r="39" stroke="none" stroke-width="1" fill="none"></circle>
					</svg> <span class="polygon">
                    <?php if ( $settings['style_type'] == 'st2' ) { ?>
					    <?php \Elementor\Icons_Manager::render_icon( $settings['icon_class'], [ 'aria-hidden' => 'true' ] ); ?>
					<?php } 
					else { ?>	
					    <i class="ti-control-play"></i>
					<?php } ;?>						
						
					</span> 
				</a>
			</div>
			<?php };?>
			<?php if ( $settings['caption'] ) { ?>
			<div class="cont mt-15 mb-30">
				<h5><?php echo do_shortcode($settings['caption']); ?></h5>
			</div>
			<?php };?>
		</div>		
								
        <?php
		

	}

}