<?php
    /**
     * ReduxFramework Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }


    // This is your option name where all the Redux data is stored.
    $opt_name = "bauen";

    // This line is only for altering the demo. Can be easily removed.
    $opt_name = apply_filters( 'bauen/opt_name', $opt_name );
	/*
     *
     * --> Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
     *
     */

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
		'class'                => 'admin-color-pimax',
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => esc_html__( 'Bauen Options', 'bauen' ),
        'page_title'           => esc_html__( 'Bauen Options', 'bauen' ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => 'AIzaSyCN8bSGZHdbSOXu0HbhXf8j0SnswTmbCNw',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => true,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => false,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => false,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => true,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => 90,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => 'bauen_opt',
        // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the bauen. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'red',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'bauen'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'bauen'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    
    // Panel Intro text -> before the form
    if ( ! isset( $args['global_variable'] ) || $args['global_variable'] !== false ) {
        if ( ! empty( $args['global_variable'] ) ) {
            $v = $args['global_variable'];
        } else {
            $v = str_replace( '-', '_', $args['opt_name'] );
        }
        $args['intro_text'] = sprintf( esc_html__( '', 'bauen' ), $v );
    } else {
        $args['intro_text'] = esc_html__( '', 'bauen' );
    }

    // Add content after the form.
    $args['footer_text'] = esc_html__( '', 'bauen' );

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */


    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => esc_html__( 'Support', 'bauen' ),
            'content' => esc_html__( 'Send us a mail by using our item support form.', 'bauen' )
        ),
        
    );
    Redux::set_help_tab( $opt_name, $tabs );

    // Set the help sidebar
    $content = esc_html__( 'Send us a mail by using our item support form.', 'bauen' );
    Redux::set_help_sidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    /*

        As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for


     */

    // ACTUAL DECLARATION OF SECTIONS
                Redux::setSection( $opt_name, array(
                    'title'  => esc_html__( 'General Settings', 'bauen' ),
                    'desc'   => esc_html__( '', 'bauen' ),
                    'icon'   => 'el el-icon-home-alt',
                    // 'submenu' => false, // Setting submenu to false on a given section will hide it from the WordPress sidebar menu!
                    'fields' => array(
					
						array(
							'id' => 'notice_maintenance_mode_opt',
							'type' => 'info',
							'notice' => true,
							'style' => 'success',
							'title' => esc_html__('Maintenance Mode Options.', 'bauen'),
							'desc' => __('Enable/ Disable Maintenance Mode.', 'bauen')
						),
						
						array(
								'id' => 'coming_soon_opt',
								'type' => 'button_set',
								'title' => esc_html__('Maintenance Mode', 'bauen'),
								'subtitle' => esc_html__('', 'bauen'),
								'desc' => '',
								'options' => array(
									'st1'=> esc_html__('Disable', 'bauen'),
									'st2' => esc_html__('Enable', 'bauen'),
								),
								'default'  => 'st1'
						),
						
						array(
							'id' => 'notice_gutenberg_opt',
							'type' => 'info',
							'notice' => true,
							'style' => 'success',
							'title' => esc_html__('Gutenberg Editor Options.', 'bauen'),
							'desc' => __('Enable/ Disable Gutenberg Editor.', 'bauen')
						),
						array(
								'id' => 'opt_theme_gutenberg',
								'type' => 'button_set',
								'title' => esc_attr__('Gutenberg Editor', 'travol'),
								'subtitle' => esc_attr__('Enable/ Disable Gutenberg Editor.', 'travol'),
								'desc' => '',
								'options' => array(
									'st1'=> esc_html__('Disable', 'travol'),
									'st2' => esc_html__('Enable', 'travol'),
								),
								'default'  => 'st1'
						),
						
						array(
							'id' => 'notice_custom_cursor_mode_opt',
							'type' => 'info',
							'notice' => true,
							'style' => 'success',
							'title' => esc_html__('Custom Cursor Options.', 'bauen'),
							'desc' => __('Enable/ Disable Custom Cursor.', 'bauen')
						),
						
						array(
							'id' => 'custom_cursor_opt',
							'type' => 'button_set',
							'title' => esc_html__('Custom Cursor', 'bauen'),
							'subtitle' => esc_attr__('Enable/ Disable custom cursor.', 'bauen'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('Disable', 'bauen'),
								'st2' => esc_html__('Enable', 'bauen'),
							),
							'default'  => 'st1'
						),
						
						array(
							'id' => 'opt_cursor_swipe',
							'type' => 'text',
							'title' => esc_html__('Swipe', 'bauen'),
							'subtitle' => esc_html__('Text Translation Options e.x: Close', 'bauen'),
							'required' => array('custom_cursor_opt', '=' , 'st2')
						),
						
						array(
							'id' => 'opt_cursor_play',
							'type' => 'text',
							'title' => esc_html__('Play', 'bauen'),
							'subtitle' => esc_html__('Text Translation Options e.x: Play', 'bauen'),
							'required' => array('custom_cursor_opt', '=' , 'st2')
						),
						
						array(
							'id' => 'opt_cursor_open',
							'type' => 'text',
							'title' => esc_html__('Open', 'bauen'),
							'subtitle' => esc_html__('Text Translation Options e.x: Open', 'bauen'),
							'required' => array('custom_cursor_opt', '=' , 'st2')
						),
						
						array(
                            'id'          => 'typo_cursor',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Cursor Text', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'compiler'      => array('body .element-item.slider_hover:after'),
                            'units'       =>'px',
							'line-height'       =>false,
							'text-align' => false,
                            'subtitle'    => esc_html__('Specify the P Text font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
                            ),
							'required' => array('custom_cursor_opt', '=' , 'st2')
						),
						
						array(
								'id' => 'notice_header_logo',
								'type' => 'info',
								'notice' => true,
								'style' => 'success',
								'title' => esc_html__('Logo Options', 'bauen'),
								'desc' => esc_html__('Logo options of your site header.', 'bauen')
						),						
						array(
								'id' => 'image_logo',
								'type' => 'button_set',
								'title' => esc_html__('Image Logo', 'bauen'),
								'subtitle' => esc_html__('', 'bauen'),
								'desc' => '',
								'options' => array(
									'st1'=> esc_html__('Disable', 'bauen'),
									'st2' => esc_html__('Enable', 'bauen'),
								),
								'default'  => 'st1'
						),					
						array(
								'id' => 'logopic',
								'type' => 'media',
								'title' => esc_html__('Upload Logo', 'bauen'),
								'subtitle' => esc_html__('', 'bauen'),
								'required' => array('image_logo', '=' , 'st2')
						),
						
						array(
								'id' => 'nav_scroll_logo',
								'type' => 'button_set',
								'title' => esc_html__('Sticky Logo Selection', 'bauen'),
								'subtitle' => esc_html__('Working only for Classic and Click  menu style.', 'bauen'),
								'desc' => '',
								'options' => array(
									'st1'=> esc_html__('Disable', 'bauen'),
									'st2' => esc_html__('Enable', 'bauen'),
								),
								'default'  => 'st1',
								'required' => array('image_logo', '=' , 'st2')
						),	
						
						array(
								'id' => 'nav_scroll_logo_visiabilty',
								'type' => 'button_set',
								'title' => esc_html__('Show Sticky Logo Image', 'bauen'),
								'subtitle' => esc_html__('Working only for Classic and Click menu style.', 'bauen'),
								'desc' => '',
								'options' => array(
									'st1'=> esc_html__('On Scroll', 'bauen'),
									'st2' => esc_html__('Always', 'bauen'),
								),
								'default'  => 'st1',
								'required' => array('nav_scroll_logo', '=' , 'st2')
						),
						
						array(
								'id' => 'nav_scroll_logo_responsive_visiabilty',
								'type' => 'button_set',
								'title' => esc_html__('Show Sticky Logo Image On Mobile', 'bauen'),
								'subtitle' => esc_html__('Working only for Classic and Click menu style. Media width 767px.', 'bauen'),
								'desc' => '',
								'options' => array(
									'st1'=> esc_html__('On Scroll', 'bauen'),
									'st2' => esc_html__('Always', 'bauen'),
								),
								'default'  => 'st1',
								'required' => array('nav_scroll_logo', '=' , 'st2')
						),

						array(
							'id' => 'logopic_dark',
							'type' => 'media',
							'title' => esc_html__('Upload Sticky Navigation Logo', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'required' => array('nav_scroll_logo', '=' , 'st2')
						),						

						$fields = array(
							'id'       => 'opt_logo_dimensions',
							'type'     => 'dimensions',
							'units'    => array('em','px','%'),
							'output' => array('img.logo-img', '.bauen-header .bauen-logo img.logo-img', '#bauen-aside .bauen-logo img.logo-img', '.navbar:not(.bn-classic-main-wrapper) div.logo', '.bauen-menu-click div.logo'),
							'title'    => __('Logo Dimensions', 'bauen'),
							'subtitle' => __('.', 'bauen'),
							'desc'     => __('Optional', 'bauen'),
							'required' => array('image_logo', '=' , 'st2')
						),
						
						$fields = array(
						'id'       => 'opt_sticky_logo_dimensions',
						'type'     => 'dimensions',
						'units'    => array('em','px','%'),
						'output' => array('.nav-scroll .logo-img', '.bn-click-main.scrolled.bauen-header .bauen-logo img.logo-img', '.bauen-menu-click.scrolled img.logo-img','.nav-scroll.navbar:not(.bn-classic-main-wrapper) div.logo'),
						'title'    => __('Sticky Logo Dimensions', 'bauen'),
						'subtitle' => __('', 'bauen'),
						'desc'     => __('Optional', 'bauen'),
						'required' => array('image_logo', '=' , 'st2')
						),
						
						$fields = array(
							'id'       => 'opt_logo_mobile_dimensions',
							'type'     => 'dimensions',
							'units'    => array('em','px','%'),
							'output' => array('body.is-mobile .logo-img', 'body.is-mobile .nav-scroll .logo-img', 'body.is-mobile .bn-click-main.scrolled.bauen-header .bauen-logo img.logo-img', 'body.is-mobile .bauen-menu-click.scrolled img.logo-img', 'body.is-mobile .nav-scroll div.logo', 'body.is-mobile .navbar .logo', '.is-mobile .bauen-menu-click div.logo'),
							'title'    => esc_html__('Responsive Logo Dimensions', 'bauen'),
							'subtitle' => __('Media width 768px<br> Max Width 200px.', 'bauen'),
							'desc'     => __('Optional', 'bauen'),
							'default'  => array(
								'Width'   => '', 
								'Height'  => ''
							),
							'required' => array('image_logo', '=' , 'st2')
						),
						
						array(
							'id' => 'text_logo',
							'type' => 'button_set',
							'title' => esc_html__('Text Logo', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('Disable', 'bauen'),
								'st2' => esc_html__('Enable', 'bauen'),
							),
							'default'  => 'st2'
						),						
						array(
							'id' => 'logo_text_title',
							'type' => 'text',
							'title' => esc_html__('Logo Text', 'bauen'),
							'subtitle' => esc_html__('Ex: BAUEN', 'bauen'),
							'required' => array('text_logo', '=' , 'st2')								
						),
						array(
							'id' => 'logo_text_sub',
							'type' => 'text',
							'title' => esc_html__('Logo Tagline Text', 'bauen'),
							'subtitle' => esc_html__('Ex: INNOVATE DESIGN', 'bauen'),
							   'required' => array('text_logo', '=' , 'st2')	
						),

						array(
							'id' => 'notice_site_nav_menu',
							'type' => 'info',
							'notice' => true,
							'style' => 'success',
							'title' => esc_html__('Nav Menu Options.', 'bauen'),
							'desc' => esc_html__('Select Nav Menu Style.', 'bauen'),
									
						),						
							
						array(
							'id' => 'nav_menu_style',
							'type' => 'select',
							'title' => esc_html__('Nav Menu Style', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('Classic', 'bauen'),
								'st2' => esc_html__('Hamburger', 'bauen'),
								'st3'=> esc_html__('Classic Fullscreen', 'bauen'),
								'st4'=> esc_html__('Hamburger Fullscreen', 'bauen'),
								'st5' => esc_html__('Sidebar', 'bauen'),
							),
							'default'  => 'st1'
						),
						
						array(
							'id' => 'nav_sidebar_logo_visiabilty',
							'type' => 'button_set',
							'title' => esc_html__('Right Side Logo Display', 'bauen'),
							'subtitle' => esc_html__('Working only for Sidebar menu style.', 'bauen'),
							'desc' => 'Media width 767px.',
							'options' => array(
								'st1'=> esc_html__('Disable', 'bauen'),
								'st2' => esc_html__('Enable', 'bauen'),
							),
							'default'  => 'st1',
							'required' => array('nav_menu_style', '=' , 'st5')
						),

						array(
							'id' => 'header_nav_sticky',
							'type' => 'button_set',
							'title' => esc_html__('Sticky Navigation', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'desc' => 'Not affected only for sidebar menu style.',
							'options' => array(
								'st1'=> esc_html__('Enable', 'bauen'),
								'st2' => esc_html__('Disable', 'bauen'),
							),
							'default'  => 'st1',
						),
						
						array(
							'id' => 'header_nav_parent_anchor',
							'type' => 'button_set',
							'title' => esc_html__('Parent Menu Permalink', 'bauen'),
							'subtitle' => esc_html__('Affected only for classic menu styles.', 'bauen'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('Disable', 'bauen'),
								'st2' => esc_html__('Enable', 'bauen'),
							),
							'default'  => 'st1',
						),	
						
						array(
								'id' => 'header_color_style',
								'type' => 'button_set',
								'title' => esc_html__('Nav Menu Color Style', 'bauen'),
								'subtitle' => esc_html__('', 'bauen'),
								'desc' => '',
								'options' => array(
										'no'=> esc_html__('Black', 'bauen'),
										'yes' => esc_html__('White', 'bauen'),
										
								),
								'default'  => 'no',
						),	
						array(
								'id' => 'header_logo_sub_color_style',
								'type' => 'button_set',
								'title' => esc_html__('Logo Tag Line Color Style', 'bauen'),
								'subtitle' => esc_html__('', 'bauen'),
								'desc' => '',
								'options' => array(
									'no'=> esc_html__('Gray', 'bauen'),
									'yes' => esc_html__('White', 'bauen'),
								),
								'default'  => 'no',
						),		
						array(
								'id' => 'notice_header_contact_info_social',
								'type' => 'info',
								'notice' => true,
								'style' => 'success',
								'title' => esc_html__('Social Icon Options', 'bauen'),
								'desc' => esc_html__('', 'bauen'),
								'required' => array('nav_menu_style', '=' , 'st5')
						),
							
						array(
								'id' => 'en_header_social_opt',
								'type' => 'button_set',
								'title' => esc_html__('Social Icon', 'bauen'),
								'subtitle' => esc_html__('', 'bauen'),
								'desc' => '',
								'options' => array(
										'st1'=> esc_html__('Disable', 'bauen'),
										'st2' => esc_html__('Enable', 'bauen'),
								),
								'default'  => 'st1',
								'required' => array('nav_menu_style', '=' , 'st5')
						),	

						
						array(
							'id' => 'notice_header_contact_info',
							'type' => 'info',
							'notice' => true,
							'style' => 'success',
							'title' => esc_html__('Hamburger Menu Info Options', 'bauen'),
							'desc' => esc_html__('', 'bauen'),
						),
						array(
							'id' => 'menu_contact_info',
							'type' => 'button_set',
							'title' => esc_html__('Menu Info', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'desc' => '',
							'options' => array(
								'no'=> esc_html__('Disable', 'bauen'),
								'yes' => esc_html__('Enable', 'bauen'),
							),
							'default'  => 'yes',
						),						
					    array(
								'id' => 'notice_header_contact_info_email',
								'type' => 'info',
								'notice' => true,
								'style' => 'success',
								'title' => esc_html__('Contact Info', 'bauen'),
								'desc' => esc_html__('', 'bauen'),
								'required' => array('menu_contact_info', '=' , 'yes')
						),
						array(
								'id' => 'hd_email_address1',
								'type' => 'text',
								
								'title' => esc_html__('Email Address 1', 'bauen'),
								'subtitle' => esc_html__('', 'bauen'),
								'required' => array('menu_contact_info', '=' , 'yes')
						),
						
						array(
								'id' => 'hd_email_address2',
								'type' => 'text',
								
								'title' => esc_html__('Email Address 2', 'bauen'),
								'subtitle' => esc_html__('', 'bauen'),
								'required' => array('menu_contact_info', '=' , 'yes')
						),
																								
						array(
								'id' => 'hd_phn_number1',
								'type' => 'text',
								
								'title' => esc_html__('Phone Number 1', 'bauen'),
								'subtitle' => esc_html__('', 'bauen'),
								'required' => array('menu_contact_info', '=' , 'yes')								
						),
						
						array(
								'id' => 'hd_phn_number2',
								'type' => 'text',
								
								'title' => esc_html__('Phone Number 2', 'bauen'),
								'subtitle' => esc_html__('', 'bauen'),
								'required' => array('menu_contact_info', '=' , 'yes')
						),
						
					
						array(
							'id' => 'notice_site_preloader',
							'type' => 'info',
							'notice' => true,
							'style' => 'success',
							'title' => esc_html__('Preloader Options.', 'bauen'),
							'desc' => esc_html__('', 'bauen'),
						),
						
						array(
							'id' => 'enable_preloader',
							'type' => 'button_set',
							'title' => esc_html__('Preloader', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'desc' => '',
							'options' => array(
								'no'=> esc_html__('Disable', 'bauen'),
								'yes' => esc_html__('Enable', 'bauen'),
							),
							'default'  => 'yes'
						),															
						
						array(
							'id' => 'opt_preloader_style',
							'type' => 'button_set',
							'title' => esc_html__('Preloader Style', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('Style 1', 'bauen'),
								'st2' => esc_html__('Style 2', 'bauen'),
								'st3' => esc_html__('Style 3', 'bauen'),
							),
							'default'  => 'st1',
							'required' => array('enable_preloader', '=' , 'yes')
						),	

						array(
							'id' => 'preloader_logopic',
							'type' => 'media',
							
							'title' => esc_html__('Upload Preloader Logo', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'required' => array('opt_preloader_style', '=' , 'st3'),
							'default' => array('url' => BAUEN_THEME_URL .'/includes/images/logo.png'),
						),
						
						$fields = array(
							'id'       => 'opt_preloadercircle_dimensions',
							'type'     => 'dimensions',
							'units'    => array('em','px','%'),
							'output' => array('body .preloader__progress'),
							'title'    => __('Preloader Circle Dimensions', 'bauen'),
							'subtitle' => __('', 'bauen'),
							'desc'     => __('Optional', 'bauen'),
							'required' => array('opt_preloader_style', '=' , 'st3'),
						),
						
						$fields = array(
							'id'       => 'opt_preloaderlogo_dimensions',
							'type'     => 'dimensions',
							'units'    => array('em','px','%'),
							'output' => array('body .ptr-prel-image'),
							'title'    => __('Preloader Logo Dimensions', 'bauen'),
							'subtitle' => __('', 'bauen'),
							'desc'     => __('Optional', 'bauen'),
							'required' => array('opt_preloader_style', '=' , 'st3'),
						),
						
						array(
							'id' => 'notice_site_lines',
							'type' => 'info',
							'notice' => true,
							'style' => 'success',
							'title' => esc_html__('Content Lines Option', 'bauen'),
							'desc' => esc_html__('', 'bauen'),
						),								
						array(
							'id' => 'content_lines',
							'type' => 'button_set',
							'title' => esc_attr__('Content Lines', 'bauen'),
							'subtitle' => esc_attr__('', 'bauen'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('Enable', 'bauen'),
								'st2' => esc_html__('Disable', 'bauen'),
							),
							'default'  => 'st1'
						),	
						array(
							'id' => 'notice_site_scrollbar',
							'type' => 'info',
							'notice' => true,
							'style' => 'success',
							'title' => esc_html__('Scrollbar Option', 'bauen'),
							'desc' => esc_html__('', 'bauen'),
						),						
						array(
								'id' => 'scrollbar',
								'type' => 'button_set',
								'title' => esc_attr__('Scrollbar Style', 'bauen'),
								'subtitle' => esc_attr__('Browser Scrollbar', 'bauen'),
								'options' => array(
										'st1'=> esc_html__('Enable', 'bauen'),
										'st2' => esc_html__('Disable', 'bauen'),
								),
								'default'  => 'st1'						
						),											
						array(
							'id' => 'notice_site_aniamte',
							'type' => 'info',
							'notice' => true,
							'style' => 'success',
							'title' => esc_html__('Animate Effect Option', 'bauen'),
							'desc' => esc_html__('', 'bauen'),
						),
								
						array(
							'id' => 'animate_style',
							'type' => 'button_set',
							'title' => esc_attr__('Animate Effect', 'bauen'),
							'subtitle' => esc_attr__('', 'bauen'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('Disable', 'bauen'),
								'st2' => esc_html__('Enable', 'bauen'),										
							),
							'default'  => 'st1'
						),											
					
				  )
               ) );
			  
				Redux::setSection( $opt_name, array(
                'icon'   => 'el el-icon-idea',
                'title'  => esc_html__( 'Header Options', 'bauen' ),
                'fields' => array(					
					
					array(
						'id' => 'logo_adjustment',
						'type' => 'info',
		                'notice' => true,
		                'style' => 'info',
						'title' => esc_html__('Header Logo Options', 'bauen'),
						'desc' => __('Control your site logo position.', 'bauen')
					),
					$fields = array(
						'id'             => 'opt_main_logo_spacing',
						'type'           => 'spacing',
						'compiler'         => array('body:not(.is-mobile) .bauen-header:not(.scrolled) .bauen-logo img', 'body:not(.is-mobile) .bauen-menu-click:not(.scrolled) .logo img'),
						'mode'           => 'margin',
						'units'          => array('px', 'em'),
						'right'   => false, 
						'bottom'  => false, 
						'left'    => false,
						'units_extended' => 'false',
						'title'          => __('Logo Top Margin', 'bauen'),
						'subtitle'       => __('Default: 0px', 'bauen'),
						'desc'           => __('', 'bauen'),
						'default'            => array(
							'margin-top'     => '', 
							'margin-right'   => '0px', 
							'margin-bottom'  => '0px', 
							'margin-left'    => '0px',
							'units'          => 'px', 
					),
					'required' => array('image_logo', '=' , 'st2')
					),
					$fields = array(
						'id'             => 'opt_sticky_logo_spacing',
						'type'           => 'spacing',
						'compiler'         => array('body:not(.is-mobile) .bauen-header.scrolled .bauen-logo img', 'body:not(.is-mobile) .bauen-menu-click.scrolled .logo img'),
						'mode'           => 'margin',
						'units'          => array('px', 'em'),
						'right'   => false, 
						'bottom'  => false, 
						'left'    => false,
						'units_extended' => 'false',
						'title'          => __('Sticky Logo Top Margin', 'bauen'),
						'subtitle'       => __('Default: 0px', 'bauen'),
						'desc'           => __('', 'bauen'),
						'default'            => array(
							'margin-top'     => '', 
							'margin-right'   => '0px', 
							'margin-bottom'  => '0px', 
							'margin-left'    => '0px',
							'units'          => 'px', 
						),
					'required' => array('image_logo', '=' , 'st2')
					),
					$fields = array(
						'id'             => 'opt_mobile_sticky_logo_spacing',
						'type'           => 'spacing',
						'compiler'         => array(''),
						'mode'           => 'margin',
						'units'          => array('px', 'em'),
						'right'   => false, 
						'bottom'  => false, 
						'left'    => false,
						'units_extended' => 'false',
						'title'          => __('Responsive Logo Top Margin', 'bauen'),
						'subtitle'       => __('Default: 0px', 'bauen'),
						'desc'           => __('', 'bauen'),
						'default'            => array(
							'margin-top'     => '', 
							'margin-right'   => '0px', 
							'margin-bottom'  => '0px', 
							'margin-left'    => '0px',
							'units'          => 'px', 
						),
						'required' => array('image_logo', '=' , 'st2')
					),
					array(
						'id' => 'notice_site_global_menu_width_opt',
						'type' => 'info',
						'notice' => true,
						'style' => 'success',
						'title' => esc_html__('Menu Container Options', 'bauen'),
						'desc' => esc_html__('Affectedted for Classic Fullscreen Menu & Hamburger Fullscreen Menu.', 'bauen'),
					),
					$fields = array(
						'id'       => 'opt_site_classic_menu_max_width',
						'type'     => 'dimensions',
						'units'    => array('px'),
						//'compiler' => array(''),
						'title'    => esc_html__('Menu Container Width', 'bauen'),
						'subtitle' => __('', 'bauen'),
						'height' => false,
						'desc'     => __('Optional', 'bauen'),
						'default'  => array(
							'width'  => ''
						),
					),
					array(
						'id' => 'notice_site_global_hamburgertoggle_opt',
						'type' => 'info',
						'notice' => true,
						'style' => 'success',
						'title' => esc_html__('Hamburger & Sidebar Menu', 'bauen'),
						'desc' => esc_html__('Control your site toogle menu button position. ', 'bauen'),
					),
					
					$fields = array(
						'id'             => 'opt_main_menu_hum_toggle_spacing',
						'type'           => 'spacing',
						'compiler'         => array('body:not(.is-mobile) .bauen-header:not(.scrolled) .bauen-nav-toggle'),
						'mode'           => 'margin',
						'units'          => array('px', 'em'),
						'right'   => false, 
						'bottom'  => false, 
						'left'    => false,
						'units_extended' => 'false',
						'title'          => __('Menu Toggle Icon Top Margin', 'bauen'),
						'subtitle'       => __('Default: 0px', 'bauen'),
						'desc'           => __('', 'bauen'),
						'default'            => array(
							'margin-top'     => '', 
							'margin-right'   => '0px', 
							'margin-bottom'  => '0px', 
							'margin-left'    => '0px',
							'units'          => 'px', 
							),
						),
						
					$fields = array(
						'id'             => 'opt_stickymenu_hum_toggle_spacing',
						'type'           => 'spacing',
						'compiler'         => array('body:not(.is-mobile) .bauen-header.scrolled .bauen-nav-toggle'),
						'mode'           => 'margin',
						'units'          => array('px', 'em'),
						'right'   => false, 
						'bottom'  => false, 
						'left'    => false,
						'units_extended' => 'false',
						'title'          => __('Sticky  Menu Toggle Icon Top Margin', 'bauen'),
						'subtitle'       => __('Default: 0px', 'bauen'),
						'desc'           => __('', 'bauen'),
						'default'            => array(
							'margin-top'     => '', 
							'margin-right'   => '0px', 
							'margin-bottom'  => '0px', 
							'margin-left'    => '0px',
							'units'          => 'px', 
						),
					),
						
					$fields = array(
						'id'             => 'opt_sticky_menu_hum_toggle_spacing',
						'type'           => 'spacing',
						'compiler'         => array('body.is-mobile .bauen-header.scrolled .bauen-nav-toggle', 'body.is-mobile .bauen-header:not(.scrolled) .bauen-nav-toggle', 'body.is-mobile .bauen-nav-toggle.bn-if-sidebar-nav'),
						'mode'           => 'margin',
						'units'          => array('px', 'em'),
						'right'   => false, 
						'bottom'  => false, 
						'left'    => false,
						'units_extended' => 'false',
						'title'          => __('Responsive  Menu Toggle Icon Top Margin', 'bauen'),
						'subtitle'       => __('Default: 0px', 'bauen'),
						'desc'           => __('', 'bauen'),
						'default'            => array(
							'margin-top'     => '', 
							'margin-right'   => '0px', 
							'margin-bottom'  => '0px', 
							'margin-left'    => '0px',
							'units'          => 'px', 
						),
					),
					array(
						'id' => 'notice_site_global_classic_menu_toggle_opt',
						'type' => 'info',
						'notice' => true,
						'style' => 'success',
						'title' => esc_html__('Classic Menu Options', 'bauen'),
						'desc' => esc_html__('Classic menu Height, Container & Toogle Button options.', 'bauen'),
					),
					
					$fields = array(
						'id'       => 'opt_site_classic_menu_dimensions',
						'type'     => 'dimensions',
						'units'    => array('px'),
						'compiler' => array('body:not(.is-mobile) .navbar'),
						'title'    => esc_html__('Classic Menu Bar Height', 'bauen'),
						'subtitle' => __('', 'bauen'),
						'width' => false,
						'desc'     => __('Optional', 'bauen'),
						'default'  => array(
							'Height'  => ''
						),
					),
						
					$fields = array(
						'id'       => 'opt_site_classic_menu_mob_dimensions',
						'type'     => 'dimensions',
						'units'    => array('px'),
						'compiler' => array('body.is-mobile .navbar'),
						'title'    => esc_html__('Responsive Classic Menu Bar Height', 'bauen'),
						'subtitle' => __('', 'bauen'),
						'width' => false,
						'desc'     => __('Optional', 'bauen'),
						'default'  => array(
							'Height'  => ''
						),
					),
					$fields = array(
						'id'             => 'opt_main_menu_toggle_spacing',
						'type'           => 'spacing',
						'compiler'         => array('body.is-mobile .navbar:not(.nav-scroll) button'),
						'mode'           => 'margin',
						'units'          => array('px', 'em'),
						'right'   => false, 
						'bottom'  => false, 
						'left'    => false,
						'units_extended' => 'false',
						'title'          => __('Menu Toggle Icon Top Margin', 'bauen'),
						'subtitle'       => __('Default: 0px', 'bauen'),
						'desc'           => __('', 'bauen'),
						'default'            => array(
							'margin-top'     => '', 
							'margin-right'   => '0px', 
							'margin-bottom'  => '0px', 
							'margin-left'    => '0px',
							'units'          => 'px', 
						),
						
					),
						
					$fields = array(
						'id'             => 'opt_main_sticky_menu_toggle_spacing',
						'type'           => 'spacing',
						'compiler'         => array('body.is-mobile .navbar.nav-scroll button'),
						'mode'           => 'margin',
						'units'          => array('px', 'em'),
						'right'   => false, 
						'bottom'  => false, 
						'left'    => false,
						'units_extended' => 'false',
						'title'          => __('Sticky Menu Toggle Icon Top Margin', 'bauen'),
						'subtitle'       => __('Default: 0px', 'bauen'),
						'desc'           => __('', 'bauen'),
						'default'            => array(
							'margin-top'     => '', 
							'margin-right'   => '0px', 
							'margin-bottom'  => '0px', 
							'margin-left'    => '0px',
							'units'          => 'px', 
						),
					),
					
				)
                ));
			   
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el el-icon-brush',
                    'title'  => esc_html__( 'Styling', 'bauen' ),
                    'fields' => array(
						array(
							'id' => 'notice_site_theme_color',
							'type' => 'info',
							'notice' => true,
							'style' => 'success',
							'title' => esc_html__('Theme Color Schemes Options.', 'bauen'),
							'desc' => esc_html__('Select Theme Color Scheme.', 'bauen'),
						),						
						array(
							'id' => 'theme_color_style',
							'type' => 'button_set',
							'title' => esc_html__('Theme Color Scheme', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'desc' => '',
							'options' => array(
								'st1' => esc_html__('Light Version', 'bauen'),
								'st2' => esc_html__('Dark Version', 'bauen'),
							),
							'default'  => 'st1'
						),
						array(
							'id' => 'notice_site_global_color',
							'type' => 'info',
							'notice' => true,
							'style' => 'success',
							'title' => esc_html__('Theme Global Color.', 'bauen'),
							'desc' => esc_html__('', 'bauen'),
						),
						array(
							'id'       => 'opt_theme_style',
							'type'     => 'color',
							'title'    => esc_html__( 'Theme Color Option', 'bauen' ),
							'subtitle' => esc_html__( 'Change all global golden color.', 'bauen' ),
							'desc'     => esc_html__( 'Change all global golden color.', 'bauen' ),
							'compiler'    => array(
								'color' => 'body .project-bar h5, body .page-list-icon i',
							),
						),
						
						array(
							'id' => 'notice_site_global_base_color',
							'type' => 'info',
							'notice' => true,
							'style' => 'success',
							'title' => esc_html__('Theme Base Color.', 'bauen'),
							'desc' => esc_html__('', 'bauen'),
						),
						array(
							'id'       => 'opt_theme_base_color',
							'type'     => 'color',
							'title'    => esc_html__( 'Theme Base Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
							'compiler'    => array(
								'background' => 'body .testimonials-box , body .blog-sidebar .search form input, body.dark-version .blog-sidebar .wp-block-search .wp-block-search__input, body .blog-sidebar .wp-block-search .wp-block-search__input, body [data-overlay-light]:before',
								'background-color' => 'body .blog-sidebar .tagcloud a:hover, body .blog-sidebar .widget_tag_cloud .tagcloud a:hover, body.light-version .projects4 .caption, body .projects4 .caption, body .projects4:nth-child(even) .caption',
							),
						),
						array(
							'id'       => 'opt_theme_base_color_2',
							'type'     => 'color',
							'title'    => esc_html__( 'Theme Base Color 2', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
							'compiler'    => array(
								'background' => 'body .about-buro, body .services .item:hover, body .bauen-blog .item .con, body .bg-scheme-1, body.dark-version .bg-scheme-1, body .blog-sidebar .widget, body .error-form .form-group input[type="text"], body .error-form .form-group input[type="search"], body .error-form .form-group input[type="email"], body.dark-version .sec-testimonials.testimonials .item, body.light-version .sec-testimonials.testimonials .item, body .process .item .cont, body .accordion-box .block',
								'border-color' => 'body .bauen-blog .item .con, body .bauen-pagination-wrap li a, body .error-form .form-group input[type="text"], body .error-form .form-group input[type="search"], body .error-form .form-group input[type="email"], body.dark-version .page-list-icon i, body .page-list-icon i, body .process .item .cont, body .process .item .icon, body .position',
								'border-bottom-color' => '.dark-version input[type=email], .dark-version input[type=text], .dark-version textarea, .dark-version input[type=password], .dark-version input[type=url], .dark-version input[type=date], .dark-version input[type=number], body input[type="password"], body input[type="email"], body input[type="text"], body input[type="file"], body input[type="tel"], body textarea',
								'background-color' => 'body.dark-version .project-bar, body  .project-bar, body .accordion-box .block .acc-btn.active, body .accordion-box .block .content, body .pricing-card, body .team .info .social',
							),
						),
						
						array(
							'id'       => 'opt_theme_base_line_color',
							'type'     => 'color_rgba',
							'title'    => esc_html__( 'Line Effect Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
							'compiler'    => array(
								'border-color' => 'body .about .about-img .img:before',
								'border-bottom-color' => 'body .testimonials-box .head-box h4',
							),
						),
						
						array(
							'id' => 'notice_site_global_currsor_color',
							'type' => 'info',
							'notice' => true,
							'style' => 'success',
							'title' => esc_html__('Theme Cursor Color.', 'bauen'),
							'desc' => esc_html__('', 'bauen'),
						),
						array(
							'id'       => 'opt_theme_cursor_base_color',
							'type'     => 'color',
							'title'    => esc_html__( 'Background Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
							'compiler'    => array(
								'background' => 'body .element-item:before', 
							),
						),
						
						array(
							'id'       => 'opt_theme_cursor_shadow_color',
							'type'     => 'color_rgba',
							'title'    => esc_html__( 'Shadow Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_theme_cursor_border_color',
							'type'     => 'color',
							'title'    => esc_html__( 'Border Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
							'compiler'    => array(
								'border-color' => 'body .element-item', 
							),
						),
						
						array(
							'id' => 'notice_site_theme_preloader',
							'type' => 'info',
							'notice' => true,
							'style' => 'success',
							'title' => esc_html__('Site Preloader Options.', 'bauen'),
							'desc' => esc_html__('', 'bauen'),
						),
						
						array(
							'id'       => 'opt_theme_site_theme_preloader_back',
							'type'     => 'color',
							'title'    => esc_html__( 'Background Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_theme_site_theme_preloader_progress_bar',
							'type'     => 'color_rgba',
							'title'    => esc_html__( 'Progress Bar Background Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
							'compiler'    => array(
								'background-color' => 'body .preloader__pulse:before, body  .preloader__pulse:after', 
							),
						),
						
						array(
							'id'       => 'opt_theme_site_theme_preloader_shadow_bar',
							'type'     => 'color_rgba',
							'title'    => esc_html__( 'Progress Bar Shadow Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_theme_site_theme_preloader_progress_bar_active',
							'type'     => 'color',
							'title'    => esc_html__( 'Progress Bar Active Background/ Border Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
							'compiler'    => array(
								'border-color' => 'body .preloader__pulse', 
							),
						),
						
						array(
							'id' => 'notice_site_theme_scroll_to_top',
							'type' => 'info',
							'notice' => true,
							'style' => 'success',
							'title' => esc_html__('Scroll To Top Button Options.', 'bauen'),
							'desc' => esc_html__('', 'bauen'),
						),
						
						array(
							'id'       => 'opt_theme_site_to_top_progress_bar',
							'type'     => 'color_rgba',
							'title'    => esc_html__( 'Progress Bar Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						array(
							'id'       =>'opt_theme_site_theme_scroll_to_top_back_active',
							'type'     => 'color',
							'title'    => esc_html__( 'Progress Bar Active Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id' => 'notice_site_global_page_mainheader_overlay',
							'type' => 'info',
							'notice' => true,
							'style' => 'success',
							'title' => esc_html__('Header Banner Overlay', 'bauen'),
							'desc' => esc_html__('', 'bauen'),
						),
						
						array(
							'id'       => 'opt_site_global_headerbanner_overlay',
							'type'     => 'color_rgba',
							'title'    => esc_html__( 'Overlay Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id' => 'notice_site_global_header_overlay',
							'type' => 'info',
							'notice' => true,
							'style' => 'success',
							'title' => esc_html__('Inner Header Banner Overlay', 'bauen'),
							'desc' => esc_html__('', 'bauen'),
						),
						
						array(
							'id'       => 'opt_site_global_header_overlay1',
							'type'     => 'color_rgba',
							'title'    => esc_html__( 'Overlay Color 1 ', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_site_global_header_overlay2',
							'type'     => 'color_rgba',
							'title'    => esc_html__( 'Overlay Color 2 ', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_site_global_header_overlay3',
							'type'     => 'color_rgba',
							'title'    => esc_html__( 'Overlay Color 3 ', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id' => 'notice_site_global_classic_menu_opt',
							'type' => 'info',
							'notice' => true,
							'style' => 'success',
							'title' => esc_html__('Classic Menu Options', 'bauen'),
							'desc' => esc_html__('Classic menu Background color,  Height & Container options.', 'bauen'),
						),
						
						array(
							'id'       => 'opt_site_classic_menu_back_color',
							'type'     => 'color_rgba',
							'title'    => esc_html__( 'Menu Background Color ', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_site_classic_menu_sticky_back_color',
							'type'     => 'color_rgba',
							'title'    => esc_html__( 'Sticky Menu Background Color ', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_theme_classic_sub_back_colors',
							'type'     => 'color',
							'title'    => esc_html__( 'Sub Menu Background Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_theme_classic_sub_border_color',
							'type'     => 'color_rgba',
							'title'    => esc_html__( 'Sub Menu Item Border Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_site_classic_menu_bottom_shadow_color',
							'type'     => 'color_rgba',
							'title'    => esc_html__( 'Bottom Shadow', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_site_classic_menu_bar_back_color_mob',
							'type'     => 'color_rgba',
							'title'    => esc_html__( 'Mobile Menu Bar Background Color ', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( 'Media width 775px.', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_site_classic_menu_sticky_back_color_mob',
							'type'     => 'color',
							'title'    => esc_html__( 'Mobile Menu Background Color ', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( 'Media width 775px.', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_theme_classic_mob_icon_back_color',
							'type'     => 'color',
							'title'    => esc_html__( 'Mobile Menu Toggle Icon Background Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( 'Media width 775px.', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_site_classic_menu_tab_back_color',
							'type'     => 'color',
							'title'    => esc_html__( 'Tab Menu Background Color ', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( 'Media width 991px.', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_theme_classic_tab_icon_back_color',
							'type'     => 'color',
							'title'    => esc_html__( 'Tab Menu Toggle Icon Background Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( 'Media width 991px.', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_theme_classic_tab_icon_line_color',
							'type'     => 'color',
							'title'    => esc_html__( 'Tab Menu Line Color', 'bauen' ),
							'subtitle' => esc_html__( 'Media width 991px.', 'bauen' ),
							'desc'     => esc_html__( 'Media width 991px.', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_theme_classic_tab_sub_border_color',
							'type'     => 'color_rgba',
							'title'    => esc_html__( 'Tab Menu Item Border Color', 'bauen' ),
							'subtitle' => esc_html__( 'Media width 991px.', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id' => 'notice_site_global_hamburger_opt',
							'type' => 'info',
							'notice' => true,
							'style' => 'success',
							'title' => esc_html__('Hamburger & Sidebar Menu', 'bauen'),
							'desc' => esc_html__('Menu Background & Icon.', 'bauen'),
						),
						array(
							'id'       => 'opt_theme_hamburger_main_main_back_color',
							'type'     => 'color',
							'title'    => esc_html__( 'Menu Bar Background Color', 'bauen' ),
							'subtitle' => esc_html__( 'Hamburger Menu Style', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
							'compiler'    => array(
								'background' => 'body:not(.is-mobile) .bauen-header:not(.scrolled), body:not(.is-mobile) .bauen-header:not(.scrolled) .bauen-logo-wrap', 
							),
						),
						array(
							'id'       => 'opt_theme_hamburger_main_sticky_back_color',
							'type'     => 'color',
							'title'    => esc_html__( 'Sticky Menu Bar & Mobile Menu Background Color', 'bauen' ),
							'subtitle' => esc_html__( 'Hamburger Menu Style', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_theme_hamburger_resmain_rg_back_color',
							'type'     => 'color_rgba',
							'title'    => esc_html__( 'Responsive Menu Bar Background Color', 'bauen' ),
							'subtitle' => esc_html__( 'Hamburger Menu Style', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
							'compiler'    => array(
								'background-color' => 'body.is-mobile .bauen-header.if-toogle-menuclass:not(.scrolled)', 
							),
						),
						
						array(
							'id'       => 'opt_theme_hamburger_resmain_sticky_back_color',
							'type'     => 'color_rgba',
							'title'    => esc_html__( 'Responsive Sticky Menu Bar Background Color', 'bauen' ),
							'subtitle' => esc_html__( 'Hamburger Menu Style', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
							'compiler'    => array(
								'background-color' => 'body.is-mobile .bauen-header.if-toogle-menuclass.scrolled', 
							),
						),
						
						array(
							'id'       => 'opt_theme_hamburger_main_back_color',
							'type'     => 'color',
							'title'    => esc_html__( 'Menu Holder Background Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id' => 'sidebar_back_img',
							'type' => 'media',
							'title' => esc_html__('Background Image', 'annie'),
							'subtitle' => esc_html__('', 'annie'),
						),
					
						array(
							'id'       => 'sidebar_back_img_overlay',
							'type'     => 'color_rgba',
							'title'    => esc_html__( 'Overlay Color', 'annie' ),
							'subtitle' => esc_html__( 'Required if you are using background image.', 'annie' ),
							'desc'     => esc_html__( '', 'annie' ),
						),
						
						array(
							'id'       => 'opt_theme_hamburger_main_border_color',
							'type'     => 'color_rgba',
							'title'    => esc_html__( 'Menu Item Border Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id' => 'opt_theme_sidebar_social_icon_color',
							'type'     => 'color',
							'title'    => esc_html__( 'Sidebar Menu Social Icon Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						array(
							'id' => 'opt_theme_sidebar_social_border_color',
							'type'     => 'color_rgba',
							'title'    => esc_html__( 'Sidebar Menu Social Icon Border Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_theme_hamburger_back_color',
							'type'     => 'color',
							'title'    => esc_html__( 'Menu Toggle Icon Background Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_theme_hamburger_icon_color',
							'type'     => 'color',
							'title'    => esc_html__( 'Toggle Icon Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_theme_hamburger_icon_color_active',
							'type'     => 'color',
							'title'    => esc_html__( 'Active / Sticky Toggle Icon Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_theme_res_hamburger_icon_color',
							'type'     => 'color',
							'title'    => esc_html__( 'Responsive Toggle Icon Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
							'compiler'    => array(
								'background' => 'body.is-mobile .bn-click-main .bauen-nav-toggle i, body.is-mobile .bn-click-main .bauen-nav-toggle i:before, body.is-mobile .bn-click-main .bauen-nav-toggle i:after, body.is-mobile .bauen-menu-click .bauen-nav-toggle i, body.is-mobile .bauen-menu-click .bauen-nav-toggle i:before,body.is-mobile .bauen-menu-click .bauen-nav-toggle i:after', 
							),
						),
						
						array(
							'id' => 'notice_site_theme_footer',
							'type' => 'info',
							'notice' => true,
							'style' => 'success',
							'title' => esc_html__('Site Footer Options.', 'bauen'),
							'desc' => esc_html__('', 'bauen'),
						),
						
						array(
							'id'       => 'opt_theme_site_theme_footer_back',
							'type'     => 'color',
							'title'    => esc_html__( '1st Section Background Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_theme_site_theme_footer_back_nd',
							'type'     => 'color',
							'title'    => esc_html__( '2nd Section Background Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_theme_site_theme_footer_line',
							'type'     => 'color_rgba',
							'title'    => esc_html__( 'Line Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
						array(
							'id'       => 'opt_theme_site_theme_footer_social',
							'type'     => 'color',
							'title'    => esc_html__( 'Social Icon Color', 'bauen' ),
							'subtitle' => esc_html__( '', 'bauen' ),
							'desc'     => esc_html__( '', 'bauen' ),
						),
						
					)
                ) );			  
			   
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el el-icon-cogs',
                    'title'  => esc_html__( 'Page Settings', 'bauen' ),
                    'desc'  => esc_html__( 'Portfolio & 404 Page Options.', 'bauen' ),
                    'fields' => array(
					array(
							'id' => 'header-error',
							'type' => 'info',
		                    'notice' => true,
		                    'style' => 'info',
							'title' => esc_attr__('404 Error Page Option', 'bauen'),
							
					),		
					array(
							'id' => '404_page_img_opt',
							'type' => 'select',
							'title' => esc_html__('404 Style', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Default', 'bauen'),	
									'st2' => esc_html__('Image', 'bauen'),
									'st3'=> esc_html__('Text', 'bauen'),									
							),
							'default'  => 'st1'
					),						
					array(
							'id' => '404_page_img',
							'type' => 'media',
							
							'title' => esc_html__('Upload 404 Image', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'default' => array('url' => get_template_directory_uri().'/includes/images/404-image.png'),'required' => array('404_page_img_opt', '=' , 'st2')								
					),
					array(
							'id' => '404_banner_img',
							'type' => 'media',
							
							'title' => esc_html__('Upload 404 Banner Background', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
					),											
					array(
			                'id' => 'notice_404page_translation',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('404 Page Translate Options', 'bauen'),
			                'desc' => esc_html__('404 Page Text Translate Options', 'bauen'),
							
			        ),		
					array(
							'id' => '404_page_title_1',
							'type' => 'text',
							'title' => esc_html__('Text 1', 'bauen'),
							'subtitle' => esc_html__('Translate Options. Ex:  404 ', 'bauen'),
							'required' => array('404_page_img_opt', '=' , 'st3')	
					),					
					array(
							'id' => '404_page_title_2',
							'type' => 'text',
							'title' => esc_html__('Text 1', 'bauen'),
							'subtitle' => esc_html__('Translate Options. Ex:  Page not found. ', 'bauen'),
							
					),
					array(
							'id' => '404_page_title_4',
							'type' => 'text',
							
							'title' => esc_html__('Text 2', 'bauen'),
							'subtitle' => esc_html__('Translate Options. Ex:  The page you were looking for does not exist. ', 'bauen'),
							
					),					
					array(
							'id' => '404_page_title_3',
							'type' => 'text',
							'title' => esc_html__('Text 3', 'bauen'),
							'subtitle' => esc_html__('Translate Options. Ex:  Back To Home', 'bauen'),
							
					),
					array(
							'id' => '404_serach',
							'type' => 'button_set',
							'title' => esc_html__('404 Page Search Box', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Disable', 'bauen'),
									'st2' => esc_html__('Enable', 'bauen'),
									
							),
							'default'  => 'st1',
					),	
						array(
							'id' => '404_serach_title',
							'type' => 'text',
							'title' => esc_html__('Text 4', 'bauen'),
							'subtitle' => esc_html__('Translate Options. Ex: Search here', 'bauen'),
							'required' => array('404_serach', '=' , 'st2')
					),				
					array(
			                'id' => 'notice_portfoliopage_translation',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Portfolio Post Page Options', 'bauen'),
			                'desc' => esc_html__('', 'bauen'),
							
			        ),
					array(
							'id' => 'portfolio_pagination_global_opt',
							'type' => 'button_set',
							'title' => esc_html__('Portfolio Details Pagination', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('Enable', 'bauen'),	
								'st2' => esc_html__('Disable', 'bauen'),
							),
							'default'  => 'st1'
					),
					array(
							'id' => 'port_page_url',
							'type' => 'text',
							'title' => esc_html__('Portfolio Page URL', 'bauen'),
							'subtitle' => esc_html__('Insert portfolio page url here.', 'bauen'),
							
					),
					array(
			                'id' => 'notice_portfolio_main_base',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Portfolio Details Base Option.', 'bauen'),
			                'desc' => __('If you like, you may enter custom structures for your Portfolio details URLs here. For example, using topics as your portfolio base would make your portfolio details links like http://yoursiteurl/topics/sample-post/. If you leave these blank the defaults will be used.<br>After make changes save permalink settings again.', 'bauen'),
					),
					
					array(
							'id' => 'portfolio_main_base_opt',
							'type' => 'text',
							'title' => esc_html__('Portfolio Details Base/Slug ', 'bauen'),
							'subtitle' => esc_html__('Ex: topics', 'bauen'),
					),
					array(
			                'id' => 'notice_portfolio_category_base',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Portfolio Category Base Option.', 'bauen'),
			                'desc' => __('If you like, you may enter custom structures for your Portfolio Category URLs here. For example, using topics as your portfolio_category base would make your portfolio category links like http://yoursiteurl/topics/uncategorized/. If you leave these blank the defaults will be used.<br>After make changes save permalink settings again.', 'bauen'),
					),
					
					array(
							'id' => 'portfolio_category_base_opt',
							'type' => 'text',
							'title' => esc_html__('Portfolio Category Base ', 'bauen'),
							'subtitle' => esc_html__('Ex: topics', 'bauen'),
					),
					
					array(
			                'id' => 'notice_portfolio_category_column_opt',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Portfolio Category Post Columns.', 'bauen'),
			                'desc' => __('Portfolio Category page post columns options.', 'bauen'),
					),
					
					array(
							'id' => 'portfolio_category_column_main_opt',
							'type' => 'button_set',
							'title' => esc_html__('Post Coumns', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('2 Columns', 'bauen'),	
								'st2' => esc_html__('3 Columns', 'bauen'),
							),
							'default'  => 'st1'
					),
					
					array(
			                'id' => 'notice_portfolio_translation',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Translation Options', 'bauen'),
			                'desc' => esc_html__('Default Text Translate Here.', 'bauen'),
			        ),
					array(
							'id' => 'back_port',
							'type' => 'text',
							'title' => esc_html__('Back To Portfolio', 'bauen'),
							'subtitle' => esc_html__('Portfolio Pagination.', 'bauen'),
					),
					array(
							'id' => 'back_home',
							'type' => 'text',
							'title' => esc_html__('Back To Home', 'bauen'),
							'subtitle' => esc_html__('Portfolio Pagination.', 'bauen'),
					),					
					array(
							'id' => 'translet_opt_5',
							'type' => 'text',
							'title' => esc_html__('Prev', 'bauen'),
							'subtitle' => esc_html__('Portfolio Pagination.', 'bauen'),
					),
					
					array(
							'id' => 'translet_opt_6',
							'type' => 'text',
							'title' => esc_html__('Next', 'bauen'),
							'subtitle' => esc_html__('Portfolio Pagination.', 'bauen'),
					),
					
					
										
					
                    )
                ) );
				
			
				
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el el-icon-bullhorn',
                    'title'  => esc_html__( 'Blog Settings', 'bauen' ),
                    'fields' => array(
					
					array(
			                'id' => 'notice_index_details_main_page_opt',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Blog Details Page Style', 'bauen'),
			                'desc' => esc_html__('Select blog details page style of your site. You can select details style from post also.', 'bauen')
			        ),
					
					array(
							'id' => 'blogdetailstyle',
							'type' => 'button_set',
							'title' => esc_html__('Select Blog Details Layout', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('Right Sidebar', 'bauen'),
								'st2' => esc_html__('Full Width', 'bauen'),
								'st3' => esc_html__('Left Sidebar', 'bauen'),
							),
							'default'  => 'st1'
					),
					array(
			                'id' => 'notice_index_page_main_page_opt',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Blog Index Page Style', 'bauen'),
			                'desc' => esc_html__('Select blog index page layout style for blog single, archives, category, tag & search page.', 'bauen')
			        ),
					
					array(
							'id' => 'index_page_layout_opt',
							'type' => 'button_set',
							'title' => esc_html__('Select Blog Index Layout', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'desc' => '',
							'options' => array(
								'st1'=> esc_html__('Right Sidebar', 'bauen'),
								'st2' => esc_html__('Left Sidebar', 'bauen'),									
							),
							'default'  => 'st1'
					),					
			        array(
							'id' => 'index_header_show',
							'type' => 'button_set',
							'title' => esc_html__('Blog Header Section', 'bauen'),
							'subtitle' => esc_html__('Enable/Disable header section for blog single, archives, category, tag & search page.', 'bauen'),
							'default'  => 'yes',
							'options' => array(
								'yes'=> esc_html__('Enable', 'bauen'),
								'no'=> esc_html__('Disable', 'bauen'),
							),
							
					),						
					array(
							'id' => 'index_header_banner_img',
							'type' => 'media',
							'title' => esc_html__('Upload Index Header Image', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'required' => array('index_header_show', '=' , 'yes')
					),		
					array(
								'id' => 'index_header_overlay',
								'type' => 'select',
								'title' => esc_html__('Header Image Overlay', 'bauen'),
								'subtitle' => esc_html__('', 'bauen'),
								'desc' => '',
								'options' => array(
									'st1'=> esc_html__('1', 'bauen'),									
									'st2'=> esc_html__('2', 'bauen'),									
									'st3'=> esc_html__('3', 'bauen'),									
									'st4'=> esc_html__('4', 'bauen'),									
									'st5'=> esc_html__('5', 'bauen'),									
									'st6'=> esc_html__('6', 'bauen'),									
									'st7'=> esc_html__('7', 'bauen'),									
									'st8'=> esc_html__('8', 'bauen'),									
									'st9'=> esc_html__('9', 'bauen'),									
								),
								
								'required' => array('index_header_show', '=' , 'yes')
						),					
					array(
							'id' => 'blog_page_title',
							'type' => 'text',
							'title' => esc_html__('Blog Title Text', 'bauen'),
							'subtitle' => esc_html__('Insert blog page header title text here.', 'bauen'),
							'required' => array('index_header_show', '=' , 'yes')
							
					),									
					array(
			                'id' => 'notice_blog_translation',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Translation Options', 'bauen'),
			                'desc' => esc_html__('Default Text Translate Here.', 'bauen'),
			        ),	
					array(
							'id' => 'blog_read_more',
							'type' => 'text',
							'title' => __('Read More', 'bauen'),
							'subtitle' => __('Change/Repalce blog post "Read More" text here.', 'bauen'),
							'default' => '',
							
					),					  					
					array(
							'id' => 'arch_page_title',
							'type' => 'text',
							'title' => esc_html__('Archive Page Title', 'bauen'),
							'subtitle' => esc_html__('Insert header title for blog archive page here. Ex: Archive : ', 'bauen'),
							'default' => '',
					),	
					array(
							'id' => 'cat_page_title',
							'type' => 'text',
							'title' => esc_html__('Category Page Title', 'bauen'),
							'subtitle' => esc_html__('Insert header title for blog category page here. Ex: Category : ', 'bauen'),
							'default' => '',
					),	
	
					array(
							'id' => 'tag_page_title',
							'type' => 'text',
							'title' => esc_html__('Tag Page Title', 'bauen'),
							'subtitle' => esc_html__('Insert header title for blog tag page here. Ex: Tag : ', 'bauen'),
							'default' => '',
					),						

					array(
							'id' => 'src_page_title',
							'type' => 'text',
							'title' => esc_html__('Search Page Title', 'bauen'),
							'subtitle' => esc_html__('Insert header title for blog search page title here. Ex: Search Results for :', 'bauen'),
							'default' => '',
					),
					array(
							'id' => 'blog_page_nopost',
							'type' => 'text',
							'title' => esc_html__('Search Page No Post Title', 'bauen'),
							'subtitle' => esc_html__('Insert header title for blog search page no post title here. Ex: No Post Found', 'bauen'),
							'default' => '',
					),	
					array(
							'id' => 'blog_page_search_again',
							'type' => 'text',
							'title' => esc_html__('Search Page Search Again Title', 'bauen'),
							'subtitle' => esc_html__('Insert header title for blog search page no post title here. Ex: Please Search Again.', 'bauen'),
							'default' => '',
					),	
					array(
							'id' => 'translet_opt_9',
							'type' => 'text',
							'title' => esc_html__('No Results Found', 'bauen'),
							'subtitle' => esc_html__('Search Page.', 'bauen'),
					),				
					array(
							'id' => 'translet_opt_3',
							'type' => 'text',
							'title' => esc_html__('Search..', 'bauen'),
							'subtitle' => esc_html__('Search Widget.', 'bauen'),
					),
					
					array(
			                'id' => 'notice_postpage_translation',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Post Details Page Options', 'bauen'),
			                'desc' => esc_html__('', 'bauen'),
							
			            ),					
					array(
							'id' => 'post_page_url',
							'type' => 'text',
							
							'title' => esc_html__('Blog Page URL', 'bauen'),
							'subtitle' => esc_html__('Insert blog page url here.', 'bauen'),
							
					),	
					array(
			                'id' => 'notice_post_translation',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Pagination Text Translation Options', 'bauen'),
			                'desc' => esc_html__('Default Text Translate Here.', 'bauen'),
			        ),
					array(
							'id' => 'post_back_port',
							'type' => 'text',
							'title' => esc_html__('Back To Blog', 'bauen'),
							'subtitle' => esc_html__('Blog Pagination.', 'bauen'),
					),
					array(
							'id' => 'post_back_home',
							'type' => 'text',
							'title' => esc_html__('Back To Home', 'bauen'),
							'subtitle' => esc_html__('Blog Pagination.', 'bauen'),
					),					
					array(
							'id' => 'post_translet_opt_5',
							'type' => 'text',
							'title' => esc_html__('Prev', 'bauen'),
							'subtitle' => esc_html__('Post Pagination.', 'bauen'),
					),
					
					array(
							'id' => 'post_translet_opt_6',
							'type' => 'text',
							'title' => esc_html__('Next', 'bauen'),
							'subtitle' => esc_html__('Post Pagination.', 'bauen'),
					),
					
                    )
                ) );	

				if (class_exists('WooCommerce')) {
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el el-shopping-cart-sign',
                    'title'  => esc_attr__( 'Shop Options', 'bauen' ),
                    'fields' => array(
					
					array(
							'id' => 'wr_pro_hover',
							'type' => 'info',
		                    'notice' => true,
		                    'style' => 'info',
							'title' => esc_attr__('Product Item Design Option.', 'bauen'),
							'desc' => esc_attr__(' ', 'bauen')
					),
					array(
						'id' => 'wr_pro_main_hover',
						'type' => 'button_set',
						'title' => esc_html__('Product Items Layout', 'bauen'),
						'subtitle' => esc_html__('', 'bauen'),
						'desc' => '',
						'options' => array(
							'st1'=> esc_html__('Hover Animation', 'bauen'),
							'st2' => esc_html__('Simple Grid Item', 'bauen'),
						),
						'default'  => 'st1'
					),
					
					array(
						'id' => 'wr-shop-opt',
						'type' => 'info',
		                'notice' => true,
		                'style' => 'info',
						'title' => esc_attr__('Shop Page Header Banner Options', 'bauen'),
						'desc' => esc_attr__(' ', 'bauen'),
					),
					
					array(
						'id' => 'wr_pro_main_shop_header',
						'type' => 'button_set',
						'title' => esc_html__('Page Header Banner', 'bauen'),
						'subtitle' => esc_html__('', 'bauen'),
						'desc' => '',
						'options' => array(
							'st1'=> esc_html__('Enable', 'bauen'),
							'st2' => esc_html__('Disable', 'bauen'),
						),
						'default'  => 'st1'
					),
					
					array(
						'id' => 'shopheaderimg',
						'type' => 'media',
						'title' => esc_attr__('Banner Image', 'bauen'),
						'subtitle' => esc_attr__('Upload Shop Page Header Banner Image', 'bauen'),
						'required' => array('wr_pro_main_shop_header', '=' , 'st1'),
					),
					
					array(
						'id' => 'shopsubtitle',
						'type' => 'textarea',
						'title' => esc_attr__('Sub Title ', 'bauen'),
						'subtitle' => esc_attr__('Shop page sub title', 'bauen'),
						'required' => array('wr_pro_main_shop_header', '=' , 'st1'),
					),
					
					
                    )
                ) );
				}
				
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el el-icon-leaf',
                    'title'  => esc_html__( 'Social Options', 'bauen' ),
                    'fields' => array(
					
					
					array(
						'id' => 'wr_inner_page_left_panel_header',
						'type' => 'button_set',
						'title' => esc_html__('Display on left panel', 'bauen'),
						'subtitle' => esc_html__('Affted for Calssic & Hamburger Menu style and if page header is Default or Static.', 'bauen'),
						'desc' => '',
						'options' => array(
							'st1'=> esc_html__('Disable', 'bauen'),
							'st2' => esc_html__('Enable', 'bauen'),
						),
						'default'  => 'st1'
					),
					
					array(
						'id' => 'facebook',
						'type' => 'text',
						'title' => esc_html__('Facebook ', 'bauen'),
						'subtitle' => esc_html__('Insert Social URL Here.', 'bauen'),
					),
					
					array(
						'id' => 'twitter',
						'type' => 'text',
						'title' => esc_html__('Twitter ', 'bauen'),
						'subtitle' => esc_html__('Insert Social URL Here.', 'bauen'),
					),
					
					array(
						'id' => 'pinterest',
						'type' => 'text',
						'title' => esc_html__('Pinterest ', 'bauen'),
						'subtitle' => esc_html__('Insert Social URL Here.', 'bauen'),
					),
					
					array(
						'id' => 'instagram',
						'type' => 'text',
						'title' => esc_html__('Instagram ', 'bauen'),
						'subtitle' => esc_html__('Insert Social URL Here.', 'bauen'),
					),					
					
					array(
						'id' => 'behance',
						'type' => 'text',
						'title' => esc_html__('Behance ', 'bauen'),
						'subtitle' => esc_html__('Insert Social URL Here.', 'bauen'),
					),
					
					array(
						'id' => 'dribbble',
						'type' => 'text',
						'title' => esc_html__('Dribbble', 'bauen'),
						'subtitle' => esc_html__('Insert Social URL Here.', 'bauen'),
					),
					
					array(
						'id' => 'gplus',
						'type' => 'text',
						'title' => esc_html__('Google+ ', 'bauen'),
						'subtitle' => esc_html__('Insert Social URL Here.', 'bauen'),
					),
					
					array(
						'id' => 'linkedin',
						'type' => 'text',
						'title' => esc_html__('LinkedIn ', 'bauen'),
						'subtitle' => esc_html__('Insert Social URL Here.', 'bauen'),
					),
					
					array(
						'id' => 'youtube',
						'type' => 'text',
						'title' => esc_html__('YouTube ', 'bauen'),
						'subtitle' => esc_html__('Insert Social URL Here.', 'bauen'),
					),
					
					array(
						'id' => 'vimeo',
						'type' => 'text',
						'title' => esc_html__('Vimeo ', 'bauen'),
						'subtitle' => esc_html__('Insert Social URL Here.', 'bauen'),
					),
					
					array(
						'id' => 'slack',
						'type' => 'text',
						'title' => esc_html__('Slack ', 'bauen'),
						'subtitle' => esc_html__('Insert Social URL Here.', 'bauen'),
					),
					
					array(
						'id' => 'github',
						'type' => 'text',
						'title' => esc_html__('GitHub ', 'bauen'),
						'subtitle' => esc_html__('Insert Social URL Here.', 'bauen'),
					),
					
					array(
						'id' => 'tumblr',
						'type' => 'text',
						'title' => esc_html__('Tumblr ', 'bauen'),
						'subtitle' => esc_html__('Insert Social URL Here.', 'bauen'),
					),
					array(
						'id'       => 'opt_add_more_social',
						'type'     => 'multi_text',
						'title'    => esc_html__( 'Add More Social Icons (Footer & Bauen Banner Slider)', 'bauen' ),
						'subtitle' => esc_html__( '', 'bauen' ),
						'desc'     => __( 'Ex: &lt;a target="_blank" href="#"&gt;&lt;i class="fab fa-facebook-f"&gt;&lt;/i&gt;&lt;/a&gt;<br>Use <a href="https://fontawesome.com/v5/cheatsheet" target="_blank">Fontawesome</a> Icon Class', 'bauen' ),
					),									
					
					array(
						'id'       => 'opt_add_more_text_social',
						'type'     => 'multi_text',
						'title'    => esc_html__( 'Add More Social Icons (Sidebar Nav)', 'bauen' ),
						'subtitle' => esc_html__( '', 'bauen' ),
						'desc'     => __( 'Ex: &lt;li&gt;&lt;a target="_blank" href="#"&gt;&lt;i class="fab fa-facebook-f"&gt;&lt;/i&gt;&lt;/a&gt;&lt;/li&gt;<br>Use <a href="https://fontawesome.com/v5/cheatsheet" target="_blank">Fontawesome</a> Icon Class', 'bauen' ),							
					),	
					
                    )
                ) );
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el el-icon-text-width',
                    'title'  => esc_attr__( 'Typography', 'bauen' ),
                    'fields' => array(  

						array(
                            'id'          => 'typo_body',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Body', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('html body'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the Body Text font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),
				
						array(
			                'id' => 'notice_t_global',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('All The Title Tag Font Properties.', 'bauen'),
			                'desc' => esc_html__('Specify the all title tag font properties.', 'bauen')
			            ),
						
						array(
                            'id'          => 'typo_t_h1',
                            'type'        => 'typography', 
                            'title'       => esc_html__('H1', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body h1'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the h1 font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),
						
						array(
                            'id'          => 'typo_t_h2',
                            'type'        => 'typography', 
                            'title'       => esc_html__('H2', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body h2'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the h2 font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),
						
						array(
                            'id'          => 'typo_t_h3',
                            'type'        => 'typography', 
                            'title'       => esc_html__('H3', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body h3'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the h3 font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),
						
						array(
                            'id'          => 'typo_t_h4',
                            'type'        => 'typography', 
                            'title'       => esc_html__('H4', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body h4'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the h4 font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),
						
						array(
                            'id'          => 'typo_t_h5',
                            'type'        => 'typography', 
                            'title'       => esc_html__('H5', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body h5'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the h5 font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),
						
						array(
                            'id'          => 'typo_t_h6',
                            'type'        => 'typography', 
                            'title'       => esc_html__('H6', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body h6'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the h6 font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),												
						array(
                            'id'          => 'typo_t_t',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Section Title', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .section-title', 'body .elementor-element .section-title2'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the title font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),	
						array(
                            'id'          => 'typo_t_t_s',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Section Title Span', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .section-title span'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the title font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),							
						array(
			                'id' => 'notice_p_1',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('P Tag Font Properties.', 'bauen'),
			                'desc' => esc_html__('Specify the p tag font properties.', 'bauen')
			            ),
						
						array(
                            'id'          => 'typo_p_s_d',
                            'type'        => 'typography', 
                            'title'       => esc_html__('P', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body p'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('Specify the p font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),
						
                        array(
                            'id'          => 'typography-lnurl',
                            'type'        => 'typography', 
                            'title'       => __('a', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body a'),
                            'units'       =>'px',
                            'subtitle'    => __('Specify the hyperlink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),							
						),		
						array(
                            'id'          => 'typography-a-hover',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('a Hover', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'compiler'      => array('body a:focus', 'body a:hover'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the hyperlink hover font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),	
						
						array(
			                'id' => 'notice_critical1button',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Button', 'bauen'),
			                'desc' => __('', 'bauen')
			            ),
						
                        array(
                            'id'          => 'typography-lnurl-btn',
                            'type'        => 'typography', 
                            'title'       => __('Button Light Text Color', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .butn-light a', '[data-overlay-dark] span'),
                            'units'       =>'px',
                            'subtitle'    => __('Specify the Light Button / Slider Button font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),							
						),
						
						array(
                            'id'          => 'typography-a-hover-btn',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Button Light Text Hover Color', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'font-style'  => false,
							'font-family' => false,
							'font-size'   => false,
							'font-weight'   => true,
							'text-align'   => false,
                            'line-height' => false,
                            'compiler'      => array('body .butn-light a:hover span'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the Light Button / Slider Button font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'font-weight'   => false,
                            ),
						),

						array(
                            'id'       => 'opt_button_style_light',
                            'type'     => 'color',
                            'title'    => esc_html__( 'Button Light Background Color', 'bauen' ),
                            'subtitle' => esc_html__( 'Button Light Hover Background Color', 'bauen' ),
                            'desc'     => esc_html__( '', 'bauen' ),
                            //'regular'   => false, // Disable Regular Color
                            //'hover'     => false, // Disable Hover Color
                            //'active'    => false, // Disable Active Color
                            //'visited'   => true,  // Enable Visited Color
                            
						),
					
                        array(
                            'id'          => 'typography-dark-btn',
                            'type'        => 'typography', 
                            'title'       => __('Button Dark Text Color', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .butn-dark a', 'body .butn-dark a:after', 'body .butn-dark a span',  'body input[type="submit"]', 'body input[type="reset"]', 'body input[type="button"]', 'body button'),
                            'units'       =>'px',
                            'subtitle'    => __('Specify the Dark Button  font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),							
						),
						
						array(
                            'id'          => 'typography-dark-hover-btn',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Button Dark Text Hover Color', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'font-style'  => false,
							'font-family' => false,
							'font-size'   => false,
							'font-weight'   => true,
							'text-align'   => false,
                            'line-height' => false,
                            'compiler'      => array('body .butn-dark a:hover span',  'body input[type="submit"]:hover', 'body input[type="reset"]:hover', 'body input[type="button"]:hover', 'body button:hover'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the Dark Button font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'font-weight'   => false,
                            ),
						),
						
						array(
                            'id'       => 'opt_button_style_dark_main',
                            'type'     => 'color',
                            'title'    => esc_html__( 'Button Dark Background Color', 'bauen' ),
                            'subtitle' => esc_html__( 'Button Dark Background Color', 'bauen' ),
                            'desc'     => esc_html__( '', 'bauen' ),
                        ),

						array(
                            'id'       => 'opt_button_style_dark',
                            'type'     => 'color',
                            'title'    => esc_html__( 'Button Hover Background Color', 'bauen' ),
                            'subtitle' => esc_html__( 'Button Dark Hover Background Color', 'bauen' ),
                            'desc'     => esc_html__( '', 'bauen' ),
                        ),

						array(
                            'id'          => 'typography-readlnurl',
                            'type'        => 'typography', 
                            'title'       => __('Read More', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'font-weight'   => true,
							'letter-spacing' => true,
                            'compiler'      => array('body .bauen-blog2 .content .cont .more'),
                            'units'       =>'px',
                            'subtitle'    => __('', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
							'font-weight'   => false,
                            ),							
						),
                        array(
                            'id'          => 'typography-readlnurlhover',
                            'type'        => 'typography', 
                            'title'       => __('Read More Hover', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'compiler'      => array('body .bauen-blog2 .content .cont .more:hover'),
                            'units'       =>'px',
                            'subtitle'    => __('', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),
						
						array(
			                'id' => 'notice_critical1_navmenu_classic',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Navigation Menu (Classic)', 'bauen'),
			                'desc' => __('Nav Menu Color Style Light', 'bauen')
			            ),		
						array(
                            'id'          => 'typography-a-navmenu-classic',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Menu Item', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'compiler'      => array('body.light-version .navbar .navbar-nav.-white .nav-link', 'body.light-version .navbar .navbar-nav.-white .nav-link.nav-color', 'body.light-version .navbar .navbar-nav.-white .nav-link.nav-color', 'body.dark-version .navbar .navbar-nav.-white .nav-link', 'body.dark-version .navbar .navbar-nav.-white .nav-link.nav-color', 'body.dark-version .navbar .navbar-nav.-white .nav-link.nav-color'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),	
						array(
                            'id'          => 'typography-a-hover-navmenu-classic',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Menu Item Hover/ Active', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'compiler'      => array('body.light-version .navbar .navbar-nav.-white .nav-link:hover', 'body.light-version .navbar .navbar-nav.-white .nav-link.nav-color:hover', 'body.light-version .navbar .navbar-nav.-white .nav-link.nav-color:hover', 'body.light-version .navbar .navbar-nav.-white .current-menu-parent > a.nav-link.nav-color', 'body.light-version .navbar .navbar-nav.-white .current-page-ancestor > a.nav-link.nav-color', 'body.light-version .navbar .navbar-nav.-white .current-menu-parent > .nav-link.nav-color', 'body.light-version .navbar .navbar-nav.-white .current-menu-item > a.nav-link.nav-color', 'body.dark-version .navbar .navbar-nav.-white .nav-link:hover', 'body.dark-version .navbar .navbar-nav.-white .nav-link.nav-color:hover', 'body.dark-version .navbar .navbar-nav.-white .nav-link.nav-color:hover', 'body.dark-version .navbar .navbar-nav.-white .current-menu-parent > a.nav-link.nav-color', 'body.dark-version .navbar .navbar-nav.-white .current-page-ancestor > a.nav-link.nav-color', 'body.dark-version .navbar .navbar-nav.-white .current-menu-parent > .nav-link.nav-color', 'body.dark-version .navbar .navbar-nav.-white .current-menu-item > a.nav-link.nav-color', 'body.dark-version .navbar .navbar-nav.-white .active', 'body.light-version .navbar .navbar-nav.-white .active'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						
						array(
			                'id' => 'notice_critical1_navmenu_dark_classic',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Navigation Menu (Classic)', 'bauen'),
			                'desc' => __('Nav Menu Color Style Dark', 'bauen')
			            ),		
						array(
                            'id'          => 'typography-a-navmenu-classic_dark',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Menu Item', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'compiler'      => array('body.light-version .navbar .navbar-nav.-black .nav-link', 'body.light-version .navbar .navbar-nav.-black .nav-link.nav-color', 'body.light-version .navbar .navbar-nav.-black .nav-link.nav-color', 'body.dark-version .navbar .navbar-nav.-black .nav-link', 'body.dark-version .navbar .navbar-nav.-black .nav-link.nav-color', 'body.dark-version .navbar .navbar-nav.-black .nav-link.nav-color'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),	
						array(
                            'id'          => 'typography-a-hover-navmenu-classic_dark',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Menu Item Hover/ Active', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'compiler'      => array('body.light-version .navbar .navbar-nav.-black .nav-link:hover', 'body.light-version .navbar .navbar-nav.-black .nav-link.nav-color:hover', 'body.light-version .navbar .navbar-nav.-black .nav-link.nav-color:hover', 'body.light-version .navbar .navbar-nav.-black .current-menu-parent > a.nav-link.nav-color', 'body.light-version .navbar .navbar-nav.-black .current-page-ancestor > a.nav-link.nav-color', 'body.light-version .navbar .navbar-nav.-black .current-menu-parent > .nav-link.nav-color', 'body.light-version .navbar .navbar-nav.-black .current-menu-item > a.nav-link.nav-color', 'body.dark-version .navbar .navbar-nav.-black .nav-link:hover', 'body.dark-version .navbar .navbar-nav.-black .nav-link.nav-color:hover', 'body.dark-version .navbar .navbar-nav.-black .nav-link.nav-color:hover', 'body.dark-version .navbar .navbar-nav.-black .current-menu-parent > a.nav-link.nav-color', 'body.dark-version .navbar .navbar-nav.-black .current-page-ancestor > a.nav-link.nav-color', 'body.dark-version .navbar .navbar-nav.-black .current-menu-parent > .nav-link.nav-color', 'body.dark-version .navbar .navbar-nav.-black .current-menu-item > a.nav-link.nav-color', 'body.dark-version .navbar .navbar-nav.-black .active', 'body.light-version .navbar .navbar-nav.-black .active'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						array(
			                'id' => 'notice_critical1_navmenu_sticky_classic',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Navigation Menu Sticky (Classic)', 'bauen'),
			                'desc' => __('Sticky menu item styles.', 'bauen')
			            ),	
						array(
                            'id'          => 'typography-a-navmenu-sticky-classic',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Sticky Menu Item', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'compiler'      => array('body:not(.is-mobile).light-version .navbar.nav-scroll .navbar-nav .nav-link', 'body:not(.is-mobile).light-version .navbar.nav-scroll .navbar-nav.-white .nav-link.nav-color', 'body:not(.is-mobile).light-version .navbar.nav-scroll .navbar-nav .nav-link.nav-color', 'body:not(.is-mobile).light-version .navbar.nav-scroll .navbar-nav.-black .nav-link.nav-color', 'body:not(.is-mobile).dark-version .navbar.nav-scroll .navbar-nav .nav-link', 'body:not(.is-mobile).dark-version .navbar.nav-scroll .navbar-nav.-white .nav-link.nav-color', 'body:not(.is-mobile).dark-version .navbar.nav-scroll .navbar-nav .nav-link.nav-color', 'body:not(.is-mobile).dark-version .navbar.nav-scroll .navbar-nav.-black .nav-link.nav-color', 'body:not(.is-mobile).dark-version .navbar.nav-scroll .navbar-nav.-black .nav-link.nav-color'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
                            'id'          => 'typography-a-hover-navmenu-stickyclassic',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Sticky Menu Item Hover/ Active', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'compiler'      => array('body:not(.is-mobile).light-version .navbar.nav-scroll .navbar-nav .nav-link:hover', 'body:not(.is-mobile).light-version .navbar.nav-scroll .navbar-nav.-white .nav-link.nav-color:hover', 'body:not(.is-mobile).light-version .navbar.nav-scroll .navbar-nav .nav-link.nav-color:hover', 'body:not(.is-mobile).light-version .navbar.nav-scroll .navbar-nav.-black .nav-link.nav-color:hover', 'body:not(.is-mobile).light-version .navbar.nav-scroll .navbar-nav.-white .current-menu-parent > a.nav-link.nav-color',
							'body:not(.is-mobile).light-version .navbar.nav-scroll .navbar-nav.-white .current-page-ancestor > a.nav-link.nav-color',
							'body:not(.is-mobile).light-version .navbar.nav-scroll .navbar-nav.-white .current-menu-parent > .nav-link.nav-color',
							'body:not(.is-mobile).light-version .navbar.nav-scroll .navbar-nav.-white .current-menu-item > a.nav-link.nav-color',
							'body:not(.is-mobile).light-version .navbar.nav-scroll .navbar-nav.-black .current-menu-parent > a.nav-link.nav-color',
							'body:not(.is-mobile).light-version .navbar.nav-scroll .navbar-nav.-black .current-page-ancestor > a.nav-link.nav-color',
							'body:not(.is-mobile).light-version .navbar.nav-scroll .navbar-nav.-black .current-menu-parent > .nav-link.nav-color',
							'body:not(.is-mobile).light-version .navbar.nav-scroll .navbar-nav.-black .current-menu-item > a.nav-link.nav-color', 'body:not(.is-mobile).dark-version .navbar.nav-scroll .navbar-nav .nav-link:hover', 'body:not(.is-mobile).dark-version .navbar.nav-scroll .navbar-nav.-white .nav-link.nav-color:hover', 'body:not(.is-mobile).dark-version .navbar.nav-scroll .navbar-nav .nav-link.nav-color:hover', 'body:not(.is-mobile).dark-version .navbar.nav-scroll .navbar-nav.-black .nav-link.nav-color:hover', 'body:not(.is-mobile).dark-version .navbar.nav-scroll .navbar-nav.-white .current-menu-parent > a.nav-link.nav-color',
							'body:not(.is-mobile).dark-version .navbar.nav-scroll .navbar-nav.-white .current-page-ancestor > a.nav-link.nav-color',
							'body:not(.is-mobile).dark-version .navbar.nav-scroll .navbar-nav.-white .current-menu-parent > .nav-link.nav-color',
							'body:not(.is-mobile).dark-version .navbar.nav-scroll .navbar-nav.-white .current-menu-item > a.nav-link.nav-color',
							'body:not(.is-mobile).dark-version .navbar.nav-scroll .navbar-nav.-black .current-menu-parent > a.nav-link.nav-color',
							'body:not(.is-mobile).dark-version .navbar.nav-scroll .navbar-nav.-black .current-page-ancestor > a.nav-link.nav-color',
							'body:not(.is-mobile).dark-version .navbar.nav-scroll .navbar-nav.-black .current-menu-parent > .nav-link.nav-color',
							'body:not(.is-mobile).dark-version .navbar.nav-scroll .navbar-nav.-black .current-menu-item > a.nav-link.nav-color', 'body:not(.is-mobile).dark-version .navbar.nav-scroll .navbar-nav.-dark .active', 'body:not(.is-mobile).light-version .navbar.nav-scroll .navbar-nav.-dark .active',  'body:not(.is-mobile).dark-version .navbar.nav-scroll .navbar-nav.-white .active', 'body:not(.is-mobile).light-version .navbar.nav-scroll .navbar-nav.-white .active'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						
						array(
			                'id' => 'notice_critical1_navmenu_classic_mob',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Responsive Navigation Menu (Classic)', 'bauen'),
			                'desc' => __('', 'bauen')
			            ),
						array(
                            'id'          => 'typography_a_mobnavmenu_classic',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Menu Item', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'compiler'      => array('body.is-mobile.light-version .navbar .navbar-nav .nav-link', 'body.is-mobile.light-version .navbar .navbar-nav.-white .nav-link.nav-color', 'body.is-mobile.light-version .navbar .navbar-nav .nav-link.nav-color', 'body.is-mobile.light-version .navbar .navbar-nav.-black .nav-link.nav-color', 'body.is-mobile.dark-version .navbar .navbar-nav .nav-link', 'body.is-mobile.dark-version .navbar .navbar-nav.-white .nav-link.nav-color', 'body.is-mobile.dark-version .navbar .navbar-nav .nav-link.nav-color', 'body.is-mobile.dark-version .navbar .navbar-nav.-black .nav-link.nav-color', 'body.is-mobile.dark-version .navbar.nav-scroll .navbar-nav.-black .nav-link.nav-color'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						array(
                            'id'          => 'typography-a-hover-navmenu-classic_light_mob',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Menu Item Hover/ Active(Light Style)', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'compiler'      => array('body.is-mobile.light-version .navbar .navbar-nav.-white .nav-link:hover', 'body.is-mobile.light-version .navbar .navbar-nav.-white .nav-link.nav-color:hover', 'body.is-mobile.light-version .navbar .navbar-nav.-white .nav-link.nav-color:hover', 'body.is-mobile.light-version .navbar .navbar-nav.-white .current-menu-parent > a.nav-link.nav-color', 'body.is-mobile.light-version .navbar .navbar-nav.-white .current-page-ancestor > a.nav-link.nav-color', 'body.is-mobile.light-version .navbar .navbar-nav.-white .current-menu-parent > .nav-link.nav-color', 'body.is-mobile.light-version .navbar .navbar-nav.-white .current-menu-item > a.nav-link.nav-color', 'body.is-mobile.dark-version .navbar .navbar-nav.-white .nav-link:hover', 'body.is-mobile.dark-version .navbar .navbar-nav.-white .nav-link.nav-color:hover', 'body.is-mobile.dark-version .navbar .navbar-nav.-white .nav-link.nav-color:hover', 'body.is-mobile.dark-version .navbar .navbar-nav.-white .current-menu-parent > a.nav-link.nav-color', 'body.is-mobile.dark-version .navbar .navbar-nav.-white .current-page-ancestor > a.nav-link.nav-color', 'body.is-mobile.dark-version .navbar .navbar-nav.-white .current-menu-parent > .nav-link.nav-color', 'body.is-mobile.dark-version .navbar .navbar-nav.-white .current-menu-item > a.nav-link.nav-color', 'body.is-mobile.dark-version .navbar .navbar-nav.-white .active', 'body.is-mobile.light-version .navbar .navbar-nav.-white .active'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						array(
                            'id'          => 'typography-a-hover-navmenu-classic_dark_mob',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Menu Item Hover/ Active(Dark Style)', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'compiler'      => array('body.is-mobile.light-version .navbar .navbar-nav.-black .nav-link:hover', 'body.is-mobile.light-version .navbar .navbar-nav.-black .nav-link.nav-color:hover', 'body.is-mobile.light-version .navbar .navbar-nav.-black .nav-link.nav-color:hover', 'body.is-mobile.light-version .navbar .navbar-nav.-black .current-menu-parent > a.nav-link.nav-color', 'body.is-mobile.light-version .navbar .navbar-nav.-black .current-page-ancestor > a.nav-link.nav-color', 'body.is-mobile.light-version .navbar .navbar-nav.-black .current-menu-parent > .nav-link.nav-color', 'body.is-mobile.light-version .navbar .navbar-nav.-black .current-menu-item > a.nav-link.nav-color', 'body.is-mobile.dark-version .navbar .navbar-nav.-black .nav-link:hover', 'body.is-mobile.dark-version .navbar .navbar-nav.-black .nav-link.nav-color:hover', 'body.is-mobile.dark-version .navbar .navbar-nav.-black .nav-link.nav-color:hover', 'body.is-mobile.dark-version .navbar .navbar-nav.-black .current-menu-parent > a.nav-link.nav-color', 'body.is-mobile.dark-version .navbar .navbar-nav.-black .current-page-ancestor > a.nav-link.nav-color', 'body.is-mobile.dark-version .navbar .navbar-nav.-black .current-menu-parent > .nav-link.nav-color', 'body.is-mobile.dark-version .navbar .navbar-nav.-black .current-menu-item > a.nav-link.nav-color', 'body.is-mobile.dark-version .navbar .navbar-nav.-black .active', 'body.is-mobile.light-version .navbar .navbar-nav.-black .active'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						array(
                            'id'          => 'typography-mob-subnavmenu-classic',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Sub Menu Item', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'compiler'      => array('body.is-mobile .dropdown-menu .dropdown-item', 'body.is-mobile .sub-menu .dropdown-item'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						array(
			                'id' => 'notice_critical1_navmenu_click',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Navigation Menu (Hamburger)', 'bauen'),
			                'desc' => __('', 'bauen')
			            ),		
						array(
                            'id'          => 'typography-a-navmenu-click',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Menu Item', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'compiler'      => array('body .bauen-menu>ul>li>a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),	
						array(
                            'id'          => 'typography-a-hover-navmenu-click',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Menu Item Hover', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'compiler'      => array('body.dark-version .bauen-menu>ul>li:hover>a', 'body.dark-version .bauen-menu .current-menu-parent > a',
							'body.dark-version .bauen-menu .current-page-ancestor > a',
							'body.dark-version .bauen-menu .current-menu-parent > span',
							'body.dark-version .bauen-menu .current-menu-item > a', 'body.dark-version .bauen-menu ul li:hover > a', 'body.dark-version .bauen-menu ul li.open > a', 'body.dark-version .bauen-menu ul li.active > a', 'body.light-version .bauen-menu>ul>li:hover>a', 'body.light-version .bauen-menu .current-menu-parent > a',
							'body.light-version .bauen-menu .current-page-ancestor > a',
							'body.light-version .bauen-menu .current-menu-parent > span', 'body.light-version .bauen-menu .current-menu-item > a', 'body.light-version .bauen-menu ul li:hover > a', 'body.light-version .bauen-menu ul li.open > a', 'body.light-version .bauen-menu ul li.active > a '),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),

						array(
			                'id' => 'notice_critical1_ham_info',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Hamburger Menu Info Options', 'bauen'),
			                'desc' => __('', 'bauen')
			            ),		
						array(
                            'id'          => 'typography-a-ham-info',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Info Item', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'compiler'      => array('body .bauen-menu-footer a', 'body .bauen-menu-footer .contact .text a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),

						array(
                            'id'          => 'typography-a-ham-info-hover',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Info Item (Hover)', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'compiler'      => array('body .bauen-menu-footer a:hover', 'body .bauen-menu-footer .contact .text a:hover'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),
						
						array(
			                'id' => 'notice_critical1_navmenu_sidebar',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Navigation Menu (Sidebar)', 'bauen'),
			                'desc' => __('', 'bauen')
			            ),		
						
						
						array(
                            'id'          => 'typography-a-navmenu-sidebar',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Menu Item', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'compiler'      => array('#bauen-aside.if-call-black .bauen-main-menu>ul>li>a', '#bauen-aside.if-call-white .bauen-main-menu>ul>li>a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),

						array(
                            'id'          => 'typography-a-hover-navmenu-sidebar',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Menu Item Hover/ Active', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'compiler'      => array('body.light-version #bauen-aside .bauen-main-menu > ul > li > a:hover', 'body.light-version #bauen-aside .bauen-main-menu > ul > li.active > a', 'body.light-version #bauen-aside .bauen-main-menu>ul>li.open>a', 'body.light-version #bauen-aside.if-call-white .bauen-main-menu .current-menu-parent > a',
							'body.light-version #bauen-aside.if-call-white .bauen-main-menu .current-page-ancestor > a',
							'body.light-version #bauen-aside.if-call-white .bauen-main-menu .current-menu-parent > span',
							'body.light-version #bauen-aside.if-call-white .bauen-main-menu .current-menu-item > a',
							'body.light-version #bauen-aside.if-call-black .bauen-main-menu .current-menu-parent > a',
							'body.light-version #bauen-aside.if-call-black .bauen-main-menu .current-page-ancestor > a',
							'body.light-version #bauen-aside.if-call-black .bauen-main-menu .current-menu-parent > span',
							'body.light-version #bauen-aside.if-call-black .bauen-main-menu .current-menu-item > a', 'body.light-version #bauen-aside.if-call-white .bauen-main-menu>ul>li>a.nav-link.active',
							'body.light-version #bauen-aside.if-call-black .bauen-main-menu>ul>li>a.nav-link.active',  'body.dark-version #bauen-aside .bauen-main-menu > ul > li > a:hover', 'body.dark-version #bauen-aside .bauen-main-menu > ul > li.active > a', 'body.dark-version #bauen-aside .bauen-main-menu>ul>li.open>a', 'body.dark-version #bauen-aside.if-call-white .bauen-main-menu .current-menu-parent > a',
							'body.dark-version #bauen-aside.if-call-white .bauen-main-menu .current-page-ancestor > a',
							'body.dark-version #bauen-aside.if-call-white .bauen-main-menu .current-menu-parent > span',
							'body.dark-version #bauen-aside.if-call-white .bauen-main-menu .current-menu-item > a',
							'body.dark-version #bauen-aside.if-call-black .bauen-main-menu .current-menu-parent > a',
							'body.dark-version #bauen-aside.if-call-black .bauen-main-menu .current-page-ancestor > a',
							'body.dark-version #bauen-aside.if-call-black .bauen-main-menu .current-menu-parent > span',
							'body.dark-version #bauen-aside.if-call-black .bauen-main-menu .current-menu-item > a', 'body.dark-version #bauen-aside.if-call-white .bauen-main-menu>ul>li>a.nav-link.active',
							'body.dark-version #bauen-aside.if-call-black .bauen-main-menu>ul>li>a.nav-link.active'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),						
						array(
			                'id' => 'notice_critical1_navmenu_overall',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Navigation Menu Sub/Dropdown', 'bauen'),
			                'desc' => __('', 'bauen')
			            ),	
						array(
                            'id'          => 'typography-a-sub-navmenu',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Sub Menu Item', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
							'text-transform' => true,
                            'compiler'      => array('body #bauen-aside .bauen-main-menu ul ul li a', 'body:not(.is-mobile) .dropdown-menu .dropdown-item', 'body:not(.is-mobile) .sub-menu .dropdown-item', 'body .bauen-menu ul ul li a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-transform' => false,
                            ),
						),										
						array(
                            'id'          => 'typography-a-hover-navmenu-sub',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Sub Menu Item Hover', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'compiler'      => array('body.dark-version #bauen-aside .bauen-main-menu ul ul li a:hover', 'body.light-version #bauen-aside .bauen-main-menu ul ul li a:hover', 'body .dropdown-menu .dropdown-item:hover', 'body .sub-menu .dropdown-item:hover', 'body .dropdown-menu .dropdown-item.current-menu-item', 'body .sub-menu .dropdown-item.current-menu-item', 'body.dark-version .bauen-menu ul ul li:hover > a', 'body.dark-version .bauen-menu ul ul li.open > a', 'body.dark-version .bauen-menu ul ul li.active > a', 'body.light-version .bauen-menu ul ul li:hover > a', 'body.light-version .bauen-menu ul ul li.open > a', 'body.light-version .bauen-menu ul ul li.active > a', 'body .dropdown-menu .dropdown-item.current-menu-item a', 'body.dark-version .bauen-menu ul ul li.current-menu-item > a', 'body.light-version .bauen-menu ul ul li.current-menu-item > a', 'body.light-version #bauen-aside.if-call-white .bauen-main-menu ul ul li.current-menu-item > a', 'body.light-version #bauen-aside.if-call-dark .bauen-main-menu ul ul li.current-menu-item > a', 'body.dark-version #bauen-aside.if-call-white .bauen-main-menu ul ul li.current-menu-item > a', 'body.dark-version #bauen-aside.if-call-dark .bauen-main-menu ul ul li.current-menu-item > a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),

						
						array(
			                'id' => 'notice_critical1_logo_overall',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Text Logo Options', 'bauen'),
			                'desc' => __('', 'bauen')
			            ),	
						array(
                            'id'          => 'typography-logo',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Logo Text', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .bauen-header .bauen-logo-wrap .bauen-logo h2', 'body .navbar .logo-wrapper .logo h2', 'body #bauen-aside .bauen-logo h2', 'body .logo-wrapper .logo h2'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),
						array(
                            'id'          => 'typography-logo-sticky',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Sticky Logo Text', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .bauen-header.scrolled.awake .bauen-logo-wrap .bauen-logo h2', 'body .navbar.nav-scroll .logo-wrapper .logo h2', 'body .nav-scroll .logo-wrapper .logo h2'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),
						
						
						
						array(
                            'id'          => 'typography-logo-responsive',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Responisve Logo Text', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body.is-mobile .bauen-header .bauen-logo-wrap .bauen-logo h2', 'body.is-mobile .navbar .logo-wrapper .logo h2', 'body.is-mobile #bauen-aside .bauen-logo h2', 'body.is-mobile .logo-wrapper .logo h2'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),
						
						array(
                            'id'          => 'typography-logo-sticky-res',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Responsive Sticky Logo Text', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body.is-mobile .bauen-header.scrolled.awake .bauen-logo-wrap .bauen-logo h2', 'body.is-mobile .navbar.nav-scroll .logo-wrapper .logo h2', 'body.is-mobile .nav-scroll .logo-wrapper .logo h2'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),
						
						
						array(
                            'id'          => 'typography-logo-tagline',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Logo Tagline', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('#bauen-aside .bauen-logo a span', '.logo-wrapper .logo.custom-logo-sub-gray span', 'body #bauen-aside .custom-logo-sub-gray span', '.logo-wrapper .logo span'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),	

						array(
                            'id'          => 'typography-logo-tagline-res',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Responsive Logo Tagline', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body.is-mobile #bauen-aside .bauen-logo a span', 'body.is-mobile .logo-wrapper .logo.custom-logo-sub-gray span', 'body.is-mobile #bauen-aside .custom-logo-sub-gray span', 'body.is-mobile .logo-wrapper .logo span'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),
						
						array(
			                'id' => 'notice_critical13',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Page', 'bauen'),
			                'desc' => __('', 'bauen')
			            ),					
                        array(
                            'id'          => 'typography-pgcontentl',
                            'type'        => 'typography', 
                            'title'       => __('Content', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .page-content p'),
                            'units'       =>'px',
                            'subtitle'    => __('Specify the page content text font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),							
						),						
                        					
						array(
			                'id' => 'notice_critical14',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Post', 'bauen'),
			                'desc' => __('', 'bauen')
			            ),	
                        array(
                            'id'          => 'typography-bltl',
                            'type'        => 'typography', 
                            'title'       => __('Blog Page Title (List Style)', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .bauen-blog3 .post-cont h5 a'),
                            'units'       =>'px',
                            'subtitle'    => __('Specify the blog post title font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),							
						),	
	                        array(
                            'id'          => 'typography-bltl-hover',
                            'type'        => 'typography', 
                            'title'       => __('Blog Page Title Hover (List Style)', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'compiler'      => array('body .bauen-blog3 .post-cont h5 a:hover'),
                            'units'       =>'px',
                            'subtitle'    => __('Specify the blog post title font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),	
                        array(
                            'id'          => 'typography-bltl-col',
                            'type'        => 'typography', 
                            'title'       => __('Blog Page Title (Column Style)', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .bauen-blog .item .con h5', 'body .bauen-blog .item .con h5 a'),
                            'units'       =>'px',
                            'subtitle'    => __('Specify the blog post title font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),							
						),	
	                        array(
                            'id'          => 'typography-bltl-hover-col',
                            'type'        => 'typography', 
                            'title'       => __('Blog Page Title Hover (Column Style)', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'compiler'      => array('body .bauen-blog .item .con h5:hover', 'body .bauen-blog .item .con h5 a:hover'),
                            'units'       =>'px',
                            'subtitle'    => __('Specify the blog post title font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),
                        array(
                            'id'          => 'typography-bltl-hor',
                            'type'        => 'typography', 
                            'title'       => __('Blog Page Title (Horizontal Style)', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .bauen-blog2 .content .cont h4'),
                            'units'       =>'px',
                            'subtitle'    => __('Specify the blog post title font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),							
						),	
	                        array(
                            'id'          => 'typography-bltl-hover-hor',
                            'type'        => 'typography', 
                            'title'       => __('Blog Page Title Hover (Horizontal Style)', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'compiler'      => array('body .bauen-blog2 .content .cont h4:hover'),
                            'units'       =>'px',
                            'subtitle'    => __('Specify the blog post title font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),							
						),								
                        array(
                            'id'          => 'typography-bltlindx',
                            'type'        => 'typography', 
                            'title'       => __('Post Page Title', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .section-title2'),
                            'units'       =>'px',
                            'subtitle'    => __('Specify the blog post title font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),							
						),						
                        array(
                            'id'          => 'typography-blcon',
                            'type'        => 'typography', 
                            'title'       => __('Post Content', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .post-content p', 'body .comment-text p'),
                            'units'       =>'px',
                            'subtitle'    => __('Specify the blog post content font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),							
						),	
                        array(
                            'id'          => 'typography-blcon',
                            'type'        => 'typography', 
                            'title'       => __('Post Meta', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .blogPost__info.leading-md'),
                            'units'       =>'px',
                            'subtitle'    => __('Specify the blog post content font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),							
						),							
						array(
			                'id' => 'notice_critical1_permalink1_post',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Permalink', 'bauen'),
			                'desc' => __('', 'bauen')
			            ),	
                        array(
                            'id'          => 'typography-lnurl_post',
                            'type'        => 'typography', 
                            'title'       => __('URL', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .post-content a'),
                            'units'       =>'px',
                            'subtitle'    => __('', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-align' => false,
							'letter-spacing' => false,	
                            ),							
						),		
						array(
                            'id'          => 'typography-a-hover_post',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('URL Hover', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'compiler'      => array('body .post-content a:focus', 'body .post-content a:hover'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),	
                        	
												
						array(
			                'id' => 'notice_critical1_intro',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Intro Slider', 'bauen'),
			                'desc' => __('', 'bauen')
			            ),
						array(
                            'id'          => 'typography-intro-slider-title',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Intro Slider Title', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .header .caption h1', 'body .bn-slider-title-class'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),
						
						array(
                            'id'          => 'typography-intro-slider-title-mob',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Intro Slider Title(Small Devices)', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body.is-mobile .header .caption h1', 'body.is-mobile .bn-slider-title-class'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),
						
						array(
                            'id'          => 'typography-intro-slider-subtitle',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Intro Slider Subtitle', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .header .caption p'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),

						array(
                            'id'          => 'typography-intro-slider-subtitle-mob',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Intro Slider Subtitle(Small Devices)', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body.is-mobile .header .caption p'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),						
						
						
						array(
			                'id' => 'notice_critical1_intro_video',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Intro Video', 'bauen'),
			                'desc' => __('', 'bauen')
			            ),
						array(
                            'id'          => 'typography-intro-video-title',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Intro Video Title', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .header .video-fullscreen-wrap h1'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),
						
						array(
                            'id'          => 'typography-intro-video-title-mob',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Intro Video Title(Small Devices)', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body.is-mobile .header .video-fullscreen-wrap h1'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),
						
						array(
                            'id'          => 'typography-intro-video-subtitle',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Intro Video Subtitle', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .video-fullscreen-wrap .video-fullscreen-inner p'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),

						array(
                            'id'          => 'typography-intro-video-subtitle-mob',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Intro Video Subtitle(Small Devices)', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body.is-mobile .video-fullscreen-wrap .video-fullscreen-inner p'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),						
																			
					    array(
			                'id' => 'notice_contact_form',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Contact form font properties.', 'bauen'),
			                'desc' => esc_html__('Specify the Contact form font properties.', 'bauen')
			            ),
						array(
                            'id'          => 'typopagi_form_1',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Contact Form Placeholder', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('::placeholder'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),	
						
						array(
                            'id'          => 'typopagi_form_2',
                            'type'        => 'typography', 
                            'title'       => esc_html__('Label', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body form label'),
                            'units'       =>'px',
                            'line-height'       =>true,
							'font-size'   => true,
                            'text-align'       =>false,
                            'subtitle'    => esc_html__('', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),	
						array(
			                'id' => 'notice_critical1contact_footer',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Footer Contact Section', 'bauen'),
			                'desc' => __('', 'bauen')
			            ),
						array(
                            'id'          => 'typography-footer-con-block',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Block Title', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .main-footer .fotcont .fothead h6'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,
                            ),
						),

						array(
                            'id'          => 'typography-footer-con-block-con',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Block Content', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .fotcont p', 'body .fotcont a', 'body .blog-sidebar .fotcont  .widget.footer-widget-block ul li a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,
                            ),
						),
						array(
			                'id' => 'notice_critical1widget_page',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Page/Post Sidebar Widgets', 'bauen'),
			                'desc' => __('', 'bauen')
			            ),
						
						
						array(
                            'id'          => 'typography-pgsecwdtl',
                            'type'        => 'typography', 
                            'title'       => __('Widget Title', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .blog-sidebar .wp-block-group h2', '.dark-version .blog-sidebar .wp-block-group h2', 'body .blog-sidebar .widget-title h6'),
                            'units'       =>'px',
                            'subtitle'    => __('Specify the page section title font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),							
						), 	
                        array(
                            'id'          => 'typography-pgsecwdcont',
                            'type'        => 'typography', 
                            'title'       => __('Widget Content', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .widget.widget-block', 'body .textwidget'),
                            'units'       =>'px',
                            'subtitle'    => __('Specify the page section title font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),							
						), 		
                        array(
                            'id'          => 'typography-lnurl_sidebar',
                            'type'        => 'typography', 
                            'title'       => __('Widget List Item', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .blog-sidebar a', 'body .blog-sidebar .widget ul li a', 'body .blog-sidebar .widget.widget_text ul li a', 'body  .blog-sidebar .widget.widget_nav_menu ul li a'),
                            'units'       =>'px',
                            'subtitle'    => __('', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),							
						),		
						array(
                            'id'          => 'typography-a-hover_sidebar',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Widget List Item(Hover)', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'compiler'      => array('body .blog-sidebar a:focus', 'body .blog-sidebar a:hover', 'body .blog-sidebar .widget ul li a:focus', 'body .blog-sidebar .widget ul li a:hover', 'body .blog-sidebar .widget.widget_nav_menu ul li:hover a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),

						array(
                            'id'          => 'typography-widget_tag',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Widget Tag', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'compiler'      => array('body .blog-sidebar .tagcloud a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),						

						array(
			                'id' => 'notice_critical1widget_footer',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Footer Widgets', 'bauen'),
			                'desc' => __('', 'bauen')
			            ),
						array(
                            'id'          => 'typography_footer_widget_title',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Widget Title', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .main-footer .fotcont .footer-widget-block .fothead h6'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,
                            ),
						),
						
						array(
                            'id'          => 'typography_footer_widget_list',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Widget List Item', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .main-footer  .footer-widget-block li'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,
                            ),
						),
						
						array(
                            'id'          => 'typography_footer_widget_list_hover',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Widget List Item(Hover)', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .main-footer  .footer-widget-block li:hover'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,
                            ),
						),
						
						array(
                            'id'          => 'typography_footer_widget_a',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Widget a', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .main-footer  .footer-widget-block .textwidget a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,
                            ),
						),
						
						array(
                            'id'          => 'typography_footer_widget_a_hover',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Widget a(Hover)', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .main-footer  .footer-widget-block .textwidget a:hover'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,
                            ),
						),
						
						array(
			                'id' => 'notice_critical1widget_footer_menu',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Footer Menu', 'bauen'),
			                'desc' => __('', 'bauen')
			            ),
						
						array(
                            'id'          => 'typography_footer_menu',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Menu Item', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('.bn-footer-nav li a', '.dark-version .bn-footer-nav li a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the footer menu font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),
						
						array(
                            'id'          => 'typography_footer_menu_hover',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Menu Item Hover', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('.bn-footer-nav li a:hover', '.dark-version .bn-footer-nav li a:hover'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the footer menu font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),
						),

						array(
			                'id' => 'notice_critical1_pagination',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Pagination', 'bauen'),
			                'desc' => __('', 'bauen')
			            ),
						
						array(
                            'id'          => 'typography_pagination_title',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Pagination Title', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .projects-prev-next a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,
                            ),
						),
						
						array(
			                'id' => 'notice_critical1_footer',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('Footer Section', 'bauen'),
			                'desc' => __('', 'bauen')
			            ),
						array(
                            'id'          => 'typography-footer-copy',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Footer Copyright', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .copyright_text'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,
                            ),
						),		
						array(
                            'id'          => 'typography-footer-url',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Footer URL Text', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .main-footer .sub-footer p'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,
                            ),
						),
						array(
                            'id'          => 'typography-footer-url-hover',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Footer URL Text Hover', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
                            'compiler'      => array('body .main-footer .sub-footer p a:hover'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),	
						array(
			                'id' => 'notice_critical1_shop_list',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => __('WooCommerce Product Page', 'bauen'),
			                'desc' => __('', 'bauen')
			            ),
						array(
                            'id'          => 'typography_result_count',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Result Count', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('.woocommerce .woocommerce-result-count', '.dark-version.woocommerce .woocommerce-result-count'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,
                            ),
						),
						array(
                            'id'          => 'typography_product_shorting',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Product Shorting', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('.dark-version select', '.light-version select'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,
                            ),
						),
						array(
                            'id'          => 'typography_product_title',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Product Title', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body .projects.products .item .con h5 a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,
                            ),
						),
						
						array(
                            'id'          => 'typography_product_price',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Product Price', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('body.woocommerce ul.products li.product .price'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,
                            ),
						),
						
						array(
                            'id'          => 'typography_cart_button',
                            'type'        => 'typography', 
                            'title'       => __('WooCommerce Button Text Color', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('.woocommerce #respond input#submit, .woocommerce a.button', '.woocommerce button.button, .woocommerce input.button', '.woocommerce #respond input#submit.alt', '.woocommerce a.button.alt', '.woocommerce button.button.alt', '.woocommerce input.button.alt', '.woocommerce button.button.alt.disabled'),
                            'units'       =>'px',
                            'subtitle'    => __('', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),							
						),
						
						array(
                            'id'          => 'typography_cart_button_hover',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('WooCommerce Button Text  Hover Color', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'font-style'  => false,
							'font-family' => false,
							'font-size'   => false,
							'font-weight'   => true,
							'text-align'   => false,
                            'line-height' => false,
                            'compiler'      => array('.woocommerce #respond input#submit:hover', '.woocommerce a.button:hover', '.woocommerce button.button:hover', '.woocommerce input.button:hover', '.woocommerce #respond input#submit.alt:hover', '.woocommerce a.button.alt:hover', '.woocommerce button.button.alt:hover', '.woocommerce input.button.alt:hover', '.woocommerce button.button.alt.disabled:hover'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the Dark Button font properties.', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
							'font-weight'   => false,
                            ),
						),
						
						array(
                            'id'          => 'typography_addedcart_button',
                            'type'        => 'typography', 
                            'title'       => __('Added To Cart Button Text Color', 'bauen'),
                            'google'      => true, 
                            'font-backup' => false,
							'letter-spacing' => true,
                            'compiler'      => array('.woocommerce a.added_to_cart'),
                            'units'       =>'px',
                            'subtitle'    => __('', 'bauen'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            'text-align' => false,
							'letter-spacing' => false,	
                            ),							
						),
						
						array(
                            'id'       => 'opt_button_style_cart_button',
                            'type'     => 'color',
                            'title'    => esc_html__( 'WooCommerce Button Background Color', 'bauen' ),
                            'subtitle' => esc_html__( '', 'bauen' ),
                            'desc'     => esc_html__( '', 'bauen' ),
                        ),

						array(
                            'id'       => 'opt_button_cart_button_hover',
                            'type'     => 'color',
                            'title'    => esc_html__( 'WooCommerce Button Hover Background Color', 'bauen' ),
                            'subtitle' => esc_html__( '', 'bauen' ),
                            'desc'     => esc_html__( '', 'bauen' ),
                        ),
                        
                    )
                ) );

				 Redux::setSection( $opt_name, array(
                    'icon'   => 'el el-icon-th-large',
                    'title'  => esc_html__( 'Footer Settings', 'bauen' ),
                    'fields' => array(					
					array(
			                'id' => 'notice_footer_contact',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Footer Contact & Widget Options', 'bauen'),
			                'desc' => esc_html__('', 'bauen'),
			        ),						
					array(
							'id' => 'en_footer_contact_opt',
							'type' => 'button_set',
							'title' => esc_html__('Footer Contact', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Disable', 'bauen'),
									'st2' => esc_html__('Enable', 'bauen'),
							),
							'default'  => 'st1',
					),
					array(
							'id' => 'en_footer_column_opt',
							'type' => 'button_set',
							'title' => esc_html__('Footer Widget Columns', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('3 Columns', 'bauen'),
									'st2' => esc_html__('4 Columns', 'bauen'),
							),
							'default'  => 'st1',
							'required' => array('en_footer_contact_opt', '=' , 'st1'),
					),
					array(
							'id' => 'footer_address_title',
							'type' => 'text',
							'title' => esc_html__('Address Text', 'bauen'),
							'subtitle' => esc_html__('Ex:  Our Address ', 'bauen'),
							'required' => array('en_footer_contact_opt', '=' , 'st2'),
					),	
					array(
							'id' => 'ft_address1',
							'type' => 'textarea',
							'title' => esc_html__('Address Line 1', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'required' => array('en_footer_contact_opt', '=' , 'st2')
					),	
					array(
							'id' => 'ft_address1_link_url',
							'type' => 'text',
							'title' => esc_html__('Address Line 1 URL', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'required' => array('en_footer_contact_opt', '=' , 'st2')
					),						
					array(
							'id' => 'ft_address2',
							'type' => 'textarea',
							'title' => esc_html__('Address Line 2', 'bauen'),
							'subtitle' => esc_html__('(Optional)', 'bauen'),
							'required' => array('en_footer_contact_opt', '=' , 'st2')
					),
					array(
							'id' => 'ft_address2_link_url',
							'type' => 'text',
							'title' => esc_html__('Address Line 2 URL', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'required' => array('en_footer_contact_opt', '=' , 'st2')
					),						
					array(
							'id' => 'ft_address_link_target',
							'type' => 'button_set',
							'title' => esc_html__('Address URL Open In', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Self', 'bauen'),
									'st2' => esc_html__('Blank', 'bauen'),
							),
							'default'  => 'st1',
							'required' => array('en_footer_contact_opt', '=' , 'st2')
					),	
					array(
							'id' => 'footer_email_title',
							'type' => 'text',
							'title' => esc_html__('Email Text', 'bauen'),
							'subtitle' => esc_html__('Ex: Email', 'bauen'),
							'required' => array('en_footer_contact_opt', '=' , 'st2'),
					),
					array(
							'id' => 'ft_email_address1',
							'type' => 'text',
							'title' => esc_html__('Email Address 1', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'required' => array('en_footer_contact_opt', '=' , 'st2')
					),
					
					array(
							'id' => 'ft_email_address2',
							'type' => 'text',
							
							'title' => esc_html__('Email Address 2', 'bauen'),
							'subtitle' => esc_html__('(Optional)', 'bauen'),
							'required' => array('en_footer_contact_opt', '=' , 'st2')
					),
					array(
							'id' => 'footer_phone_title',
							'type' => 'text',
							'title' => esc_html__('Phone Text', 'bauen'),
							'subtitle' => esc_html__('Ex: Phone', 'bauen'),
							'required' => array('en_footer_contact_opt', '=' , 'st2'),
					),																							
					array(
							'id' => 'ft_phn_number1',
							'type' => 'text',
							'title' => esc_html__('Phone Number 1', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'required' => array('en_footer_contact_opt', '=' , 'st2')								
					),					
					array(
							'id' => 'ft_phn_number2',
							'type' => 'text',
							
							'title' => esc_html__('Phone Number 2', 'bauen'),
							'subtitle' => esc_html__('(Optional)', 'bauen'),
							'required' => array('en_footer_contact_opt', '=' , 'st2')
					),					
				    array(
							'id' => 'theme_copy_right_info_notice',
							'type' => 'info',
		                    'notice' => true,
		                    'style' => 'info',
							'title' => esc_html__('Footer Copyright Options', 'bauen'),
							'desc' => esc_html__('Copyright text of your webSite.', 'bauen'),
					),
					array(
							'id' => 'en_footer_copyright_positon_opt',
							'type' => 'button_set',
							'title' => esc_html__('Copyright Block Position', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Left', 'bauen'),
									'st2' => esc_html__('Center', 'bauen'),
							),
							'default'  => 'st1',
					),
					array(
							'id' => 'copyright',
							'type' => 'editor',
							'wpautop'=>true,
							'title' => esc_html__('Copyright Text', 'bauen'),
							'subtitle' => esc_html__('Insert copyright text here.', 'bauen'),
							'default'          => '&copy; Copyright 2023 Bauen. Developed By <a href="https://themeforest.net/user/webredox/portfolio">webRedox</a>',
							'args'   => array(
								'teeny'            => true,
								'textarea_rows'    => 10
							),
					),				
					array(
			                'id' => 'notice_footer_social',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Footer Social Icon Options', 'bauen'),
			                'desc' => esc_html__('', 'bauen'),
			        ),						
					array(
							'id' => 'en_footer_social_opt',
							'type' => 'button_set',
							'title' => esc_html__('Footer Social Icon', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Disable', 'bauen'),
									'st2' => esc_html__('Enable', 'bauen'),
							),
							'default'  => 'st1',
					),			
					array(
			                'id' => 'notice_footer_nav',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_html__('Footer Right Side Custom URL', 'bauen'),
			                'desc' => esc_html__('Footer right side botttom section custom url option. Working if the footer menu is not active.', 'bauen'),
			        ),						
					array(
							'id' => 'footer_menu_title',
							'type' => 'text',
							
							'title' => esc_html__('Button Text', 'bauen'),
							'subtitle' => esc_html__('Ex: Terms &amp; Conditions', 'bauen'),
					),	
					array(
							'id' => 'ft_menu_link_url',
							'type' => 'text',
							'title' => esc_html__('Custom URL', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
					),						
					array(
							'id' => 'ft_menu_link_target',
							'type' => 'button_set',
							'title' => esc_html__('Link Target', 'bauen'),
							'subtitle' => esc_html__('', 'bauen'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_html__('Self', 'bauen'),
									'st2' => esc_html__('Blank', 'bauen'),
							),
							'default'  => 'st1',
					),									

					array(
						'id' => 'notice_site_to_top',
						'type' => 'info',
						'notice' => true,
						'style' => 'success',
						'title' => esc_html__('Scroll To Top Button Option', 'bauen'),
						'desc' => esc_html__('Enable/Disable to top button.', 'bauen'),
					),
							
					array(
						'id' => 'enable_scroll_top',
						'type' => 'button_set',
						'title' => esc_attr__('Scroll To Top Button', 'bauen'),
						'subtitle' => esc_attr__('', 'bauen'),
						'desc' => '',
						'options' => array(
							'no'=> esc_html__('Disable', 'bauen'),
							'yes' => esc_html__('Enable', 'bauen'),
						),
						'default'  => 'yes'
					),					
					
					)
                ) );
				
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el el-icon-key',
                    'title'  => esc_html__( 'Documentation', 'bauen' ),
                    'fields' => array(					
					
					array(
							'id' => 'docs',
							'type' => 'info',
		                    'notice' => true,
		                    'style' => 'info',
							'title' => esc_html__('Bauen Theme Documentation', 'bauen'),
							'desc' => __('<a href="http://webredox.net/demo/wp/bauen/doc/documentation.html" target="_blank">Click Here</a> To get the theme documentation.', 'bauen')
					),	
					)
                ));
				
				
    /*
     * <--- END SECTIONS
     */


    /*
     *
     * YOU MUST PREFIX THE FUNCTIONS BELOW AND ACTION FUNCTION CALLS OR ANY OTHER CONFIG MAY OVERRIDE YOUR CODE.
     *
     */

    /*
    *
    * --> Action hook examples
    *
    */

    // If Redux is running as a plugin, this will remove the demo notice and links
    //add_action( 'redux/loaded', 'remove_demo' );

    // Function to test the compiler hook and demo CSS output.
    // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
    add_filter('redux/options/' . $opt_name . '/compiler', 'compiler_action', 10, 3);

    // Change the arguments after they've been declared, but before the panel is created
    //add_filter('redux/options/' . $opt_name . '/args', 'change_arguments' );

    // Change the default value of a field after it's been set, but before it's been useds
    //add_filter('redux/options/' . $opt_name . '/defaults', 'change_defaults' );

    // Dynamically add a section. Can be also used to modify sections/fields
    //add_filter('redux/options/' . $opt_name . '/sections', 'dynamic_section');

    /**
     * This is a test function that will let you see when the compiler hook occurs.
     * It only runs if a field    set with compiler=>true is changed.
     * */
    if ( ! function_exists( 'compiler_action' ) ) {
		function compiler_action($options, $css, $changed_values) {
		global $wp_filesystem;
		$bauen_upload_dir = wp_upload_dir(); // Grab uploads folder array
		$bauen_dir = trailingslashit( $bauen_upload_dir['basedir'] ) . 'bauen-typography/';
			if( empty( $wp_filesystem ) ) {
				require_once( ABSPATH .'/wp-admin/includes/file.php' );
				WP_Filesystem();
			}
			if( $wp_filesystem ) {
				$wp_filesystem->mkdir( $bauen_dir );
				$wp_filesystem->put_contents(
					$bauen_dir . 'bauen-daynamic.css',
					$css,
					FS_CHMOD_FILE // predefined mode settings for WP files
				);
			}
		}
    }

    /**
     * Custom function for the callback validation referenced above
     * */
    if ( ! function_exists( 'redux_validate_callback_function' ) ) {
        function redux_validate_callback_function( $field, $value, $existing_value ) {
            $error   = false;
            $warning = false;

            //do your validation
            if ( $value == 1 ) {
                $error = true;
                $value = $existing_value;
            } elseif ( $value == 2 ) {
                $warning = true;
                $value   = $existing_value;
            }

            $return['value'] = $value;

            if ( $error == true ) {
                $return['error'] = $field;
                $field['msg']    = 'your custom error message';
            }

            if ( $warning == true ) {
                $return['warning'] = $field;
                $field['msg']      = 'your custom warning message';
            }

            return $return;
        }
    }

    /**
     * Custom function for the callback referenced above
     */
    if ( ! function_exists( 'redux_my_custom_field' ) ) {
        function redux_my_custom_field( $field, $value ) {
            print_r( $field );
            echo '<br/>';
            print_r( $value );
        }
    }

    /**
     * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
     * Simply include this function in the child themes functions.php file.
     * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
     * so you must use get_template_directory_uri() if you want to use any of the built in icons
     * */
    if ( ! function_exists( 'dynamic_section' ) ) {
        function dynamic_section( $sections ) {
            //$sections = array();
            $sections[] = array(
                'title'  => esc_html__( 'Section via hook', 'bauen' ),
                'desc'   => esc_html__( '<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'bauen' ),
                'icon'   => 'el el-paper-clip',
                // Leave this as a blank section, no options just some intro text set above.
                'fields' => array()
            );

            return $sections;
        }
    }

    /**
     * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
     * */
    if ( ! function_exists( 'change_arguments' ) ) {
        function change_arguments( $args ) {
            //$args['dev_mode'] = true;

            return $args;
        }
    }

    /**
     * Filter hook for filtering the default value of any given field. Very useful in development mode.
     * */
    if ( ! function_exists( 'change_defaults' ) ) {
        function change_defaults( $defaults ) {
            $defaults['str_replace'] = 'Testing filter hook!';

            return $defaults;
        }
    }

    /**
     * Removes the demo link and the notice of integrated demo from the redux-bauen plugin
     */
    if ( ! function_exists( 'remove_demo' ) ) {
        function remove_demo() {
            // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
            if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
                remove_filter( 'plugin_row_meta', array(
                    ReduxFrameworkPlugin::instance(),
                    'plugin_metalinks'
                ), null, 2 );

                // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
                remove_action( 'admin_notices', array( ReduxFrameworkPlugin::instance(), 'admin_notices' ) );
            }
        }
    }